@@ -10,7 +10,7 @@
 ## This sample program is distributed under a different license than the rest
 ## of libSBML.  This program uses the open-source MIT license, as follows:
 ##
-## Copyright (c) 2013-2017 by the California Institute of Technology
+## Copyright (c) 2013-2018 by the California Institute of Technology
 ## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
 ## and the University of Heidelberg (Germany), with support from the National
 ## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
@@ -54,28 +54,28 @@ def main (args):
      program will attempt to convert the model to Level 1 Version 2.     
   """
 
-  latestLevel = SBMLDocument.getDefaultLevel();  
-  latestVersion = SBMLDocument.getDefaultVersion();
+  latestLevel = SBMLDocument.getDefaultLevel()
+  latestVersion = SBMLDocument.getDefaultVersion()
 
   if len(args) != 3:
     print(main.__doc__)
     sys.exit(1)
   
   
-  inputFile = args[1];
-  outputFile = args[2];
-  
-  document = readSBML(inputFile);
-  
-  errors = document.getNumErrors();
-  
-  if (errors > 0):
-      print("Encountered the following SBML errors:" + "\n");
-      document.printErrors();
+  inputFile = args[1]
+  outputFile = args[2]
+
+  document = readSBML(inputFile)
+
+  errors = document.getNumErrors()
+
+  if errors > 0:
+      print("Encountered the following SBML errors:" + "\n")
+      document.printErrors()
       print("Conversion skipped.  Please correct the problems above first."
-      + "\n");
-      return errors;
-  
+      + "\n")
+      return errors
+
   # 
   # If the given model is not already L2v4, assume that the user wants to
   # convert it to the latest release of SBML (which is L2v4 currently).
@@ -83,41 +83,42 @@ def main (args):
   # convert it down to Level 1 (specifically L1v2).
   # 
     
-  olevel = document.getLevel();
-  oversion = document.getVersion();
-  success = False;
-  
-  if (olevel < latestLevel or oversion < latestVersion):
+  olevel = document.getLevel()
+  oversion = document.getVersion()
+  success = False
+
+  if olevel < latestLevel or oversion < latestVersion:
       print ("Attempting to convert Level " + str(olevel) + " Version " + str(oversion)
                                 + " model to Level " + str(latestLevel)
-                                + " Version " + str(latestVersion) + "." + "\n");
-      success = document.setLevelAndVersion(latestLevel, latestVersion);
+                                + " Version " + str(latestVersion) + "." + "\n")
+      success = document.setLevelAndVersion(latestLevel, latestVersion)
   else:
       print ("Attempting to convert Level " + str(olevel) + " Version " + str(oversion)
-                                 + " model to Level 1 Version 2." + "\n");
-      success = document.setLevelAndVersion(1, 2);
-  
-  errors = document.getNumErrors();
-  
-  if (not success):
-      print("Unable to perform conversion due to the following:" + "\n");
-      document.printErrors();
-      print("\n");
+                                 + " model to Level 1 Version 2." + "\n")
+      success = document.setLevelAndVersion(1, 2)
+
+  errors = document.getNumErrors()
+
+  if not success:
+      print("Unable to perform conversion due to the following:" + "\n")
+      document.printErrors()
+      print("\n")
       print("Conversion skipped.  Either libSBML does not (yet)" + "\n"
                                 + "have the ability to convert this model or (automatic)" + "\n"
-                                + "conversion is not possible in this case." + "\n");
-  
-      return errors;
-  elif (errors > 0):
-      print("Information may have been lost in conversion; but a valid model ");
-      print("was produced by the conversion.\nThe following information ");
-      print("was provided:\n");
-      document.printErrors();
-      writeSBML(document, outputFile);
+                                + "conversion is not possible in this case." + "\n")
+
+      return errors
+  elif errors > 0:
+      print("Information may have been lost in conversion; but a valid model ")
+      print("was produced by the conversion.\nThe following information ")
+      print("was provided:\n")
+      document.printErrors()
+      writeSBML(document, outputFile)
   else:
-      print("Conversion completed." + "\n");
-      writeSBML(document, outputFile);
-  return 0;
-  
+      print("Conversion completed." + "\n")
+      writeSBML(document, outputFile)
+  return 0
+
+
 if __name__ == '__main__':
   main(sys.argv)  
