@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -308,7 +308,6 @@ int fixNegativeIndex(int i, ListOf *l){
   }
 }
   
-#ifndef LIBSBML_USE_LEGACY_MATH
 
 /**
  * @return the most specific Swig type for the given ASTBasePlugin object.
@@ -326,4 +325,3 @@ GetDowncastSwigType (ASTBasePlugin* sbp)
 }
 
 
-#endif // #ifndef LIBSBML_USE_LEGACY_MATH
