@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -250,41 +250,41 @@ AssignmentRule::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this AssignmentRule.
  */
-int
-AssignmentRule::getAttribute(const std::string& attributeName,
-                             const char* value) const
-{
-  int return_value = LIBSBML_OPERATION_FAILED;
-  if (getLevel() > 1)
-  {
-    return_value = Rule::getAttribute(attributeName, value);
-  }
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "variable")
-  {
-    value = getVariable().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else
-  {
-    int l1type = getL1TypeCode();
-    if ((attributeName == "name" && l1type == SBML_PARAMETER_RULE) 
-      || (attributeName == "compartment" && l1type == SBML_COMPARTMENT_VOLUME_RULE) 
-      || (attributeName == "species" && l1type == SBML_SPECIES_CONCENTRATION_RULE))
-    {
-      value = getVariable().c_str();
-      return_value = LIBSBML_OPERATION_SUCCESS;
-    }
-  }
-
-  return return_value;
-}
-
+//int
+//AssignmentRule::getAttribute(const std::string& attributeName,
+//                             const char* value) const
+//{
+//  int return_value = LIBSBML_OPERATION_FAILED;
+//  if (getLevel() > 1)
+//  {
+//    return_value = Rule::getAttribute(attributeName, value);
+//  }
+//
+//  if (return_value == LIBSBML_OPERATION_SUCCESS)
+//  {
+//    return return_value;
+//  }
+//
+//  if (attributeName == "variable")
+//  {
+//    value = getVariable().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//  else
+//  {
+//    int l1type = getL1TypeCode();
+//    if ((attributeName == "name" && l1type == SBML_PARAMETER_RULE) 
+//      || (attributeName == "compartment" && l1type == SBML_COMPARTMENT_VOLUME_RULE) 
+//      || (attributeName == "species" && l1type == SBML_SPECIES_CONCENTRATION_RULE))
+//    {
+//      value = getVariable().c_str();
+//      return_value = LIBSBML_OPERATION_SUCCESS;
+//    }
+//  }
+//
+//  return return_value;
+//}
+//
 /** @endcond */
 
 
@@ -437,34 +437,34 @@ AssignmentRule::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this AssignmentRule.
  */
-int
-AssignmentRule::setAttribute(const std::string& attributeName,
-                             const char* value)
-{
-  int return_value = LIBSBML_OPERATION_FAILED;
-  if (getLevel() > 1)
-  {
-    return_value = Rule::setAttribute(attributeName, value);
-  }
-
-  if (attributeName == "variable")
-  {
-    return_value = setVariable(value);
-  }
-  else
-  {
-    int l1type = getL1TypeCode();
-    if ((attributeName == "name" && l1type == SBML_PARAMETER_RULE) 
-      || (attributeName == "compartment" && l1type == SBML_COMPARTMENT_VOLUME_RULE) 
-      || (attributeName == "species" && l1type == SBML_SPECIES_CONCENTRATION_RULE))
-    {
-        return_value = setVariable(value);
-    }
-  }
-
-  return return_value;
-}
-
+//int
+//AssignmentRule::setAttribute(const std::string& attributeName,
+//                             const char* value)
+//{
+//  int return_value = LIBSBML_OPERATION_FAILED;
+//  if (getLevel() > 1)
+//  {
+//    return_value = Rule::setAttribute(attributeName, value);
+//  }
+//
+//  if (attributeName == "variable")
+//  {
+//    return_value = setVariable(value);
+//  }
+//  else
+//  {
+//    int l1type = getL1TypeCode();
+//    if ((attributeName == "name" && l1type == SBML_PARAMETER_RULE) 
+//      || (attributeName == "compartment" && l1type == SBML_COMPARTMENT_VOLUME_RULE) 
+//      || (attributeName == "species" && l1type == SBML_SPECIES_CONCENTRATION_RULE))
+//    {
+//        return_value = setVariable(value);
+//    }
+//  }
+//
+//  return return_value;
+//}
+//
 /** @endcond */
 
 
