@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -283,7 +283,14 @@ Compartment::getSpatialDimensions () const
     }
     else
     {
-      return static_cast<unsigned int>(mSpatialDimensionsDouble);
+      if (util_isNaN(mSpatialDimensionsDouble))
+      {
+        return 0;
+      }
+      else
+      {
+        return static_cast<unsigned int>(mSpatialDimensionsDouble);
+      }
     }
   }
 }
@@ -343,7 +350,7 @@ Compartment::getOutside () const
 
 
 /*
- * @return true if this Compartment is constant, false otherwise.
+ * @return @c true if this Compartment is constant, false otherwise.
  */
 bool
 Compartment::getConstant () const
@@ -353,7 +360,7 @@ Compartment::getConstant () const
 
 
 /*
- * @return true if the id of this SBML object is  set, false
+ * @return @c true if the id of this SBML object is  set, false
  * otherwise.
  */
 bool
@@ -364,7 +371,7 @@ Compartment::isSetId () const
 
 
 /*
- * @return true if the name of this SBML object is  set, false
+ * @return @c true if the name of this SBML object is  set, false
  * otherwise.
  */
 bool
@@ -376,7 +383,7 @@ Compartment::isSetName () const
 
 
 /*
- * @return true if the compartmentType of this Compartment is  set,
+ * @return @c true if the compartmentType of this Compartment is  set,
  * false otherwise. 
  */
 bool
@@ -387,7 +394,7 @@ Compartment::isSetCompartmentType () const
 
 
 /*
- * @return true if the size (volume in L1) of this Compartment is 
+ * @return @c true if the size (volume in L1) of this Compartment is 
  * set, false otherwise.
  */
 bool
@@ -398,7 +405,7 @@ Compartment::isSetSize () const
 
 
 /*
- * @return true if the volume (size in L2) of this Compartment is 
+ * @return @c true if the volume (size in L2) of this Compartment is 
  * set, false otherwise.
  *
  * In SBML L1, a Compartment volume has a default value (1.0) and therefore
@@ -413,7 +420,7 @@ Compartment::isSetVolume () const
 
 
 /*
- * @return true if the units of this Compartment is set, false
+ * @return @c true if the units of this Compartment is set, false
  * otherwise.
  */
 bool
@@ -424,7 +431,7 @@ Compartment::isSetUnits () const
 
 
 /*
- * @return true if the outside of this Compartment is set, false
+ * @return @c true if the outside of this Compartment is set, false
  * otherwise.
  */
 bool
@@ -435,7 +442,7 @@ Compartment::isSetOutside () const
 
 
 /*
- * @return true if the spatialDimenions of this Compartment is set, false
+ * @return @c true if the spatialDimenions of this Compartment is set, false
  * otherwise.
  */
 bool
@@ -446,7 +453,7 @@ Compartment::isSetSpatialDimensions () const
 
 
 /*
- * @return true if the constant of this Compartment is set, false
+ * @return @c true if the constant of this Compartment is set, false
  * otherwise.
  */
 bool
@@ -921,7 +928,7 @@ Compartment::getDerivedUnitDefinition()
   /* we should have a model by this point 
    * OR the object is not yet a child of a model
    */
-
+  
   if (m != NULL)
   {
     if (!m->isPopulatedListFormulaUnitsData())
@@ -929,10 +936,10 @@ Compartment::getDerivedUnitDefinition()
       m->populateListFormulaUnitsData();
     }
     
-    if (m->getFormulaUnitsData(getId(), getTypeCode()))
+    FormulaUnitsData *fud = m->getFormulaUnitsData(getId(), getTypeCode());
+    if (fud != NULL)
     {
-      return m->getFormulaUnitsData(getId(), getTypeCode())
-                                             ->getUnitDefinition();
+      return fud->getUnitDefinition();
     }
     else
     {
@@ -1161,36 +1168,36 @@ Compartment::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this Compartment.
  */
-int
-Compartment::getAttribute(const std::string& attributeName,
-                          const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "units")
-  {
-    value = getUnits().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "outside")
-  {
-    value = getOutside().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "compartmentType")
-  {
-    value = getCompartmentType().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
+//int
+//Compartment::getAttribute(const std::string& attributeName,
+//                          const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  if (return_value == LIBSBML_OPERATION_SUCCESS)
+//  {
+//    return return_value;
+//  }
+//
+//  if (attributeName == "units")
+//  {
+//    value = getUnits().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//  else if (attributeName == "outside")
+//  {
+//    value = getOutside().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//  else if (attributeName == "compartmentType")
+//  {
+//    value = getCompartmentType().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//
+//  return return_value;
+//}
+//
 /** @endcond */
 
 
@@ -1370,30 +1377,30 @@ Compartment::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this Compartment.
  */
-int
-Compartment::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "units")
-  {
-    return_value = setUnits(value);
-  }
-  else if (attributeName == "outside")
-  {
-    return_value = setOutside(value);
-  }
-  else if (attributeName == "compartmentType")
-  {
-    return_value = setCompartmentType(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
+//int
+//Compartment::setAttribute(const std::string& attributeName, const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  if (attributeName == "units")
+//  {
+//    return_value = setUnits(value);
+//  }
+//  else if (attributeName == "outside")
+//  {
+//    return_value = setOutside(value);
+//  }
+//  else if (attributeName == "compartmentType")
+//  {
+//    return_value = setCompartmentType(value);
+//  }
+//
+//  return return_value;
+//}
+//
+///** @endcond */
+//
+//
 
 /** @cond doxygenLibsbmlInternal */
 
