@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -140,7 +140,7 @@ CompartmentType::getName () const
 
 
 /*
- * @return true if the id of this SBML object is set, false
+ * @return @c true if the id of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -151,7 +151,7 @@ CompartmentType::isSetId () const
 
 
 /*
- * @return true if the name of this SBML object is set, false
+ * @return @c true if the name of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -400,14 +400,14 @@ CompartmentType::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this CompartmentType.
  */
-int
-CompartmentType::getAttribute(const std::string& attributeName,
-                              const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  return return_value;
-}
+//int
+//CompartmentType::getAttribute(const std::string& attributeName,
+//                              const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -523,15 +523,15 @@ CompartmentType::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this CompartmentType.
  */
-int
-CompartmentType::setAttribute(const std::string& attributeName,
-                              const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  return return_value;
-}
-
+//int
+//CompartmentType::setAttribute(const std::string& attributeName,
+//                              const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  return return_value;
+//}
+//
 /** @endcond */
 
 
