@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -163,7 +163,7 @@ Delay::getMath () const
 
 
 /*
- * @return true if the math (or equivalently the formula) of this
+ * @return @c true if the math (or equivalently the formula) of this
  * Delay is set, false otherwise.
  */
 bool
@@ -242,10 +242,10 @@ Delay::getDerivedUnitDefinition()
       m->populateListFormulaUnitsData();
     }
     
-    if (m->getFormulaUnitsData(getId(), SBML_EVENT))
+    FormulaUnitsData *fud = m->getFormulaUnitsData(getId(), SBML_EVENT);
+    if (fud != NULL)
     {
-      return m->getFormulaUnitsData(getId(), SBML_EVENT)
-                                             ->getUnitDefinition();
+      return fud->getUnitDefinition();
     }
     else
     {
@@ -311,10 +311,10 @@ Delay::containsUndeclaredUnits()
       m->populateListFormulaUnitsData();
     }
     
-    if (m->getFormulaUnitsData(getId(), SBML_EVENT))
+    FormulaUnitsData *fud = m->getFormulaUnitsData(getId(), SBML_EVENT);
+    if (fud != NULL)
     {
-      return m->getFormulaUnitsData(getId(), SBML_EVENT)
-      ->getContainsUndeclaredUnits();
+      return fud->getContainsUndeclaredUnits();
     }
     else
     {
@@ -532,13 +532,13 @@ Delay::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this Delay.
  */
-int
-Delay::getAttribute(const std::string& attributeName, const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  return return_value;
-}
+//int
+//Delay::getAttribute(const std::string& attributeName, const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -653,13 +653,13 @@ Delay::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this Delay.
  */
-int
-Delay::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  return return_value;
-}
+//int
+//Delay::setAttribute(const std::string& attributeName, const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -687,7 +687,7 @@ Delay::unsetAttribute(const std::string& attributeName)
  * Subclasses should override this method to read (and store) XHTML,
  * MathML, etc. directly from the XMLInputStream.
  *
- * @return true if the subclass read from the stream, false otherwise.
+ * @return @c true if the subclass read from the stream, false otherwise.
  */
 bool
 Delay::readOtherXML (XMLInputStream& stream)
