@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -417,7 +417,7 @@ Event::getUseValuesFromTriggerTime () const
 
   
 /*
- * @return true if the id of this SBML object is set, false
+ * @return @c true if the id of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -428,7 +428,7 @@ Event::isSetId () const
 
 
 /*
- * @return true if the name of this SBML object is set, false
+ * @return @c true if the name of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -440,7 +440,7 @@ Event::isSetName () const
 
 
 /*
- * @return true if the trigger of this Event is set, false otherwise.
+ * @return @c true if the trigger of this Event is set, false otherwise.
  */
 bool
 Event::isSetTrigger () const
@@ -450,7 +450,7 @@ Event::isSetTrigger () const
 
 
 /*
- * @return true if the delay of this Event is set, false otherwise.
+ * @return @c true if the delay of this Event is set, false otherwise.
  */
 bool
 Event::isSetDelay () const
@@ -460,7 +460,7 @@ Event::isSetDelay () const
 
 
 /*
- * @return true if the priority of this Event is set, false otherwise.
+ * @return @c true if the priority of this Event is set, false otherwise.
  */
 bool
 Event::isSetPriority () const
@@ -470,7 +470,7 @@ Event::isSetPriority () const
 
 
 /*
- * @return true if the timeUnits of this Event is set, false
+ * @return @c true if the timeUnits of this Event is set, false
  * otherwise.
  *
  * @warning Definitions of Event in SBML Level 2 Versions 1 and 2
@@ -487,7 +487,7 @@ Event::isSetTimeUnits () const
 
 
 /*
- * @return true if the mUseValuesFromTriggerTime of this Event is set, false otherwise.
+ * @return @c true if the mUseValuesFromTriggerTime of this Event is set, false otherwise.
  */
 bool
 Event::isSetUseValuesFromTriggerTime () const
@@ -1163,6 +1163,19 @@ Event::enablePackageInternal(const std::string& pkgURI, const std::string& pkgPr
   if (mDelay)   mDelay->enablePackageInternal(pkgURI,pkgPrefix,flag);
   if (mPriority)   mPriority->enablePackageInternal(pkgURI,pkgPrefix,flag);
 }
+
+void
+Event::updateSBMLNamespace(const std::string& pkg, unsigned int level,
+  unsigned int version)
+{
+  SBase::updateSBMLNamespace(pkg, level, version);
+
+  mEventAssignments.updateSBMLNamespace(pkg, level, version);
+  if (mTrigger) mTrigger->updateSBMLNamespace(pkg, level, version);
+  if (mDelay)   mDelay->updateSBMLNamespace(pkg, level, version);
+  if (mPriority)   mPriority->updateSBMLNamespace(pkg, level, version);
+
+}
 /** @endcond */
 
 
@@ -1464,24 +1477,24 @@ Event::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this Event.
  */
-int
-Event::getAttribute(const std::string& attributeName, const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "timeUnits")
-  {
-    value = getTimeUnits().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
+//int
+//Event::getAttribute(const std::string& attributeName, const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  if (return_value == LIBSBML_OPERATION_SUCCESS)
+//  {
+//    return return_value;
+//  }
+//
+//  if (attributeName == "timeUnits")
+//  {
+//    value = getTimeUnits().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -1615,18 +1628,18 @@ Event::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this Event.
  */
-int
-Event::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "timeUnits")
-  {
-    return_value = setTimeUnits(value);
-  }
-
-  return return_value;
-}
+//int
+//Event::setAttribute(const std::string& attributeName, const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  if (attributeName == "timeUnits")
+//  {
+//    return_value = setTimeUnits(value);
+//  }
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -1693,8 +1706,8 @@ Event::createChildObject(const std::string& elementName)
 /** @cond doxygenLibsbmlInternal */
 
 /*
-* Adds an new "elementName" object in this Event.
-*/
+ * Adds an new "elementName" object in this Event.
+ */
 int
 Event::addChildObject(const std::string& elementName, const SBase* element)
 {
@@ -1724,8 +1737,8 @@ Event::addChildObject(const std::string& elementName, const SBase* element)
 /** @cond doxygenLibsbmlInternal */
 
 /*
-* Adds an new "elementName" object in this Event.
-*/
+ * Adds an new "elementName" object in this Event.
+ */
 SBase*
 Event::removeChildObject(const std::string& elementName, const std::string& id)
 {
