@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -171,7 +171,7 @@ EventAssignment::getMath () const
 
 
 /*
- * @return true if the variable of this EventAssignment is set, false
+ * @return @c true if the variable of this EventAssignment is set, false
  * otherwise.
  */
 bool
@@ -182,7 +182,7 @@ EventAssignment::isSetVariable () const
 
 
 /*
- * @return true if the math of this EventAssignment is set, false
+ * @return @c true if the math of this EventAssignment is set, false
  * otherwise.
  */
 bool
@@ -300,10 +300,10 @@ EventAssignment::getDerivedUnitDefinition()
     if (e != NULL) eid = e->getInternalId();
     
     std::string id = getVariable() + eid;
-    if (m->getFormulaUnitsData(id, getTypeCode()) != NULL)
+    FormulaUnitsData *fud = m->getFormulaUnitsData(id, getTypeCode());
+    if (fud != NULL)
     {
-      return m->getFormulaUnitsData(id, getTypeCode())
-                                             ->getUnitDefinition();
+      return fud->getUnitDefinition();
     }
     else
     {
@@ -375,10 +375,10 @@ EventAssignment::containsUndeclaredUnits()
     if (e != NULL) eid = e->getInternalId();
 
     std::string id = getVariable() + eid;
-    if (m->getFormulaUnitsData(id, getTypeCode()) != NULL)
+    FormulaUnitsData *fud = m->getFormulaUnitsData(id, getTypeCode());
+    if (fud != NULL)
     {
-      return m->getFormulaUnitsData(id, getTypeCode())
-      ->getContainsUndeclaredUnits();
+      return fud->getContainsUndeclaredUnits();
     }
     else
     {
@@ -584,26 +584,26 @@ EventAssignment::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this EventAssignment.
  */
-int
-EventAssignment::getAttribute(const std::string& attributeName,
-                              const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "variable")
-  {
-    value = getVariable().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
+//int
+//EventAssignment::getAttribute(const std::string& attributeName,
+//                              const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  if (return_value == LIBSBML_OPERATION_SUCCESS)
+//  {
+//    return return_value;
+//  }
+//
+//  if (attributeName == "variable")
+//  {
+//    value = getVariable().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//
+//  return return_value;
+//}
+//
 /** @endcond */
 
 
@@ -728,19 +728,19 @@ EventAssignment::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this EventAssignment.
  */
-int
-EventAssignment::setAttribute(const std::string& attributeName,
-                              const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "variable")
-  {
-    return_value = setVariable(value);
-  }
-
-  return return_value;
-}
+//int
+//EventAssignment::setAttribute(const std::string& attributeName,
+//                              const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  if (attributeName == "variable")
+//  {
+//    return_value = setVariable(value);
+//  }
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -859,7 +859,7 @@ EventAssignment::writeElements (XMLOutputStream& stream) const
  * Subclasses should override this method to read (and store) XHTML,
  * MathML, etc. directly from the XMLInputStream.
  *
- * @return true if the subclass read from the stream, false otherwise.
+ * @return @c true if the subclass read from the stream, false otherwise.
  */
 bool
 EventAssignment::readOtherXML (XMLInputStream& stream)
