@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -177,7 +177,7 @@ FunctionDefinition::getMath () const
 
 
 /*
- * @return true if the id of this SBML object is set, false
+ * @return @c true if the id of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -188,7 +188,7 @@ FunctionDefinition::isSetId () const
 
 
 /*
- * @return true if the name of this SBML object is set, false
+ * @return @c true if the name of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -200,7 +200,7 @@ FunctionDefinition::isSetName () const
 
 
 /*
- * @return true if the math of this FunctionDefinition is set, false
+ * @return @c true if the math of this FunctionDefinition is set, false
  * otherwise.
  */
 bool
@@ -719,14 +719,14 @@ FunctionDefinition::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this FunctionDefinition.
  */
-int
-FunctionDefinition::getAttribute(const std::string& attributeName,
-                                 const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  return return_value;
-}
+//int
+//FunctionDefinition::getAttribute(const std::string& attributeName,
+//                                 const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -843,14 +843,14 @@ FunctionDefinition::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this FunctionDefinition.
  */
-int
-FunctionDefinition::setAttribute(const std::string& attributeName,
-                                 const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  return return_value;
-}
+//int
+//FunctionDefinition::setAttribute(const std::string& attributeName,
+//                                 const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -879,7 +879,7 @@ FunctionDefinition::unsetAttribute(const std::string& attributeName)
  * Subclasses should override this method to read (and store) XHTML,
  * MathML, etc. directly from the XMLInputStream.
  *
- * @return true if the subclass read from the stream, false otherwise.
+ * @return @c true if the subclass read from the stream, false otherwise.
  */
 bool
 FunctionDefinition::readOtherXML (XMLInputStream& stream)
