@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -450,6 +450,20 @@ ListOf::enablePackageInternal(const std::string& pkgURI, const std::string& pkgP
     ++it;
   }
 }
+
+void
+ListOf::updateSBMLNamespace(const std::string& pkg, unsigned int level,
+  unsigned int version)
+{
+  SBase::updateSBMLNamespace(pkg, level, version);
+  
+  ListItemIter it = mItems.begin();
+  while (it != mItems.end())
+  {
+    (*it)->updateSBMLNamespace(pkg, level, version);
+    ++it;
+  }
+}
 /** @endcond */
 
 
