@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -435,7 +435,7 @@ Reaction::getCompartment () const
 
 
 /*
- * @return true if the id of this SBML object is set, false
+ * @return @c true if the id of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -446,7 +446,7 @@ Reaction::isSetId () const
 
 
 /*
- * @return true if the name of this SBML object is set, false
+ * @return @c true if the name of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -458,7 +458,7 @@ Reaction::isSetName () const
 
 
 /*
- * @return true if the KineticLaw of this Reaction is set, false
+ * @return @c true if the KineticLaw of this Reaction is set, false
  * otherwise.
  */
 bool
@@ -469,7 +469,7 @@ Reaction::isSetKineticLaw () const
 
 
 /*
- * @return true if the fast status of this Reaction is set, false
+ * @return @c true if the fast status of this Reaction is set, false
  * otherwise.
  *
  * In L1, fast is optional with a default of false, which means it is
@@ -484,7 +484,7 @@ Reaction::isSetFast () const
 
 
 /*
- * @return true if the compartment of this SBML object is set, false
+ * @return @c true if the compartment of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -495,7 +495,7 @@ Reaction::isSetCompartment () const
 
 
 /*
- * @return true if the fast status of this Reaction is set, false
+ * @return @c true if the fast status of this Reaction is set, false
  * otherwise.
  */
 bool
@@ -1424,6 +1424,20 @@ Reaction::enablePackageInternal(const std::string& pkgURI,
 
   if (mKineticLaw) mKineticLaw->enablePackageInternal(pkgURI,pkgPrefix,flag);
 }
+
+
+void
+Reaction::updateSBMLNamespace(const std::string& pkg, unsigned int level,
+  unsigned int version)
+{
+  SBase::updateSBMLNamespace(pkg, level, version);
+
+  mReactants.updateSBMLNamespace(pkg, level, version);
+  mProducts.updateSBMLNamespace(pkg, level, version);
+  mModifiers.updateSBMLNamespace(pkg, level, version);
+
+  if (mKineticLaw) mKineticLaw->updateSBMLNamespace(pkg, level, version);
+}
 /** @endcond */
 
 
@@ -1686,25 +1700,25 @@ Reaction::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this Reaction.
  */
-int
-Reaction::getAttribute(const std::string& attributeName,
-                       const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "compartment")
-  {
-    value = getCompartment().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
+//int
+//Reaction::getAttribute(const std::string& attributeName,
+//                       const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  if (return_value == LIBSBML_OPERATION_SUCCESS)
+//  {
+//    return return_value;
+//  }
+//
+//  if (attributeName == "compartment")
+//  {
+//    value = getCompartment().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -1846,18 +1860,18 @@ Reaction::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this Reaction.
  */
-int
-Reaction::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "compartment")
-  {
-    return_value = setCompartment(value);
-  }
-
-  return return_value;
-}
+//int
+//Reaction::setAttribute(const std::string& attributeName, const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  if (attributeName == "compartment")
+//  {
+//    return_value = setCompartment(value);
+//  }
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -1928,8 +1942,8 @@ Reaction::createChildObject(const std::string& elementName)
 /** @cond doxygenLibsbmlInternal */
 
 /*
-* Adds an new "elementName" object in this Reaction.
-*/
+ * Adds an new "elementName" object in this Reaction.
+ */
 int
 Reaction::addChildObject(const std::string& elementName, const SBase* element)
 {
@@ -1959,8 +1973,8 @@ Reaction::addChildObject(const std::string& elementName, const SBase* element)
 /** @cond doxygenLibsbmlInternal */
 
 /*
-* Adds an new "elementName" object in this Reaction.
-*/
+ * Adds an new "elementName" object in this Reaction.
+ */
 SBase*
 Reaction::removeChildObject(const std::string& elementName, const std::string& id)
 {
