@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -231,7 +231,7 @@ Rule::getUnits () const
 
 
 /*
- * @return true if the formula (or equivalently the math) for this Rule is
+ * @return @c true if the formula (or equivalently the math) for this Rule is
  * set, false otherwise.
  */
 bool
@@ -242,7 +242,7 @@ Rule::isSetFormula () const
 
 
 /*
- * @return true if the math (or equivalently the formula) for this Rule is
+ * @return @c true if the math (or equivalently the formula) for this Rule is
  * set, false otherwise.
  */
 bool
@@ -268,7 +268,7 @@ Rule::isSetMath () const
 
 
 /*
- * @return true if the variable of this Rule is set, false
+ * @return @c true if the variable of this Rule is set, false
  * otherwise.
  */
 bool
@@ -279,7 +279,7 @@ Rule::isSetVariable () const
 
 
 /*
- * @return true if the units for this Rule is set, false otherwise
+ * @return @c true if the units for this Rule is set, false otherwise
  * (L1 ParameterRules only).
  */
 bool
@@ -502,10 +502,10 @@ Rule::getDerivedUnitDefinition()
     
     if (isAlgebraic())
     {
-      if (m->getFormulaUnitsData(getInternalId(), getTypeCode()) != NULL)
+      FormulaUnitsData *fud = m->getFormulaUnitsData(getInternalId(), getTypeCode());
+      if (fud != NULL)
       {
-        return m->getFormulaUnitsData(getInternalId(), getTypeCode())
-                                               ->getUnitDefinition();
+        return fud->getUnitDefinition();
       }
       else
       {
@@ -514,10 +514,10 @@ Rule::getDerivedUnitDefinition()
     }
     else
     {
-      if (m->getFormulaUnitsData(getVariable(), getTypeCode()) != NULL)
+      FormulaUnitsData *fud = m->getFormulaUnitsData(getVariable(), getTypeCode());
+      if (fud != NULL)
       {
-        return m->getFormulaUnitsData(getVariable(), getTypeCode())
-                                              ->getUnitDefinition();
+        return fud->getUnitDefinition();
       }
       else
       {
@@ -588,10 +588,10 @@ Rule::containsUndeclaredUnits()
     
     if (isAlgebraic())
     {
-      if (m->getFormulaUnitsData(getInternalId(), getTypeCode()) != NULL)
+      FormulaUnitsData *fud = m->getFormulaUnitsData(getInternalId(), getTypeCode());
+      if (fud != NULL)
       {
-        return m->getFormulaUnitsData(getInternalId(), getTypeCode())
-          ->getContainsUndeclaredUnits();
+        return fud->getContainsUndeclaredUnits();
       }
       else
       {
@@ -600,10 +600,10 @@ Rule::containsUndeclaredUnits()
     }
     else
     {
-      if (m->getFormulaUnitsData(getVariable(), getTypeCode()) != NULL)
+      FormulaUnitsData *fud = m->getFormulaUnitsData(getVariable(), getTypeCode());
+      if (fud != NULL)
       {
-        return m->getFormulaUnitsData(getVariable(), getTypeCode())
-          ->getContainsUndeclaredUnits();
+        return fud->getContainsUndeclaredUnits();
       }
       else
       {
@@ -642,7 +642,7 @@ Rule::getType () const
 
 
 /*
- * @return true if this Rule is an AlgebraicRule, false otherwise.
+ * @return @c true if this Rule is an AlgebraicRule, false otherwise.
  */
 bool
 Rule::isAlgebraic () const
@@ -652,7 +652,7 @@ Rule::isAlgebraic () const
 
 
 /*
- * @return true if this Rule is an AssignmentRule, false otherwise.
+ * @return @c true if this Rule is an AssignmentRule, false otherwise.
  */
 bool
 Rule::isAssignment () const
@@ -662,7 +662,7 @@ Rule::isAssignment () const
 
 
 /*
- * @return true if this Rule is a CompartmentVolumeRule, false otherwise.
+ * @return @c true if this Rule is a CompartmentVolumeRule, false otherwise.
  */
 bool
 Rule::isCompartmentVolume () const
@@ -680,7 +680,7 @@ Rule::isCompartmentVolume () const
 
 
 /*
- * @return true if this Rule is a ParameterRule, false otherwise.
+ * @return @c true if this Rule is a ParameterRule, false otherwise.
  */
 bool
 Rule::isParameter () const
@@ -698,7 +698,7 @@ Rule::isParameter () const
 
 
 /*
- * @return true if this Rule is a RateRule (L2) or has type="rate" (L1),
+ * @return @c true if this Rule is a RateRule (L2) or has type="rate" (L1),
  * false otherwise.
  */
 bool
@@ -709,7 +709,7 @@ Rule::isRate () const
 
 
 /*
- * @return true if this Rule is an AssignmentRule (L2) has type="scalar"
+ * @return @c true if this Rule is an AssignmentRule (L2) has type="scalar"
  * (L1), false otherwise.
  */
 bool
@@ -720,7 +720,7 @@ Rule::isScalar () const
 
 
 /*
- * @return true if this Rule is a SpeciesConcentrationRule, false
+ * @return @c true if this Rule is a SpeciesConcentrationRule, false
  * otherwise.
  */
 bool
@@ -1014,14 +1014,14 @@ Rule::getAttribute(const std::string& attributeName, std::string& value) const
 /*
  * Gets the value of the "attributeName" attribute of this Rule.
  */
-int
-Rule::getAttribute(const std::string& attributeName, const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  return return_value;
-}
-
+//int
+//Rule::getAttribute(const std::string& attributeName, const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  return return_value;
+//}
+//
 /** @endcond */
 
 
@@ -1133,13 +1133,13 @@ Rule::setAttribute(const std::string& attributeName, const std::string& value)
 /*
  * Sets the value of the "attributeName" attribute of this Rule.
  */
-int
-Rule::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  return return_value;
-}
+//int
+//Rule::setAttribute(const std::string& attributeName, const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -1187,7 +1187,7 @@ Rule::writeElements (XMLOutputStream& stream) const
  * Subclasses should override this method to read (and store) XHTML,
  * MathML, etc. directly from the XMLInputStream.
  *
- * @return true if the subclass read from the stream, false otherwise.
+ * @return @c true if the subclass read from the stream, false otherwise.
  */
 bool
 Rule::readOtherXML (XMLInputStream& stream)
