@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -549,12 +549,12 @@ SBMLDocument::setLevelAndVersion (unsigned int level, unsigned int version,
 /** @cond doxygenLibsbmlInternal */
 
 /* 
-* function to set level to 0 on a doc that was just been created to read in to
-* the SBMLReader will only do this if the file is found to be invalid
-* this will allow for testing for an SBMLDocument without
-* relying on it having a model to be valid 
-* (in L3V2 a missing model will be valid) 
-*/
+ * function to set level to 0 on a doc that was just been created to read in to
+ * the SBMLReader will only do this if the file is found to be invalid
+ * this will allow for testing for an SBMLDocument without
+ * relying on it having a model to be valid 
+ * (in L3V2 a missing model will be valid) 
+ */
 void 
 SBMLDocument::setInvalidLevel()
 {
@@ -566,92 +566,20 @@ SBMLDocument::setInvalidLevel()
 
 /** @cond doxygenLibsbmlInternal */
 void 
-SBMLDocument::updateSBMLNamespace(const std::string&, unsigned int level,
+SBMLDocument::updateSBMLNamespace(const std::string& package, unsigned int level,
                             unsigned int version)
 {
-  // is there a prefix on the sbml namespace
-  std::string currentSBMLCoreURI = 
-                        SBMLNamespaces::getSBMLNamespaceURI(getLevel(), 
-                                                            getVersion()); 
-  std::string currentSBMLCorePrefix = mSBMLNamespaces->getNamespaces()->
-    getPrefix(currentSBMLCoreURI);
-
-  //bool sbmlDecl = false;
-
-  //if (currentSBMLCorePrefix.empty() == false)
-  //  sbmlDecl = true;
-
-  mLevel   = level;
-  mVersion = version;
-
-  if (mSBMLNamespaces == NULL) 
-    mSBMLNamespaces = new SBMLNamespaces(mLevel, mVersion);
-
-  std::string uri;
-
-  switch (mLevel)
+  SBase::updateSBMLNamespace(package, level, version);
+  if (package.empty() || package == "core")
   {
-    case 1:
-      uri = SBML_XMLNS_L1;
-      break;
-    case 2:
-      switch (mVersion)
-      {
-      case 1:
-        uri = SBML_XMLNS_L2V1;
-        break;
-      case 2:
-        uri = SBML_XMLNS_L2V2;
-        break;
-      case 3:
-        uri = SBML_XMLNS_L2V3;
-        break;
-      case 4:
-        uri = SBML_XMLNS_L2V4;
-        break;
-      case 5:
-      default:
-        uri = SBML_XMLNS_L2V5;
-        break;
-      }
-      break;
-    case 3:
-    default:
-      switch (mVersion)
-      {
-      case 1:
-        uri = SBML_XMLNS_L3V1;
-        break;
-      case 2:
-      default:
-        uri = SBML_XMLNS_L3V2;
-        break;
-      }
-      break;
+    mLevel = level;
+    mVersion = version;
   }
 
-
-  mSBMLNamespaces->getNamespaces()->remove(currentSBMLCorePrefix);
-  mSBMLNamespaces->getNamespaces()->add(uri, currentSBMLCorePrefix);
-  // it is possible that the ns exists unprefixed as well as prefixed
-  // the code will return the first it encounters
-  // so check if the original ns is still there
-  if (mSBMLNamespaces->getNamespaces()->containsUri(currentSBMLCoreURI) == true)
+  if (isSetModel())
   {
-    currentSBMLCorePrefix = mSBMLNamespaces->getNamespaces()
-      ->getPrefix(currentSBMLCoreURI);
-    mSBMLNamespaces->getNamespaces()->remove(currentSBMLCorePrefix);
-    mSBMLNamespaces->getNamespaces()->add(uri, currentSBMLCorePrefix);
+    mModel->updateSBMLNamespace(package, level, version);
   }
-
-
-  //if (sbmlDecl)
-  //{
-  //  mSBMLNamespaces->getNamespaces()->add(uri, currentSBMLCorePrefix);
-  //}
-  mSBMLNamespaces->setLevel(mLevel);
-  mSBMLNamespaces->setVersion(mVersion);
-  setElementNamespace(uri); // this needs to propagate
 }
 /** @endcond */
 
@@ -1210,12 +1138,12 @@ SBMLDocument::checkL3v1Compatibility ()
 
 
 /*
-* Performs a set of semantic consistency checks on the document to establish
-* whether it is compatible with L3v2 and can be converted.  Query
-* the results by calling getNumErrors() and getError().
-*
-* @return the number of failed checks (errors) encountered.
-*/
+ * Performs a set of semantic consistency checks on the document to establish
+ * whether it is compatible with L3v2 and can be converted.  Query
+ * the results by calling getNumErrors() and getError().
+ *
+ * @return the number of failed checks (errors) encountered.
+ */
 unsigned int
 SBMLDocument::checkL3v2Compatibility()
 {
@@ -1378,8 +1306,8 @@ SBMLDocument::createObject (XMLInputStream& stream)
       if (getLevel() < 3 || (getLevel() == 3 && getVersion() < 2)) 
       {
         logError(NotSchemaConformant, getLevel(), getVersion(),
-	        "Only one <model> element is permitted inside a "
-	        "document.");
+          "Only one <model> element is permitted inside a "
+          "document.");
       }
       else
       {
@@ -1797,6 +1725,32 @@ SBMLDocument::readAttributes (const XMLAttributes& attributes,
 
       if (sbmlext && sbmlext->isEnabled())
       {
+        // if we are in l3v2 and there exists an l3v2 version for the package
+        // we wont accept the l3v1 version
+        if (sbmlext->getVersion(uri) < 2 && this->getVersion() > 1)
+        {
+          std::string dummyURI;
+          dummyURI.assign(uri);
+          size_t pos = dummyURI.find("level3");
+          if (pos != std::string::npos)
+          {
+            dummyURI.replace(pos, 15, "level3/version2");
+            if (sbmlext->getVersion(dummyURI) == 2)
+            {
+              ostringstream msg;
+
+              msg << "Package '" << xmlns->getPrefix(i) <<
+                "' has a L3V2V1 specification which must be used in an L3V2 document.";
+              logError(InvalidPackageLevelVersion, mLevel, mVersion, msg.str());
+              return;
+
+
+            }
+          }
+        }
+
+
+
         const std::string &prefix = xmlns->getPrefix(i);
         SBaseExtensionPoint extPoint(getPackageName(), SBML_DOCUMENT);
         const SBasePluginCreatorBase* sbPluginCreator = sbmlext->getSBasePluginCreator(extPoint);
@@ -1821,7 +1775,7 @@ SBMLDocument::readAttributes (const XMLAttributes& attributes,
         //     if the value is true.
         //  4) Added a check that the uri could possibly be a l3 ns
         //
-        size_t pos = uri.find("http://www.sbml.org/sbml/level3/version1");
+        size_t pos = uri.find("http://www.sbml.org/sbml/level3/version");
         std::string requiredAttr = attributes.getValue("required",uri);
         if (pos == 0 && !requiredAttr.empty())
         {
@@ -2091,14 +2045,39 @@ SBMLDocument::writeAttributes (XMLOutputStream& stream) const
   // level: positiveInteger  { use="required" fixed="1" }  (L1v1)
   // level: positiveInteger  { use="required" fixed="2" }  (L2v1)
   //
-  stream.writeAttribute("level", mLevel);
+
+  /* when a non xml model is read in level and version are set to 0
+   * is we were for some obscure reason writing out the SBMLDocument that 
+   * was created - we dont want to use l0v0
+   */
+  if (mLevel > 0)
+  {
+    stream.writeAttribute("level", mLevel);
+  }
+  else
+  {
+    stream.writeAttribute("level", getDefaultLevel());
+  }
 
   //
   // version: positiveInteger  { use="required" fixed="1" }  (L1v1, L2v1)
   // version: positiveInteger  { use="required" fixed="2" }  (L1v2, L2v2)
   // version: positiveInteger  { use="required" fixed="3" }  (L2v3)
   //
-  stream.writeAttribute("version", mVersion);
+
+  /* when a non xml model is read in level and version are set to 0
+  * is we were for some obscure reason writing out the SBMLDocument that
+  * was created - we dont want to use l0v0
+  */
+  if (mVersion > 0)
+  {
+    stream.writeAttribute("version", mVersion);
+  }
+  else
+  {
+    stream.writeAttribute("version", getDefaultVersion());
+  }
+
 
 
   //
@@ -2144,6 +2123,17 @@ SBMLDocument::writeAttributes (XMLOutputStream& stream) const
 void
 SBMLDocument::writeXMLNS (XMLOutputStream& stream) const
 {
+  /* when a non xml model is read in level and version are set to 0
+  * is we were for some obscure reason writing out the SBMLDocument that
+  * was created - we dont want to use l0v0
+  */
+  unsigned int level = mLevel;
+  unsigned int version = mVersion;
+  if (mLevel == 0 && mVersion == 0)
+  {
+    level = getDefaultLevel();
+    version = getDefaultVersion();
+  }
   // need to check that we have indeed a namespace set!
   XMLNamespaces * thisNs = this->getNamespaces();
 
@@ -2151,19 +2141,19 @@ SBMLDocument::writeXMLNS (XMLOutputStream& stream) const
   if (thisNs == NULL)
   {
     XMLNamespaces xmlns;
-    xmlns.add(SBMLNamespaces::getSBMLNamespaceURI(mLevel, mVersion));
+    xmlns.add(SBMLNamespaces::getSBMLNamespaceURI(level, version));
 
     mSBMLNamespaces->setNamespaces(&xmlns);
     thisNs = getNamespaces();
   }
   else if (thisNs->getLength() == 0)
   {
-     thisNs->add(SBMLNamespaces::getSBMLNamespaceURI(mLevel, mVersion));
+     thisNs->add(SBMLNamespaces::getSBMLNamespaceURI(level, version));
   }
   else
   {
     // check that there is an sbml namespace
-    std::string sbmlURI = SBMLNamespaces::getSBMLNamespaceURI(mLevel, mVersion);
+    std::string sbmlURI = SBMLNamespaces::getSBMLNamespaceURI(level, version);
     std::string sbmlPrefix = thisNs->getPrefix(sbmlURI);
     if (thisNs->hasNS(sbmlURI, sbmlPrefix) == false)
     {
