@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -362,33 +362,33 @@
  * errors that can occur while validating general SBML constructs.  With
  * respect to the SBML specification, these concern failures in applying
  * the validation rules numbered 2xxxx in the Level&nbsp;2 Versions&nbsp;2&ndash;4
- * and Level&nbsp;3 Version&nbsp;1 specifications.</td></tr>
+ * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications.</td></tr>
  * <tr><td>@sbmlconstant{LIBSBML_CAT_IDENTIFIER_CONSISTENCY, XMLErrorCategory_t}</td><td>Category of
  * errors that can occur while validating symbol identifiers in a model.
  * With respect to the SBML specification, these concern failures in
  * applying the validation rules numbered 103xx in the Level&nbsp;2 Versions&nbsp;2&ndash;4
- * and Level&nbsp;3 Version&nbsp;1 specifications.</td></tr>
+ * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications.</td></tr>
  * <tr><td>@sbmlconstant{LIBSBML_CAT_UNITS_CONSISTENCY, XMLErrorCategory_t}</td><td>Category of
  * errors that can occur while validating the units of measurement on
  * quantities in a model.  With respect to the SBML specification, these
  * concern failures in applying the validation rules numbered 105xx in the
  * Level&nbsp;2 Versions&nbsp;2&ndash;4
- * and Level&nbsp;3 Version&nbsp;1 specifications.</td></tr>
+ * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications.</td></tr>
  * <tr><td>@sbmlconstant{LIBSBML_CAT_MATHML_CONSISTENCY, XMLErrorCategory_t}</td><td>Category of
  * errors that can occur while validating MathML formulas in a model.  With
  * respect to the SBML specification, these concern failures in applying
  * the validation rules numbered 102xx in the Level&nbsp;2 Versions&nbsp;2&ndash;4
- * and Level&nbsp;3 Version&nbsp;1 specifications.</td></tr>
+ * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications.</td></tr>
  * <tr><td>@sbmlconstant{LIBSBML_CAT_SBO_CONSISTENCY, XMLErrorCategory_t}</td><td>Category of errors
  * that can occur while validating SBO identifiers in a model.  With
  * respect to the SBML specification, these concern failures in applying
  * the validation rules numbered 107xx in the Level&nbsp;2 Versions&nbsp;2&ndash;4
- * and Level&nbsp;3 Version&nbsp;1 specifications.</td></tr>
+ * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications.</td></tr>
  * <tr><td>@sbmlconstant{LIBSBML_CAT_OVERDETERMINED_MODEL, XMLErrorCategory_t}</td><td>Error in the
  * system of equations in the model: the system is overdetermined,
  * therefore violating a tenet of proper SBML.  With respect to the SBML
  * specification, this is validation rule #10601 in the SBML Level&nbsp;2 Versions&nbsp;2&ndash;4
- * and Level&nbsp;3 Version&nbsp;1 specifications.</td></tr>
+ * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications.</td></tr>
  * <tr><td>@sbmlconstant{LIBSBML_CAT_SBML_L2V3_COMPAT, XMLErrorCategory_t}</td><td>Category of errors
  * that can only occur during attempted translation from one Level/Version
  * of SBML to another.  This particular category applies to errors
@@ -495,7 +495,10 @@ typedef enum
 , InvalidNoArgsPassedToFunctionDef      = 10219 /*!< Incorrect number of arguments given to function invocation. */
 , DisallowedMathUnitsUse                = 10220 /*!< Attribute 'units' is only permitted on <code>&lt;cn&gt;</code> elements. */
 , InvalidUnitsValue                     = 10221 /*!< Invalid value given for the 'units' attribute. */
-, CiCannotReference0DCompartment        = 10222
+, CiCannotReference0DCompartment        = 10222 /*!< A <code>&lt;ci&gt;</code> element cannot reference a 0D compartment. */
+, RateOfTargetMustBeCi                  = 10223 /*!< A 'rateOf' <code>&lt;csymbol&gt;</code> must target only a single <code>&lt;ci&gt;</code> element. */
+, RateOfTargetCannotBeAssigned          = 10224 /*!< The target of a 'rateOf' <code>&lt;csymbol&gt;</code> cannot be assigned. */
+, RateOfSpeciesTargetCompartmentNot     = 10225 /*!< Compartments of non-substance <code>&lt;species&gt;</code> referenced by 'rateOf' must not vary. */
 , DuplicateComponentId                  = 10301 /*!< Duplicate 'id' attribute value. */
 , DuplicateUnitDefinitionId             = 10302 /*!< Duplicate unit definition 'id' attribute value. */
 , DuplicateLocalParameterId             = 10303 /*!< Duplicate local parameter 'id' attribute value. */
@@ -508,7 +511,7 @@ typedef enum
 , InvalidIdSyntax                       = 10310 /*!< Invalid syntax for an 'id' attribute value. */
 , InvalidUnitIdSyntax                   = 10311 /*!< Invalid syntax for the identifier of a unit. */
 , InvalidNameSyntax                     = 10312 /*!< Invalid syntax for a 'name' attribute value. */
-, DanglingUnitReference                 = 10313 /*!< Dangling reference to a unit. */ 
+, DanglingUnitReference                 = 10313 /*!< Dangling reference to a unit. */
 , MissingAnnotationNamespace            = 10401 /*!< Missing declaration of the XML namespace for the annotation. */
 , DuplicateAnnotationNamespaces         = 10402 /*!< Multiple annotations using the same XML namespace. */
 , SBMLNamespaceInAnnotation             = 10403 /*!< The SBML XML namespace cannot be used in an Annotation object. */
@@ -554,7 +557,8 @@ typedef enum
 , InvalidSpeciesTypeSBOTerm             = 10715 /*!< Invalid 'sboTerm' attribute value for a SpeciesType object. */
 , InvalidTriggerSBOTerm                 = 10716 /*!< Invalid 'sboTerm' attribute value for an Event Trigger object. */
 , InvalidDelaySBOTerm                   = 10717 /*!< Invalid 'sboTerm' attribute value for an Event Delay object. */
-, InvalidLocalParameterSBOTerm          = 10718 /*!< Invalid 'sboTerm' attribute value for aLocal Parameter object. */
+, InvalidLocalParameterSBOTerm          = 10718 /*!< Invalid 'sboTerm' attribute value for a LocalParameter object. */
+, InvalidSBMLElementSBOTerm             = 10719 /*!< Invalid 'sboTerm' attribute value for the <code>&lt;sbml&gt;</code> element. */
 , NotesNotInXHTMLNamespace              = 10801 /*!< Notes must be placed in the XHTML XML namespace. */
 , NotesContainsXMLDecl                  = 10802 /*!< XML declarations are not permitted in Notes objects. */
 , NotesContainsDOCTYPE                  = 10803 /*!< XML DOCTYPE elements are not permitted in Notes objects. */
@@ -606,7 +610,7 @@ typedef enum
 , RecursiveFunctionDefinition           = 20303 /*!< Recursive function definitions are not permitted. */
 , InvalidCiInLambda                     = 20304 /*!< Invalid <code>&lt;ci&gt;</code> reference found inside the <code>&lt;lambda&gt;</code> mathematical formula. */
 , InvalidFunctionDefReturnType          = 20305 /*!< A function's return type must be either a number or a Boolean. */
-, OneMathElementPerFunc                 = 20306 /*!< A FunctionDefinition object must contain one <code>&lt;math&gt;</code> element. */
+, OneMathElementPerFunc                 = 20306 /*!< A FunctionDefinition object may contain one <code>&lt;math&gt;</code> element. */
 , AllowedAttributesOnFunc               = 20307 /*!< Invalid attribute found on the FunctionDefinition object. */
 , InvalidUnitDefId                      = 20401 /*!< Invalid 'id' attribute value for a UnitDefinition object. */
 , InvalidSubstanceRedefinition          = 20402 /*!< Invalid redefinition of built-in type 'substance'. */
@@ -666,28 +670,29 @@ typedef enum
 , InvalidInitAssignSymbol               = 20801 /*!< Invalid value for the 'symbol' attribute of an InitialAssignment object. */
 , MultipleInitAssignments               = 20802 /*!< Multiple initial assignments for the same 'symbol' value are not allowed. */
 , InitAssignmentAndRuleForSameId        = 20803 /*!< Cannot set a value using both an initial assignment and an assignment rule simultaneously. */
-, OneMathElementPerInitialAssign        = 20804 /*!< An InitialAssignment object must contain one <code>&lt;math&gt;</code> element. */
+, OneMathElementPerInitialAssign        = 20804 /*!< An InitialAssignment object may contain one <code>&lt;math&gt;</code> element. */
 , AllowedAttributesOnInitialAssign      = 20805 /*!< Invalid attribute found on an InitialAssignment object. */
-, InitAssignmentCannotRef0DComp         = 20806
+, InitAssignmentCannotRef0DComp         = 20806 /*!< InitialAssignment cannot reference 0D compartment. */
 , InvalidAssignRuleVariable             = 20901 /*!< Invalid value for the 'variable' attribute of an AssignmentRule object. */
 , InvalidRateRuleVariable               = 20902 /*!< Invalid value for the 'variable' attribute of a RateRule object. */
 , AssignmentToConstantEntity            = 20903 /*!< An assignment rule cannot assign an entity declared to be constant. */
 , RateRuleForConstantEntity             = 20904 /*!< A rate rule cannot assign an entity declared to be constant. */
 , RepeatedRule10304                     = 20905
 , CircularRuleDependency                = 20906 /*!< Circular dependencies involving rules and reactions are not permitted. */
-, OneMathElementPerRule                 = 20907 /*!< A rule object must contain one <code>&lt;math&gt;</code> element. */
+, OneMathElementPerRule                 = 20907 /*!< A rule object may contain one <code>&lt;math&gt;</code> element. */
 , AllowedAttributesOnAssignRule         = 20908 /*!< Invalid attribute found on an AssignmentRule object. */
 , AllowedAttributesOnRateRule           = 20909 /*!< Invalid attribute found on a RateRule object. */
 , AllowedAttributesOnAlgRule            = 20910 /*!< Invalid attribute found on an AlgebraicRule object. */
-, RuleCannotRef0DComp                   = 20911
+, RuleCannotRef0DComp                   = 20911 /*!< Rule cannot reference 0D compartment. */
+, CircularDependencyRateOf              = 20912 /*!< Circular dependencies are not permitted in RateRule and KineticLaw objects. */
 , ConstraintMathNotBoolean              = 21001 /*!< A Constraint object's <code>&lt;math&gt;</code> must evaluate to a Boolean value. */
 , IncorrectOrderInConstraint            = 21002 /*!< Subobjects inside the Constraint object are not in the prescribed order. */
 , ConstraintNotInXHTMLNamespace         = 21003 /*!< A Constraint's Message subobject must be in the XHTML XML namespace. */
 , ConstraintContainsXMLDecl             = 21004 /*!< XML declarations are not permitted within Constraint's Message objects. */
 , ConstraintContainsDOCTYPE             = 21005 /*!< XML DOCTYPE elements are not permitted within Constraint's Message objects. */
 , InvalidConstraintContent              = 21006 /*!< Invalid content for a Constraint object's Message object. */
-, OneMathElementPerConstraint           = 21007 /*!< A Constraint object must contain one <code>&lt;math&gt;</code> element. */
-, OneMessageElementPerConstraint        = 21008 /*!< A Constraint object must contain one Message subobject. */
+, OneMathElementPerConstraint           = 21007 /*!< A Constraint object may contain one <code>&lt;math&gt;</code> element. */
+, OneMessageElementPerConstraint        = 21008 /*!< A Constraint object can only have one Message subobject. */
 , AllowedAttributesOnConstraint         = 21009 /*!< Invalid attribute found on Constraint object. */
 , NoReactantsOrProducts                 = 21101 /*!< Cannot have a reaction with neither reactants nor products. */
 , IncorrectOrderInReaction              = 21102 /*!< Subobjects inside the Reaction object are not in the prescribed order. */
@@ -716,8 +721,9 @@ typedef enum
 , AllowedAttributesOnKineticLaw         = 21132 /*!< Invalid attribute found on the KineticLaw object. */
 , AllowedAttributesOnListOfSpeciesRef   = 21150 /*!< Invalid attribute found on the ListOfSpeciesReferences object. */
 , AllowedAttributesOnListOfMods         = 21151 /*!< Invalid attribute found on the ListOfModifiers object. */
-, L3V2FastDeprecated                    = 21152 /*!< Fast deprecated. */
+, L3V2FastDeprecated                    = 21152 /*!< Fast attribute deprecated. */
 , AllowedAttributesOnLocalParameter     = 21172 /*!< Invalid attribute found on the LocalParameter object. */
+, LocalParameterShadowsSpecies          = 21173 /*!< Invalid attribute found on the LocalParameter object. */
 , MissingTriggerInEvent                 = 21201 /*!< The Event object is missing a Trigger subobject. */
 , TriggerMathNotBoolean                 = 21202 /*!< A Trigger object's <code>&lt;math&gt;</code> expression must evaluate to a Boolean value. */
 , MissingEventAssignment                = 21203 /*!< The Event object is missing an EventAssignment subobject. */
@@ -725,11 +731,11 @@ typedef enum
 , IncorrectOrderInEvent                 = 21205 /*!< Incorrect ordering of components in Event object. */
 , ValuesFromTriggerTimeNeedDelay        = 21206 /*!< Attribute 'useValuesFromTriggerTime'='false', but the Event object does not define a delay. */
 , DelayNeedsValuesFromTriggerTime       = 21207 /*!< The use of a Delay object requires the Event attribute 'useValuesFromTriggerTime'. */
-, OneMathPerTrigger                     = 21209 /*!< A Trigger object must have one <code>&lt;math&gt;</code> element. */
-, OneMathPerDelay                       = 21210 /*!< A Delay object must have one <code>&lt;math&gt;</code> element. */
+, OneMathPerTrigger                     = 21209 /*!< A Trigger object may have one <code>&lt;math&gt;</code> element. */
+, OneMathPerDelay                       = 21210 /*!< A Delay object may have one <code>&lt;math&gt;</code> element. */
 , InvalidEventAssignmentVariable        = 21211 /*!< Invalid 'variable' attribute value in Event object. */
 , EventAssignmentForConstantEntity      = 21212 /*!< An EventAssignment object cannot assign to a component having attribute 'constant'='true'. */
-, OneMathPerEventAssignment             = 21213 /*!< An EventAssignment object must have one <code>&lt;math&gt;</code> element. */
+, OneMathPerEventAssignment             = 21213 /*!< An EventAssignment object may have one <code>&lt;math&gt;</code> element. */
 , AllowedAttributesOnEventAssignment    = 21214 /*!< Invalid attribute found on the EventAssignment object. */
 , OnlyOneDelayPerEvent                  = 21221 /*!< An Event object can only have one Delay subobject. */
 , OneListOfEventAssignmentsPerEvent     = 21222 /*!< An Event object can only have one ListOfEventAssignments subobject. */
@@ -741,13 +747,13 @@ typedef enum
 , PersistentNotBoolean                  = 21228 /*!< The Trigger attribute 'persistent' must evaluate to a Boolean value. */
 , InitialValueNotBoolean                = 21229 /*!< The Trigger attribute 'initialValue' must evaluate to a Boolean value. */
 , OnlyOnePriorityPerEvent               = 21230 /*!< An Event object can only have one Priority subobject. */
-, OneMathPerPriority                    = 21231 /*!< A Priority object must have one <code>&lt;math&gt;</code> element. */
+, OneMathPerPriority                    = 21231 /*!< A Priority object may have one <code>&lt;math&gt;</code> element. */
 , AllowedAttributesOnPriority           = 21232 /*!< Invalid attribute found on the Priority object. */
 , GeneralWarningNotSpecified            = 29999 /*!< Unknown error. */
 , CompartmentShouldHaveSize             = 80501 /*!< It's best to define a size for every compartment in a model. */
 , SpeciesShouldHaveValue                = 80601 /*!< It's best to define an initial amount or initial concentration for every species in a model. */
 , ParameterShouldHaveUnits              = 80701 /*!< It's best to declare units for every parameter in a model. */
-, ParameterShouldHaveValue              = 80702 /*!< It's best to declare units for every parameter in a model. */
+, ParameterShouldHaveValue              = 80702 /*!< It's best to declare values for every parameter in a model. */
 , LocalParameterShadowsId               = 81121 /*!< Local parameters defined within a kinetic law shadow global object symbols. */
 , LibSBMLAdditionalCodesLowerBound      = 90000 /*!< Lower boundary of libSBML-specific diagnostic codes. */
 , CannotConvertToL1V1                   = 90001 /*!< Cannot convert to SBML Level 1 Version 1. */
@@ -768,7 +774,7 @@ typedef enum
 , ConversionFactorNotInL1               = 91015 /*!< SBML Level 1 does not support the 'conversionFactor' attribute. */
 , CompartmentNotOnL1Reaction            = 91016 /*!< SBML Level 1 does not support the 'compartment' attribute on Reaction objects. */
 , ExtentUnitsNotSubstance               = 91017 /*!< Units of extent must be compatible with units of substance. */
-, GlobalUnitsNotDeclared                = 91018 /*!< Global units must be refer to a predefined unit kind or a UnitDefinition. */
+, GlobalUnitsNotDeclared                = 91018 /*!< Global units must be refer to unit kind or unitDefinition. */
 , HasOnlySubstanceUnitsNotinL1          = 91019 /*!< The concept of hasOnlySubstanceUnits was not available in SBML Level 1. */
 , AvogadroNotSupported                  = 91020 /*!< Avogadro not supported in Levels 2 and 1. */
 , NoConstraintsInL2v1                   = 92001 /*!< SBML Level 2 Version 1 does not support Constraint objects. */
@@ -821,7 +827,19 @@ typedef enum
 , DuplicateAnnotationInvalidInL3v1      = 96009 /*!< Duplicate top-level annotations are invalid in SBML Level 3 Version 1. */
 , NoCompartmentOutsideInL3v1            = 96010 /*!< This Level+Version of SBML does not support the 'outside' attribute on Compartment objects. */
 , NoStoichiometryMathInL3v1             = 96011 /*!< This Level+Version of SBML does not support the StoichiometryMath object. */
+, DoubleExponentNotSupported            = 98001 /*!< Exponent of type double not supported in Levels 2 and 1. */
+, MathMLElementNotSupported             = 98002 /*!< This MathML element is only permitted in L3V2. */
+, EmptyListOfElementNotSupported        = 98003 /*!< Empty 'ListOf' element is only permitted in L3V2. */
+, MissingMathElementNotSupported        = 98004 /*!< Missing <code>&lt;math&gt;</code> element is only permitted in L3V2. */
+, MissingTriggerElementNotSupported     = 98005 /*!< missing <code>&lt;trigger&gt;</code> element is only permitted in L3V2. */
+, BooleanNumericDiscrepancy             = 98006 /*!< Interchange of Boolean and numeric values only permitted in L3V2. */
+, IdNameSBaseInL3V2                     = 98007 /*!< Conversion will lose attributes only available in L3V2 and higher. */
+, MissingParticipantsNotSupported       = 98008 /*!< Omission of both <code>&lt;listOfReactants&gt;</code> and <code>&lt;listOfProducts&gt;</code> is only valid in L3V2. */
+, ConvertibleMathInitialAssignment      = 98009 /*!< Some L3V2-specific MathML elements are not permitted in InitialAssignment objects. */
+, FastReactionsNotSupported             = 98010 /*!< Conversion of reactions employing the 'fast' attribute is not supported. */
+, SpeciesRefIdInMathMLNotSupported      = 98011 /*!< This MathML element is only permitted in L3V2. */
 , InvalidSBMLLevelVersion               = 99101 /*!< Unknown Level+Version combination of SBML. */
+, InvalidPackageLevelVersion            = 99102 /*!< Invalid package Level+Version combination of SBML. */
 , AnnotationNotesNotAllowedLevel1       = 99104 /*!< Annotation objects on the SBML container element are not permitted in SBML Level 1. */
 , InvalidRuleOrdering                   = 99106 /*!< Invalid ordering of rules. */
 , RequiredPackagePresent                = 99107 /*!< The SBML document requires an SBML Level 3 package unavailable in this software. */
@@ -831,6 +849,7 @@ typedef enum
 , TimeUnitsAllowedInKL                  = 99128 /*!< Disallowed value for attribute 'timeUnits' on KineticLaw object. */
 , FormulaInLevel1KL                     = 99129 /*!< Only predefined functions are allowed in SBML Level 1 formulas. */
 , L3SubstanceUnitsOnModel               = 99130 /*!< Invalid 'substanceUnits' attribute value. */
+, StoichiometryMathMissingMath          = 99131 /*!< The <code>&lt;stoichiometryMath&gt;</code> element must contain a <code>&lt;math&gt;</code> element. */
 , TimeUnitsRemoved                      = 99206 /*!< This Level+Version of SBML does not support the 'timeUnits' attribute on Event objects. */
 , BadMathML                             = 99219 /*!< Invalid MathML expression. */
 , FailedMathMLReadOfDouble              = 99220 /*!< Missing or invalid floating-point number in MathML expression. */
@@ -856,6 +875,7 @@ typedef enum
 , UndeclaredTimeUnitsL3                 = 99506 /*!< Unable to verify consistency of units: the unit of time has not been declared. */
 , UndeclaredExtentUnitsL3               = 99507 /*!< Unable to verify consistency of units: the units of reaction extent have not been declared. */
 , UndeclaredObjectUnitsL3               = 99508 /*!< Unable to verify consistency of units: encountered a model entity with no declared units. */
+, CannotVerifyUnitsObjectNoMath         = 99509 /*!< Unable to verify consistency of units: encountered an object with no <code>&lt;math&gt;</code> element. */
 , UnrecognisedSBOTerm                   = 99701 /*!< Unrecognized 'sboTerm' attribute value. */
 , ObseleteSBOTerm                       = 99702 /*!< Obsolete 'sboTerm' attribute value. */
 , IncorrectCompartmentSpatialDimensions = 99901 /*!< In SBML Level 1, only three-dimensional compartments are allowed. */
@@ -932,21 +952,21 @@ typedef enum
      * constructs.  With respect to the SBML specification, these concern
      * failures in applying the validation rules numbered 2xxxx in the
      * Level&nbsp;2 Versions&nbsp;2&ndash;4
-     * and Level&nbsp;3 Version&nbsp;1 specifications. */
+     * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications. */
 
   , LIBSBML_CAT_IDENTIFIER_CONSISTENCY
     /*!< Category of errors that can occur while validating symbol
      * identifiers in a model.  With respect to the SBML specification,
      * these concern failures in applying the validation rules numbered
      * 103xx in the Level&nbsp;2 Versions&nbsp;2&ndash;4
-     * and Level&nbsp;3 Version&nbsp;1 specifications. */
+     * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications. */
 
   , LIBSBML_CAT_UNITS_CONSISTENCY
     /*!< Category of errors that can occur while validating the units of
      * measurement on quantities in a model.  With respect to the SBML
      * specification, these concern failures in applying the validation
      * rules numbered 105xx in the Level&nbsp;2 Versions&nbsp;2&ndash;4
-     * and Level&nbsp;3 Version&nbsp;1
+     * and Level&nbsp;3 Versions&nbsp;1&ndash;2
      * specifications. */
 
   , LIBSBML_CAT_MATHML_CONSISTENCY
@@ -954,21 +974,21 @@ typedef enum
      * in a model.  With respect to the SBML specification, these concern
      * failures in applying the validation rules numbered 102xx in the
      * Level&nbsp;2 Versions&nbsp;2&ndash;4
-     * and Level&nbsp;3 Version&nbsp;1 specifications. */
+     * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications. */
 
   , LIBSBML_CAT_SBO_CONSISTENCY
     /*!< Category of errors that can occur while validating SBO identifiers
      * in a model.  With respect to the SBML specification, these concern
      * failures in applying the validation rules numbered 107xx in the
      * Level&nbsp;2 Versions&nbsp;2&ndash;4
-     * and Level&nbsp;3 Version&nbsp;1 specifications. */
+     * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications. */
 
   , LIBSBML_CAT_OVERDETERMINED_MODEL
     /*!< Error in the system of equations in the model: the system is
      * overdetermined, therefore violating a tenet of proper SBML.  With
      * respect to the SBML specification, this is validation rule #10601 in
      * the SBML Level&nbsp;2 Versions&nbsp;2&ndash;4
-     * and Level&nbsp;3 Version&nbsp;1 specifications. */
+     * and Level&nbsp;3 Versions&nbsp;1&ndash;2 specifications. */
 
   , LIBSBML_CAT_SBML_L2V3_COMPAT
     /*!< Category of errors that can only occur during attempted
@@ -999,6 +1019,16 @@ typedef enum
      * particular category applies to errors encountered while trying to
      * convert a model to SBML Level&nbsp;3 Version&nbsp;1. */
 
+  , LIBSBML_CAT_SBML_L3V2_COMPAT
+    /*!< Category of errors that can only occur during attempted
+     * translation from one Level/Version of SBML to another.  This
+     * particular category applies to errors encountered while trying to
+     * convert a model to SBML Level&nbsp;3 Version&nbsp;1. */
+
+  , LIBSBML_CAT_SBML_COMPATIBILITY
+    /*!< Category of errors that can only occur during attempted
+     * translation from one Level/Version of SBML to another. */
+
 } SBMLErrorCategory_t;
 
 
@@ -1136,9 +1166,9 @@ public:
    *
    * @param errorId an unsigned int, the identification number of the error.
    *
-   * @param level the SBML Level of the SBML model
+   * @param level the SBML Level of the SBML model.
    *
-   * @param version the SBML Version within the Level of the SBML model
+   * @param version the SBML Version within the Level of the SBML model.
    *
    * @param details a string containing additional details about the error.
    * If the error code in @p errorId is one that is recognized by SBMLError,
@@ -1178,6 +1208,8 @@ public:
 
   /**
    * Copy constructor; creates a copy of this SBMLError.
+   *
+   * @param orig the instance to copy.
    */
   SBMLError(const SBMLError& orig);
 
