@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -366,7 +366,7 @@ Species::getUnits () const
 
 
 /*
- * @return true if this Species hasOnlySubstanceUnits, false otherwise.
+ * @return @c true if this Species hasOnlySubstanceUnits, false otherwise.
  */
 bool
 Species::getHasOnlySubstanceUnits () const
@@ -376,7 +376,7 @@ Species::getHasOnlySubstanceUnits () const
 
 
 /*
- * @return true if this Species has boundaryCondition
+ * @return @c true if this Species has boundaryCondition
  * true, false otherwise.
  */
 bool
@@ -397,7 +397,7 @@ Species::getCharge () const
 
 
 /*
- * @return true if this Species is constant, false otherwise.
+ * @return @c true if this Species is constant, false otherwise.
  */
 bool
 Species::getConstant () const
@@ -417,7 +417,7 @@ Species::getConversionFactor () const
 
 
 /*
- * @return true if the id of this SBML object has been set, false
+ * @return @c true if the id of this SBML object has been set, false
  * otherwise.
  */
 bool
@@ -428,7 +428,7 @@ Species::isSetId () const
 
 
 /*
- * @return true if the name of this SBML object is set, false
+ * @return @c true if the name of this SBML object is set, false
  * otherwise.
  */
 bool
@@ -440,7 +440,7 @@ Species::isSetName () const
 
 
 /*
- * @return true if the speciesType of this Species is set, false
+ * @return @c true if the speciesType of this Species is set, false
  * otherwise.
  */
 bool
@@ -451,7 +451,7 @@ Species::isSetSpeciesType () const
 
 
 /*
- * @return true if the compartment of this Species is set, false
+ * @return @c true if the compartment of this Species is set, false
  * otherwise.
  */
 bool
@@ -462,7 +462,7 @@ Species::isSetCompartment () const
 
 
 /*
- * @return true if the initialAmount of this Species is set, false
+ * @return @c true if the initialAmount of this Species is set, false
  * otherwise.
  *
  * In SBML L1, a Species initialAmount is required and therefore <b>should
@@ -477,7 +477,7 @@ Species::isSetInitialAmount () const
 
 
 /*
- * @return true if the initialConcentration of this Species is set,
+ * @return @c true if the initialConcentration of this Species is set,
  * false otherwise.
  */
 bool
@@ -488,7 +488,7 @@ Species::isSetInitialConcentration () const
 
 
 /*
- * @return true if the substanceUnits of this Species is set, false
+ * @return @c true if the substanceUnits of this Species is set, false
  * otherwise.
  */
 bool
@@ -499,7 +499,7 @@ Species::isSetSubstanceUnits () const
 
 
 /*
- * @return true if the spatialSizeUnits of this Species is set, false
+ * @return @c true if the spatialSizeUnits of this Species is set, false
  * otherwise.
  */
 bool
@@ -510,7 +510,7 @@ Species::isSetSpatialSizeUnits () const
 
 
 /*
- * @return true if the units of this Species is set, false otherwise
+ * @return @c true if the units of this Species is set, false otherwise
  * (L1 only).
  */
 bool
@@ -521,7 +521,7 @@ Species::isSetUnits () const
 
 
 /*
- * @return true if the charge of this Species is set, false
+ * @return @c true if the charge of this Species is set, false
  * otherwise.
  */
 bool
@@ -532,7 +532,7 @@ Species::isSetCharge () const
 
 
 /*
- * @return true if the conversionFactor of this Species is set, false
+ * @return @c true if the conversionFactor of this Species is set, false
  * otherwise.
  */
 bool
@@ -1167,10 +1167,10 @@ Species::getDerivedUnitDefinition()
       m->populateListFormulaUnitsData();
     }
     
-    if (m->getFormulaUnitsData(getId(), getTypeCode()) != NULL)
+    FormulaUnitsData *fud = m->getFormulaUnitsData(getId(), getTypeCode());
+    if (fud != NULL)
     {
-      return m->getFormulaUnitsData(getId(), getTypeCode())
-                                             ->getUnitDefinition();
+      return fud->getUnitDefinition();
     }
     else
     {
@@ -1438,51 +1438,51 @@ Species::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this Species.
  */
-int
-Species::getAttribute(const std::string& attributeName,
-                      const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "compartment")
-  {
-    value = getCompartment().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "substanceUnits")
-  {
-    value = getSubstanceUnits().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "conversionFactor")
-  {
-    value = getConversionFactor().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "speciesType")
-  {
-    value = getSpeciesType().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "spatialSizeUnits")
-  {
-    value = getSpatialSizeUnits().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "units")
-  {
-    value = getUnits().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
+//int
+//Species::getAttribute(const std::string& attributeName,
+//                      const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  if (return_value == LIBSBML_OPERATION_SUCCESS)
+//  {
+//    return return_value;
+//  }
+//
+//  if (attributeName == "compartment")
+//  {
+//    value = getCompartment().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//  else if (attributeName == "substanceUnits")
+//  {
+//    value = getSubstanceUnits().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//  else if (attributeName == "conversionFactor")
+//  {
+//    value = getConversionFactor().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//  else if (attributeName == "speciesType")
+//  {
+//    value = getSpeciesType().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//  else if (attributeName == "spatialSizeUnits")
+//  {
+//    value = getSpatialSizeUnits().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//  else if (attributeName == "units")
+//  {
+//    value = getUnits().c_str();
+//    return_value = LIBSBML_OPERATION_SUCCESS;
+//  }
+//
+//  return return_value;
+//}
+//
 /** @endcond */
 
 
@@ -1697,39 +1697,39 @@ Species::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this Species.
  */
-int
-Species::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "compartment")
-  {
-    return_value = setCompartment(value);
-  }
-  else if (attributeName == "substanceUnits")
-  {
-    return_value = setSubstanceUnits(value);
-  }
-  else if (attributeName == "conversionFactor")
-  {
-    return_value = setConversionFactor(value);
-  }
-  else if (attributeName == "speciesType")
-  {
-    return_value = setSpeciesType(value);
-  }
-  else if (attributeName == "spatialSizeUnits")
-  {
-    return_value = setSpatialSizeUnits(value);
-  }
-  else if (attributeName == "units")
-  {
-    return_value = setUnits(value);
-  }
-
-  return return_value;
-}
-
+//int
+//Species::setAttribute(const std::string& attributeName, const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  if (attributeName == "compartment")
+//  {
+//    return_value = setCompartment(value);
+//  }
+//  else if (attributeName == "substanceUnits")
+//  {
+//    return_value = setSubstanceUnits(value);
+//  }
+//  else if (attributeName == "conversionFactor")
+//  {
+//    return_value = setConversionFactor(value);
+//  }
+//  else if (attributeName == "speciesType")
+//  {
+//    return_value = setSpeciesType(value);
+//  }
+//  else if (attributeName == "spatialSizeUnits")
+//  {
+//    return_value = setSpatialSizeUnits(value);
+//  }
+//  else if (attributeName == "units")
+//  {
+//    return_value = setUnits(value);
+//  }
+//
+//  return return_value;
+//}
+//
 /** @endcond */
 
 
