@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -197,7 +197,7 @@ Trigger::getPersistent () const
 
 
 /*
- * @return true if the math (or equivalently the formula) of this
+ * @return @c true if the math (or equivalently the formula) of this
  * Trigger is set, false otherwise.
  */
 bool
@@ -209,7 +209,7 @@ Trigger::isSetMath () const
 
 
 /*
- * @return true if initialValue is set of this Trigger.
+ * @return @c true if initialValue is set of this Trigger.
  */
 bool
 Trigger::isSetInitialValue () const
@@ -219,7 +219,7 @@ Trigger::isSetInitialValue () const
 
 
 /*
- * @return true if persistent is set of this Trigger.
+ * @return @c true if persistent is set of this Trigger.
  */
 bool
 Trigger::isSetPersistent () const
@@ -514,14 +514,14 @@ Trigger::getAttribute(const std::string& attributeName,
 /*
  * Gets the value of the "attributeName" attribute of this Trigger.
  */
-int
-Trigger::getAttribute(const std::string& attributeName,
-                      const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  return return_value;
-}
+//int
+//Trigger::getAttribute(const std::string& attributeName,
+//                      const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -654,13 +654,13 @@ Trigger::setAttribute(const std::string& attributeName,
 /*
  * Sets the value of the "attributeName" attribute of this Trigger.
  */
-int
-Trigger::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  return return_value;
-}
+//int
+//Trigger::setAttribute(const std::string& attributeName, const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -739,8 +739,8 @@ Trigger::replaceSIDWithFunction(const std::string& id, const ASTNode* function)
 
 /** @cond doxygenLibsbmlInternal */
 /*
-* Function to set/get an identifier for unit checking
-*/
+ * Function to set/get an identifier for unit checking
+ */
 std::string 
 Trigger::getInternalId() const
 { 
@@ -763,7 +763,7 @@ Trigger::setInternalId(std::string id)
  * Subclasses should override this method to read (and store) XHTML,
  * MathML, etc. directly from the XMLInputStream.
  *
- * @return true if the subclass read from the stream, false otherwise.
+ * @return @c true if the subclass read from the stream, false otherwise.
  */
 bool
 Trigger::readOtherXML (XMLInputStream& stream)
