@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -330,7 +330,7 @@ Unit::getOffset () const
 
 
 /*
- * @return true if the kind of this Unit is 'ampere', false otherwise.
+ * @return @c true if the kind of this Unit is 'ampere', false otherwise.
  */
 bool
 Unit::isAmpere () const
@@ -340,7 +340,7 @@ Unit::isAmpere () const
 
 
 /*
- * @return true if the kind of this Unit is 'avogadro', false otherwise.
+ * @return @c true if the kind of this Unit is 'avogadro', false otherwise.
  */
 bool
 Unit::isAvogadro () const
@@ -350,7 +350,7 @@ Unit::isAvogadro () const
 
 
 /*
- * @return true if the kind of this Unit is 'becquerel', false otherwise.
+ * @return @c true if the kind of this Unit is 'becquerel', false otherwise.
  */
 bool
 Unit::isBecquerel () const
@@ -360,7 +360,7 @@ Unit::isBecquerel () const
 
 
 /*
- * @return true if the kind of this Unit is 'candela', false otherwise.
+ * @return @c true if the kind of this Unit is 'candela', false otherwise.
  */
 bool
 Unit::isCandela () const
@@ -370,7 +370,7 @@ Unit::isCandela () const
 
 
 /*
- * @return true if the kind of this Unit is 'Celsius', false otherwise.
+ * @return @c true if the kind of this Unit is 'Celsius', false otherwise.
  */
 bool
 Unit::isCelsius () const
@@ -380,7 +380,7 @@ Unit::isCelsius () const
 
 
 /*
- * @return true if the kind of this Unit is 'coulomb', false otherwise.
+ * @return @c true if the kind of this Unit is 'coulomb', false otherwise.
  */
 bool
 Unit::isCoulomb () const
@@ -390,7 +390,7 @@ Unit::isCoulomb () const
 
 
 /*
- * @return true if the kind of this Unit is 'dimensionless', false
+ * @return @c true if the kind of this Unit is 'dimensionless', false
  * otherwise.
  */
 bool
@@ -401,7 +401,7 @@ Unit::isDimensionless () const
 
 
 /*
- * @return true if the kind of this Unit is 'farad', false otherwise.
+ * @return @c true if the kind of this Unit is 'farad', false otherwise.
  */
 bool
 Unit::isFarad () const
@@ -411,7 +411,7 @@ Unit::isFarad () const
 
 
 /*
- * @return true if the kind of this Unit is 'gram', false otherwise.
+ * @return @c true if the kind of this Unit is 'gram', false otherwise.
  */
 bool
 Unit::isGram () const
@@ -421,7 +421,7 @@ Unit::isGram () const
 
 
 /*
- * @return true if the kind of this Unit is 'gray', false otherwise.
+ * @return @c true if the kind of this Unit is 'gray', false otherwise.
  */
 bool
 Unit::isGray () const
@@ -431,7 +431,7 @@ Unit::isGray () const
 
 
 /*
- * @return true if the kind of this Unit is 'henry', false otherwise.
+ * @return @c true if the kind of this Unit is 'henry', false otherwise.
  */
 bool
 Unit::isHenry () const
@@ -441,7 +441,7 @@ Unit::isHenry () const
 
 
 /*
- * @return true if the kind of this Unit is 'hertz', false otherwise.
+ * @return @c true if the kind of this Unit is 'hertz', false otherwise.
  */
 bool
 Unit::isHertz () const
@@ -451,7 +451,7 @@ Unit::isHertz () const
 
 
 /*
- * @return true if the kind of this Unit is 'item', false otherwise.
+ * @return @c true if the kind of this Unit is 'item', false otherwise.
  */
 bool
 Unit::isItem () const
@@ -461,7 +461,7 @@ Unit::isItem () const
 
 
 /*
- * @return true if the kind of this Unit is 'joule', false otherwise.
+ * @return @c true if the kind of this Unit is 'joule', false otherwise.
  */
 bool
 Unit::isJoule () const
@@ -471,7 +471,7 @@ Unit::isJoule () const
 
 
 /*
- * @return true if the kind of this Unit is 'katal', false otherwise.
+ * @return @c true if the kind of this Unit is 'katal', false otherwise.
  */
 bool
 Unit::isKatal () const
@@ -481,7 +481,7 @@ Unit::isKatal () const
 
 
 /*
- * @return true if the kind of this Unit is 'kelvin', false otherwise.
+ * @return @c true if the kind of this Unit is 'kelvin', false otherwise.
  */
 bool
 Unit::isKelvin () const
@@ -491,7 +491,7 @@ Unit::isKelvin () const
 
 
 /*
- * @return true if the kind of this Unit is 'kilogram', false otherwise.
+ * @return @c true if the kind of this Unit is 'kilogram', false otherwise.
  */
 bool
 Unit::isKilogram () const
@@ -501,7 +501,7 @@ Unit::isKilogram () const
 
 
 /*
- * @return true if the kind of this Unit is 'litre' or 'liter', false
+ * @return @c true if the kind of this Unit is 'litre' or 'liter', false
  * otherwise.
  */
 bool
@@ -519,7 +519,7 @@ Unit::isLitre () const
 
 
 /*
- * @return true if the kind of this Unit is 'lumen', false otherwise.
+ * @return @c true if the kind of this Unit is 'lumen', false otherwise.
  */
 bool
 Unit::isLumen () const
@@ -529,7 +529,7 @@ Unit::isLumen () const
 
 
 /*
- * @return true if the kind of this Unit is 'lux', false otherwise.
+ * @return @c true if the kind of this Unit is 'lux', false otherwise.
  */
 bool
 Unit::isLux () const
@@ -539,7 +539,7 @@ Unit::isLux () const
 
 
 /*
- * @return true if the kind of this Unit is 'metre' or 'meter', false
+ * @return @c true if the kind of this Unit is 'metre' or 'meter', false
  * otherwise.
  */
 bool
@@ -557,7 +557,7 @@ Unit::isMetre () const
 
 
 /*
- * @return true if the kind of this Unit is 'mole', false otherwise.
+ * @return @c true if the kind of this Unit is 'mole', false otherwise.
  */
 bool
 Unit::isMole () const
@@ -567,7 +567,7 @@ Unit::isMole () const
 
 
 /*
- * @return true if the kind of this Unit is 'newton', false otherwise.
+ * @return @c true if the kind of this Unit is 'newton', false otherwise.
  */
 bool
 Unit::isNewton () const
@@ -577,7 +577,7 @@ Unit::isNewton () const
 
 
 /*
- * @return true if the kind of this Unit is 'ohm', false otherwise.
+ * @return @c true if the kind of this Unit is 'ohm', false otherwise.
  */
 bool
 Unit::isOhm () const
@@ -587,7 +587,7 @@ Unit::isOhm () const
 
 
 /*
- * @return true if the kind of this Unit is 'pascal', false otherwise.
+ * @return @c true if the kind of this Unit is 'pascal', false otherwise.
  */
 bool
 Unit::isPascal () const
@@ -597,7 +597,7 @@ Unit::isPascal () const
 
 
 /*
- * @return true if the kind of this Unit is 'radian', false otherwise.
+ * @return @c true if the kind of this Unit is 'radian', false otherwise.
  */
 bool
 Unit::isRadian () const
@@ -607,7 +607,7 @@ Unit::isRadian () const
 
 
 /*
- * @return true if the kind of this Unit is 'second', false otherwise.
+ * @return @c true if the kind of this Unit is 'second', false otherwise.
  */
 bool
 Unit::isSecond () const
@@ -617,7 +617,7 @@ Unit::isSecond () const
 
 
 /*
- * @return true if the kind of this Unit is 'siemens', false otherwise.
+ * @return @c true if the kind of this Unit is 'siemens', false otherwise.
  */
 bool
 Unit::isSiemens () const
@@ -627,7 +627,7 @@ Unit::isSiemens () const
 
 
 /*
- * @return true if the kind of this Unit is 'sievert', false otherwise.
+ * @return @c true if the kind of this Unit is 'sievert', false otherwise.
  */
 bool
 Unit::isSievert () const
@@ -637,7 +637,7 @@ Unit::isSievert () const
 
 
 /*
- * @return true if the kind of this Unit is 'steradian', false otherwise.
+ * @return @c true if the kind of this Unit is 'steradian', false otherwise.
  */
 bool
 Unit::isSteradian () const
@@ -647,7 +647,7 @@ Unit::isSteradian () const
 
 
 /*
- * @return true if the kind of this Unit is 'tesla', false otherwise.
+ * @return @c true if the kind of this Unit is 'tesla', false otherwise.
  */
 bool
 Unit::isTesla () const
@@ -657,7 +657,7 @@ Unit::isTesla () const
 
 
 /*
- * @return true if the kind of this Unit is 'volt', false otherwise.
+ * @return @c true if the kind of this Unit is 'volt', false otherwise.
  */
 bool
 Unit::isVolt () const
@@ -667,7 +667,7 @@ Unit::isVolt () const
 
 
 /*
- * @return true if the kind of this Unit is 'watt', false otherwise.
+ * @return @c true if the kind of this Unit is 'watt', false otherwise.
  */
 bool
 Unit::isWatt () const
@@ -677,7 +677,7 @@ Unit::isWatt () const
 
 
 /*
- * @return true if the kind of this Unit is 'weber', false otherwise.
+ * @return @c true if the kind of this Unit is 'weber', false otherwise.
  */
 bool
 Unit::isWeber () const
@@ -687,7 +687,7 @@ Unit::isWeber () const
 
 
 /*
- * @return true if the kind of this Unit is set, false otherwise.
+ * @return @c true if the kind of this Unit is set, false otherwise.
  */
 bool
 Unit::isSetKind () const
@@ -1149,17 +1149,17 @@ Unit::getAttribute(const std::string& attributeName, std::string& value) const
 /*
  * Gets the value of the "attributeName" attribute of this Unit.
  */
-int
-Unit::getAttribute(const std::string& attributeName, const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (attributeName == "kind")
-  {
-    value = UnitKind_toString(getKind());
-  }
-  return return_value;
-}
+//int
+//Unit::getAttribute(const std::string& attributeName, const char* value) const
+//{
+//  int return_value = SBase::getAttribute(attributeName, value);
+//
+//  if (attributeName == "kind")
+//  {
+//    value = UnitKind_toString(getKind());
+//  }
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -1323,13 +1323,13 @@ Unit::setAttribute(const std::string& attributeName, const std::string& value)
 /*
  * Sets the value of the "attributeName" attribute of this Unit.
  */
-int
-Unit::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  return return_value;
-}
+//int
+//Unit::setAttribute(const std::string& attributeName, const char* value)
+//{
+//  int return_value = SBase::setAttribute(attributeName, value);
+//
+//  return return_value;
+//}
 
 /** @endcond */
 
@@ -1375,7 +1375,7 @@ Unit::unsetAttribute(const std::string& attributeName)
 
 
 /*
- * @return true if name is one of the five SBML built-in Unit names
+ * @return @c true if name is one of the five SBML built-in Unit names
  * ('substance', 'volume', 'area', 'length' or 'time'), false otherwise.
  */
 bool
@@ -1429,7 +1429,7 @@ Unit::isUnitKind(const std::string &name, unsigned int level,
 
 /** @cond doxygenLibsbmlInternal */
 /*
- * @return true if name is a valid UnitKind.
+ * @return @c true if name is a valid UnitKind.
  */
 bool
 Unit::isL1UnitKind (const std::string& name)
@@ -1581,20 +1581,35 @@ Unit::merge(Unit * unit1, Unit * unit2)
 
   newExponent = unit1->getExponentAsDouble() + unit2->getExponentAsDouble();
 
+  // if we are merging units where 1 exponent was zero 
+  // but we had a multiplier that was not 1
+  // need to preserve that multiplier
+  double unit1Multi = pow(unit1->getMultiplier(), unit1->getExponentAsDouble());
+  if (util_isEqual(unit1->getExponentAsDouble(), 0.0)
+    && (!util_isEqual(unit1->getMultiplier(), 1.0)))
+  {
+    unit1Multi = unit1->getMultiplier();
+  }
+
+  double unit2Multi = pow(unit2->getMultiplier(), unit2->getExponentAsDouble());
+  if (util_isEqual(unit2->getExponentAsDouble(), 0.0)
+    && (!util_isEqual(unit2->getMultiplier(), 1.0)))
+  {
+    unit2Multi = unit2->getMultiplier();
+  }
+
   if (newExponent == 0)
   {
     // actually we do not want the new multiplier to be 1
     // there may be a scaling factor in the now dimensionless unit that
     // needs to propogate thru a units calculation
     // newMultiplier = 1;
-    newMultiplier = pow(unit1->getMultiplier(), unit1->getExponentAsDouble())*
-      pow(unit2->getMultiplier(), unit2->getExponentAsDouble());
+
+    newMultiplier = unit1Multi * unit2Multi;
   }
   else
   {
-    newMultiplier = pow(pow(unit1->getMultiplier(), unit1->getExponentAsDouble())*
-      pow(unit2->getMultiplier(), unit2->getExponentAsDouble()), 
-                                                  1/(double)(newExponent));
+    newMultiplier = pow(unit1Multi * unit2Multi, 1/(double)(newExponent));
   }
     
   /* hack to force multiplier to be double precision */
@@ -2083,7 +2098,7 @@ Unit::convertToSI(const Unit * unit)
 
 /** @cond doxygenLibsbmlInternal */
 /*
- * @return true if name is a valid UnitKind.
+ * @return @c true if name is a valid UnitKind.
  */
 bool
 Unit::isL2V1UnitKind (const std::string& name)
@@ -2100,7 +2115,7 @@ Unit::isL2V1UnitKind (const std::string& name)
 
 /** @cond doxygenLibsbmlInternal */
 /*
- * @return true if name is a valid UnitKind.
+ * @return @c true if name is a valid UnitKind.
  */
 bool
 Unit::isL2UnitKind (const std::string& name)
@@ -2119,7 +2134,7 @@ Unit::isL2UnitKind (const std::string& name)
 
 /** @cond doxygenLibsbmlInternal */
 /*
- * @return true if name is a valid UnitKind.
+ * @return @c true if name is a valid UnitKind.
  */
 bool
 Unit::isL3UnitKind (const std::string& name)
