@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1228,8 +1228,8 @@ public:
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
-  virtual int getAttribute(const std::string& attributeName,
-                           const char* value) const;
+  //virtual int getAttribute(const std::string& attributeName,
+  //                         const char* value) const;
 
   /** @endcond */
 
@@ -1362,8 +1362,8 @@ public:
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
-  virtual int setAttribute(const std::string& attributeName, const char*
-    value);
+  //virtual int setAttribute(const std::string& attributeName, const char*
+  //  value);
 
   /** @endcond */
 
@@ -1389,11 +1389,9 @@ public:
 
   #endif /* !SWIG */
 
-
-protected:
   /** @cond doxygenLibsbmlInternal */
-  void setExponentUnitChecking (double value); 
-                                           
+  void setExponentUnitChecking(double value);
+
   double getExponentUnitChecking();
 
   double getExponentUnitChecking() const;
@@ -1402,6 +1400,11 @@ protected:
 
   bool isUnitChecking() const;
 
+  /** @endcond */
+
+
+protected:
+  /** @cond doxygenLibsbmlInternal */
   /**
    * Subclasses should override this method to get the list of
    * expected attributes.
@@ -1526,6 +1529,7 @@ protected:
   friend class UnitConsistencyValidator;
   friend class UnitFormulaFormatter;
   friend class UnitDefinition;
+  friend class ASTBasePlugin;
 
 
   /** @endcond */
@@ -1610,6 +1614,7 @@ public:
    * @param n the index number of the Unit to get.
    * 
    * @return the nth Unit in this ListOfUnits.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
@@ -1622,6 +1627,7 @@ public:
    * @param n the index number of the Unit to get.
    * 
    * @return the nth Unit in this ListOfUnits.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
