@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -602,6 +602,7 @@ public:
    * @param n an integer, the index of the Unit to be returned.
    * 
    * @return the nth Unit of this UnitDefinition.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see getNumUnits()
    */
@@ -614,6 +615,7 @@ public:
    * @param n an integer, the index of the Unit to be returned.
    * 
    * @return the nth Unit of this UnitDefinition.
+   * If the index @p n is invalid, @c NULL is returned.
    */
   const Unit* getUnit (unsigned int n) const;
 
@@ -684,6 +686,14 @@ public:
   /** @endcond */
 
 
+  /** @cond doxygenLibsbmlInternal */
+
+  virtual void updateSBMLNamespace(const std::string& package,
+    unsigned int level, unsigned int version);
+
+  /** @endcond */
+
+
   /**
    * Returns the libSBML type code for this object instance.
    * 
@@ -1049,8 +1059,8 @@ public:
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
-  virtual int getAttribute(const std::string& attributeName,
-                           const char* value) const;
+  //virtual int getAttribute(const std::string& attributeName,
+  //                         const char* value) const;
 
   /** @endcond */
 
@@ -1183,8 +1193,8 @@ public:
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
-  virtual int setAttribute(const std::string& attributeName, const char*
-    value);
+  //virtual int setAttribute(const std::string& attributeName, const char*
+  //  value);
 
   /** @endcond */
 
@@ -1440,6 +1450,7 @@ public:
    * @param n the index number of the UnitDefinition to get.
    * 
    * @return the nth UnitDefinition in this ListOfUnitDefinitions.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
@@ -1452,6 +1463,7 @@ public:
    * @param n the index number of the UnitDefinition to get.
    * 
    * @return the nth UnitDefinition in this ListOfUnitDefinitions.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
@@ -1979,6 +1991,7 @@ UnitDefinition_getListOfUnits (UnitDefinition_t *ud);
  * @param n an integer, the index of the Unit_t structure to be returned.
  * 
  * @return the nth Unit_t of this UnitDefinition_t structure.
+ * If the index @p n is invalid, @c NULL is returned.
  *
  * @see UnitDefinition_getNumUnits()
  *
