@@ -1,35 +1,35 @@
 /**
-* @file    SBMLIdConverter.cpp
-* @brief   Implementation of SBMLIdConverter, a converter renaming SIds
-* @author  Frank Bergmann 
-* 
-* <!--------------------------------------------------------------------------
-* This file is part of libSBML.  Please visit http://sbml.org for more
-* information about SBML, and the latest version of libSBML.
-*
-* Copyright (C) 2013-2017 jointly by the following organizations:
-*     1. California Institute of Technology, Pasadena, CA, USA
-*     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
-*     3. University of Heidelberg, Heidelberg, Germany
-*
-* Copyright (C) 2009-2013 jointly by the following organizations: 
-*     1. California Institute of Technology, Pasadena, CA, USA
-*     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
-*  
-* Copyright (C) 2006-2008 by the California Institute of Technology,
-*     Pasadena, CA, USA 
-*  
-* Copyright (C) 2002-2005 jointly by the following organizations: 
-*     1. California Institute of Technology, Pasadena, CA, USA
-*     2. Japan Science and Technology Agency, Japan
-* 
-* This library is free software; you can redistribute it and/or modify it
-* under the terms of the GNU Lesser General Public License as published by
-* the Free Software Foundation.  A copy of the license agreement is provided
-* in the file named "LICENSE.txt" included with this software distribution
-* and also available online as http://sbml.org/software/libsbml/license.html
-* ------------------------------------------------------------------------ -->
-*/
+ * @file    SBMLIdConverter.cpp
+ * @brief   Implementation of SBMLIdConverter, a converter renaming SIds
+ * @author  Frank Bergmann 
+ * 
+ * <!--------------------------------------------------------------------------
+ * This file is part of libSBML.  Please visit http://sbml.org for more
+ * information about SBML, and the latest version of libSBML.
+ *
+ * Copyright (C) 2013-2018 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
+ * Copyright (C) 2009-2013 jointly by the following organizations: 
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *  
+ * Copyright (C) 2006-2008 by the California Institute of Technology,
+ *     Pasadena, CA, USA 
+ *  
+ * Copyright (C) 2002-2005 jointly by the following organizations: 
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. Japan Science and Technology Agency, Japan
+ * 
+ * This library is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation.  A copy of the license agreement is provided
+ * in the file named "LICENSE.txt" included with this software distribution
+ * and also available online as http://sbml.org/software/libsbml/license.html
+ * ------------------------------------------------------------------------ -->
+ */
 
 
 #include <sbml/conversion/SBMLIdConverter.h>
@@ -141,9 +141,9 @@ SBMLIdConverter::convert()
   std::map<std::string, std::string> renamed;
   
   // rename ids 
-  for (unsigned int i = 0; i < allElements->getSize(); ++i)
+  for (ListIterator iter = allElements->begin(); iter != allElements->end(); ++iter)
   {
-    SBase* current = static_cast<SBase*>(allElements->get(i));
+    SBase* current = static_cast<SBase*>(*iter);
     if (current == NULL || !current->isSetId() 
       || current->getTypeCode() == SBML_LOCAL_PARAMETER)
       continue;	 
@@ -168,9 +168,9 @@ SBMLIdConverter::convert()
 
   // update all references that we changed
   std::map<std::string, std::string>::const_iterator it;
-  for (unsigned int i = 0; i < allElements->getSize(); ++i)
+  for (ListIterator iter = allElements->begin(); iter != allElements->end(); ++iter)
   {
-	  SBase* current = static_cast<SBase*>(allElements->get(i));
+    SBase* current = static_cast<SBase*>(*iter);
 	  for (it = renamed.begin(); it != renamed.end(); ++it)
 	  {
 	    current->renameSIdRefs(it->first, it->second);
