@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -276,6 +276,8 @@ private:
    */
   bool performConversion(bool strict, bool strictUnits, bool duplicateAnn);
 
+  void updatePackages(unsigned int targetVersion);
+
   unsigned int validateConvertedDocument();
 
   bool has_fatal_errors(unsigned int level, unsigned int version);
@@ -293,20 +295,6 @@ private:
   /** @endcond */
 };
 
-/** @cond doxygenLibsbmlInternal */
-class LIBSBML_EXTERN MathFilter : public ElementFilter
-{
-public:
-  MathFilter();
-
-  virtual ~MathFilter();
-
-  virtual bool filter(const SBase* element);
-};
-
-
-/** @endcond */
-
 
 LIBSBML_CPP_NAMESPACE_END
 
