@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -69,9 +69,6 @@ SBMLExtensionRegistry::deleteRegistry()
 }
 
 /** @cond doxygenLibsbmlInternal */
-/*
- *
- */
 SBMLExtensionRegistry& 
 SBMLExtensionRegistry::getInstance()
 {
@@ -199,6 +196,15 @@ SBMLExtensionRegistry::addExtension (const SBMLExtension* sbmlExt)
     mSBasePluginMap.insert( SBasePluginPair(sbPluginCreator->getTargetExtensionPoint(), sbPluginCreator));
   }    
 
+  // Register ASTPlugins
+  if (sbmlExtClone->isSetASTBasePlugin())
+  {
+    ASTBasePlugin* astPlugin = sbmlExtClone->getASTBasePlugin();
+    astPlugin->setSBMLExtension(sbmlExtClone);
+
+    mASTPluginsVector.push_back(astPlugin);
+  }
+
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -574,6 +580,24 @@ SBMLExtensionRegistry::enablePackages(const std::vector<std::string>& packages)
 }
 /** @endcond */
 
+std::vector<ASTBasePlugin*>
+SBMLExtensionRegistry::getASTPlugins()
+{
+  return mASTPluginsVector;
+}
+
+unsigned int 
+SBMLExtensionRegistry::getNumASTPlugins()
+{
+  return mASTPluginsVector.size();
+}
+
+const ASTBasePlugin * 
+SBMLExtensionRegistry::getASTPlugin(unsigned int i)
+{
+  return mASTPluginsVector.at(i);
+}
+
 
 
 #endif /* __cplusplus */
