@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -48,6 +48,7 @@
 #define SBMLExtensionRegistry_h
 
 #include <sbml/extension/SBMLExtension.h>
+#include <sbml/extension/ASTBasePlugin.h>
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 
@@ -76,6 +77,7 @@ public:
   typedef std::map<std::string, const SBMLExtension*>              SBMLExtensionMap;
   typedef std::pair<std::string, const SBMLExtension*>             SBMLExtensionPair;
   typedef SBMLExtensionMap::iterator                               SBMLExtensionMapIter;
+
   /** @endcond */
 #endif //SWIG
 
@@ -375,6 +377,9 @@ public:
    */
   static std::string getRegisteredPackageName(unsigned int index);
 
+  std::vector<ASTBasePlugin*> getASTPlugins();
+  unsigned int getNumASTPlugins();
+  const ASTBasePlugin * getASTPlugin(unsigned int i);
 
 private:
 
@@ -392,6 +397,7 @@ private:
   /** @cond doxygenLibsbmlInternal */
   SBMLExtensionMap  mSBMLExtensionMap;
   SBasePluginMap    mSBasePluginMap;
+  std::vector<ASTBasePlugin*>  mASTPluginsVector;
 
   static SBMLExtensionRegistry* mInstance;
 
