@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -735,7 +735,7 @@ public:
 
   /** @endcond */
 
-   virtual int getAttribute(const std::string& attributeName, const char * value) const;
+   //virtual int getAttribute(const std::string& attributeName, const char * value) const;
 
 
    virtual bool isSetAttribute(const std::string& attributeName) const;
@@ -774,7 +774,7 @@ public:
 
   /** @cond doxygenLibsbmlInternal */
 
-   virtual int setAttribute(const std::string& attributeName, const char* value);
+   //virtual int setAttribute(const std::string& attributeName, const char* value);
 
   /** @endcond */
 
@@ -829,6 +829,12 @@ public:
 
 #endif
 
+  /** @cond doxygenLibsbmlInternal */
+
+  virtual void updateSBMLNamespace(const std::string& package, unsigned int level,
+    unsigned int version);
+  /** @endcond */
+
 
 protected:
   /** @cond doxygenLibsbmlInternal */
