@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -99,8 +99,8 @@
  * &quot;<code>pi</code>&quot;, and the formula to be parsed is
  * &quot;<code>3*pi</code>&quot;, the MathML produced will contain the
  * construct <code>&lt;ci&gt; pi &lt;/ci&gt;</code> instead of the construct
- * <code>&lt;pi/&gt;</code>.  Similarly, when a Model object is provided,
- * @c SId values of user-defined functions present in the Model will be used
+ * <code>&lt;pi/&gt;</code>.  Similarly, when a Model object is provided, @c
+ * SId values of user-defined functions present in the Model will be used
  * preferentially over pre-defined MathML functions.  For example, if the
  * passed-in Model contains a FunctionDefinition with the identifier
  * &quot;<code>sin</code>&quot;, that function will be used instead of the
@@ -195,7 +195,7 @@
  * @class doc_modulo_l3v2_settings
  *
  * @par
- * This setting affects whether the @% symbol (modulo) is parsed as a
+ * This setting affects whether the '%' symbol (modulo) is parsed as a
  * piecewise equation that returns the modulo value of the entries on 
  * either side of the symbol, or whether it is parsed as the MathML 
  * 'rem' function, which was allowed in SBML Level&nbsp;3 Version&nbsp;2,
@@ -216,30 +216,45 @@
  *
  * @par
  * This setting affects whether the names of functions added in SBML
- * Level&nbsp;3 Version&nbsp;2 are parsed as those added MathML functions,
+ * Level&nbsp;3 Version&nbsp;2 are parsed as those added MathML functions, 
  * or whether they are added as generic functions with those names (to
  * be used in SBML as function definitions).
  *
  * @class doc_l3v2_function_values
  *
  * <ul>
- * <li> @sbmlconstant{L3P_PARSE_L3V2_FUNCTIONS_DIRECTLY,} (value = @c true):
- * parse the strings <code>rateOf</code>, <code>implies</code>,
- * <code>max</code>, <code>min</code>, <code>quotient</code>, and
- * <code>rem</code> as
+ * <li> @sbmlconstant{L3P_PARSE_L3V2_FUNCTIONS_DIRECTLY,} (value = @c true): parse the 
+ * strings 'rateOf', 'implies', 'max', 'min', 'quotient', and 'rem' as
  * @sbmlconstant{AST_FUNCTION_RATE_OF,ASTNodeType_t},
  * @sbmlconstant{AST_LOGICAL_IMPLIES,ASTNodeType_t},
  * @sbmlconstant{AST_FUNCTION_MAX,ASTNodeType_t},
  * @sbmlconstant{AST_FUNCTION_MIN,ASTNodeType_t},
  * @sbmlconstant{AST_FUNCTION_QUOTIENT,ASTNodeType_t}, and
  * @sbmlconstant{AST_FUNCTION_REM,ASTNodeType_t}, respectively.
- * <li> @sbmlconstant{L3P_PARSE_L3V2_FUNCTIONS_AS_GENERIC,} (value = @c false):
- * parse the strings <code>rateOf</code>, <code>implies</code>,
- * <code>max</code>, <code>min</code>, <code>quotient</code>, and
- * <code>rem</code> all as
- * @sbmlconstant{AST_FUNCTION,ASTNodeType_t} with the appropriate
+ * <li> @sbmlconstant{L3P_PARSE_L3V2_FUNCTIONS_AS_GENERIC,} (value = @c false): 
+ * parse the strings 'rateOf', 'implies', 'max', 'min', 'quotient', and 
+ * 'rem' all as @sbmlconstant{AST_FUNCTION,ASTNodeType_t} with the appropriate
  * name set.
  * </ul>
+ *
+ * @class doc_package_math_settings
+ *
+ * @par
+ * This setting affects whether the math added in a given SBML
+ * Level&nbsp;3 package are parsed as those added MathML elements, 
+ * or whether they are added as generic functions or variables
+ * with those names.
+ *
+ * @class doc_package_math_values
+ *
+ * <ul>
+ * <li> @sbmlconstant{L3P_PARSE_PACKAGE_MATH_DIRECTLY,} (value = @c true): parse any 
+ * string defined in a given SBML L3 package as its corresponding ASTType_t.
+ * <li> @sbmlconstant{L3P_PARSE_PACKAGE_MATH_AS_GENERIC,} (value = @c false): 
+ * parse any string that would have been defined in the given SBML L3 package
+ * as @sbmlconstant{AST_FUNCTION,ASTNodeType_t} or @sbmlconstant{AST_NAME,ASTNodeType_t} 
+ * with the appropriate name set.
+ * </ul>
  */
 
 #ifndef L3ParserSettings_h
@@ -249,6 +264,8 @@
 #include <sbml/common/extern.h>
 #include <sbml/common/sbmlfwd.h>
 #include <sbml/util/StringBuffer.h>
+#include <sbml/math/ASTNodeType.h>
+
 
 
 /**
@@ -351,7 +368,7 @@ typedef enum
 #define L3P_COMPARE_BUILTINS_CASE_SENSITIVE true
 
  /**
- * Parse the @% symbol as the l3v2-allowed 'rem' symbol.
+ * Parse the '%' symbol as the l3v2-allowed 'rem' symbol.
  *
  * @see L3ParserSettings::getParseModuloL3v2()
  * @see L3ParserSettings::setParseModuloL3v2()
@@ -359,7 +376,7 @@ typedef enum
 #define L3P_MODULO_IS_REM true
 
  /**
- * Parse the @% symbol as an expanded 'piecewise' function (valid in all levels/versions).
+ * Parse the '%' symbol as an expanded 'piecewise' function (valid in all levels/versions).
  *
  * @see L3ParserSettings::getParseModuloL3v2()
  * @see L3ParserSettings::setParseModuloL3v2()
@@ -376,7 +393,7 @@ typedef enum
 #define L3P_PARSE_L3V2_FUNCTIONS_DIRECTLY true
 
  /**
- * Parse the @% symbol as an expanded 'piecewise' function (valid in all levels/versions).
+ * Parse the '%' symbol as an expanded 'piecewise' function (valid in all levels/versions).
  *
  * @see L3ParserSettings::getParseL3v2Functions()
  * @see L3ParserSettings::setParseL3v2Functions()
@@ -384,6 +401,23 @@ typedef enum
 #define L3P_PARSE_L3V2_FUNCTIONS_AS_GENERIC  false
 
 
+ /**
+ * Parse the functions added in distrib.
+ *
+ * @see L3ParserSettings::getParseDistribFunctions()
+ * @see L3ParserSettings::setParseDistribFunctions()
+ */
+#define L3P_PARSE_PACKAGE_MATH_DIRECTLY true
+
+ /**
+ * Parse the '%' symbol as an expanded 'piecewise' function (valid in all levels/versions).
+ *
+ * @see L3ParserSettings::getParseDistribFunctions()
+ * @see L3ParserSettings::setParseDistribFunctions()
+ */
+#define L3P_PARSE_PACKAGE_MATH_AS_GENERIC  false
+
+
 typedef enum
 {
     INFIX_SYNTAX_NAMED_SQUARE_BRACKETS
@@ -392,6 +426,7 @@ typedef enum
 } L3ParserGrammarLineType_t;
 
 
+#include <sbml/extension/ASTBasePlugin.h>
 
 #ifdef __cplusplus
 
@@ -403,9 +438,7 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 class Model;
 class L3Parser;
 
-#ifndef LIBSBML_USE_LEGACY_MATH
 class ASTBasePlugin;
-#endif
 
 class LIBSBML_EXTERN L3ParserSettings
 {
@@ -418,10 +451,7 @@ private:
   bool mAvoCsymbol;
   bool mStrCmpIsCaseSensitive;
   bool mModuloL3v2;
-  bool ml3v2Functions;
-#ifndef LIBSBML_USE_LEGACY_MATH
-  std::vector<ASTBasePlugin*> mPlugins;
-#endif
+  std::map<ExtendedMathType_t, bool> mParsePackages;
   /** @endcond */
 
 public:
@@ -510,16 +540,16 @@ public:
    * @sbmlconstant{L3P_COMPARE_BUILTINS_CASE_SENSITIVE,}, symbols are
    * interpreted in a case-sensitive manner.
    *
-   * @param moduloL3v2 ("modulo L3v2") a flag that controls how the
-   * parser will handle the @% ('modulo') symbol in formulas.  By default, 
+   * @param modulol3v2 ("modulo l3v2") a flag that controls how the
+   * parser will handle the '%' ('modulo') symbol in formulas.  By default, 
    * the parser will convert 'a % b' to a piecewise function that properly
    * calculates the remainder of a with respect to be, but the parser can
    * also be set to produce the MathML @c rem function, should the target
    * of the produced ASTNode be an SBML Level&nbsp;3 Version&nbsp;2 
    * document, where the @c rem function is legal.
    * The possible values of this field are
-   * @sbmlconstant{L3P_MODULO_IS_PIECEWISE,} (to parse @% as a piecewise function) and
-   * @sbmlconstant{L3P_MODULO_IS_REM,} (to parse @% as @c rem).
+   * @sbmlconstant{L3P_MODULO_IS_PIECEWISE,} (to parse '%' as a piecewise function) and
+   * @sbmlconstant{L3P_MODULO_IS_REM,} (to parse '%' as @c rem).
    *
    * @param sbmlns ("SBML namespaces") an SBML namespaces object.  The
    * namespaces identify the SBML Level&nbsp;3 packages that can extend the
@@ -528,13 +558,6 @@ public:
    * it may understand vector/array extensions introduced by the SBML
    * Level&nbsp;3 @em Arrays package.
    *
-   * @param l3v2functions ("parse L3v2 functions directly") is a Boolean flag
-   * that controls how to translate certain mathematical functions added in SBML
-   * Level&nbsp;3 Version&nbsp;2 Core.  The parser can either turn them into
-   * specific AST node types, or turn them all into
-   * @sbmlconstant{AST_FUNCTION,ASTNodeType_t} with the name set to the
-   * function name in question.
-   *
    * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    *
    * @see getModel()
@@ -793,8 +816,8 @@ public:
    *
    * @copydetails doc_case_sensitivity
    *
-   * @param strcmp a boolean indicating whether to be case sensitive (if
-   * @c true) or be case insensitive (if @c false).
+   * @param strcmp a boolean indicating whether to be case sensitive (if @c
+   * true) or be case insensitive (if @c false).
    *
    * @see getComparisonCaseSensitivity()
    */
@@ -817,13 +840,13 @@ public:
 
 
   /**
-  * Sets the behavior for handling the @% symbol in mathematical
+  * Sets the behavior for handling the '%' sumbol in mathematical
   * formulas.
   *
   * @copydetails doc_modulo_l3v2_settings
   *
   * This method lets you tell the parser which behavior to use---either
-  * parse @% as the 'rem' function or as a piecewise function with the
+  * parse '%' as the 'rem' function or as a piecewise function with the
   * same interpretation.  The two possibilities are
   * represented using the following constants:
   *
@@ -832,7 +855,7 @@ public:
   * @param modulol3v2 a boolean value (one of the constants
   * @sbmlconstant{L3P_MODULO_IS_PIECEWISE,} or
   * @sbmlconstant{L3P_MODULO_IS_REM,})
-  * indicating how the @% symbol in the input should be handled.
+  * indicating how the '%' symbol in the input should be handled.
   *
   * @see getParseModuloL3v2()
   */
@@ -840,7 +863,7 @@ public:
 
 
   /**
-  * Indicates the current behavior set for handling the @% symbol in 
+  * Indicates the current behavior set for handling the '%' sumbol in 
   * mathematical formulas.
   *
   * @copydetails doc_modulo_l3v2_settings
@@ -878,8 +901,8 @@ public:
 
 
   /**
-  * Indicates the current behavior set for handling the @% symbol in
-  * mathematical formulas.
+  * Indicates the current behavior set for handling whether to
+  * parse the functions added in L3v2 as that MathML or not.
   *
   * @copydetails doc_l3v2_function_settings
   *
@@ -887,30 +910,47 @@ public:
   * values are as follows:
   * @copydetails doc_l3v2_function_values
   *
-  * @see setParseModuloL3v2(@if java boolean@endif)
+  * @see setParsePackageMath(@if java boolean@endif)
   */
   bool getParseL3v2Functions() const;
 
 
   /**
-   * Set up the plugins for this L3ParserSettings, based on the
-   * SBMLNamespaces object.
-   *
-   * When a SBMLNamespaces object is provided, the parser will only interpret
-   * infix syntax understood by the core libSBML @em plus the packages
-   * indicated by the SBMLNamespaces objects provided.  ASTNode objects
-   * returned by the L3Parser will contain those SBMLNamespaces objects, and
-   * will be used to parse certain constructs that may only be understood by
-   * packages (e.g., vectors for the SBML Level&nbsp;3 "arrays" package).
-   * Note that by default, all packages that were compiled with this version
-   * of libSBML are included, so this function is most useful as a way to
-   * turn @em off certain namespaces, such as might be desired if your tool
-   * does not support vectors, for example.
-   *
-   * @param sbmlns a SBMLNamespaces object to be used.  If @c NULL is given
-   * as the value, all plugins will be loaded.
-   */
-  void setPlugins(const SBMLNamespaces * sbmlns);
+  * Sets the behavior for handling functions added in SBML packages
+  *
+  * @copydetails doc_package_math_settings
+  *
+  * This method lets you tell the parser which behavior to use---either
+  * to parse the functions added in a given package as their built-in counterparts,
+  * or as generic functions with that name (to be defined by SBML as
+  * function definitions).  The two possibilities are
+  * represented using the following constants:
+  *
+  * @copydetails doc_package_math_values
+  *
+  * @param l3v2functions a boolean value (one of the constants
+  * @sbmlconstant{L3P_PARSE_L3V2_FUNCTIONS_DIRECTLY,} or
+  * @sbmlconstant{L3P_PARSE_L3V2_FUNCTIONS_AS_GENERIC,})
+  * indicating how to interpret those function names.
+  *
+  * @see getParsePackageMath()
+  */
+  void setParsePackageMath(ExtendedMathType_t package, bool parsepackage);
+
+
+  /**
+  * Indicates the current behavior set for handling whether to
+  * parse the functions added in the given package as that MathML or not.
+  *
+  * @copydetails doc_package_math_settings
+  *
+  * @return A boolean indicating the behavior currently set.  The possible
+  * values are as follows:
+  * @copydetails doc_package_math_values
+  *
+  * @see setParsePackageMath(@if java boolean@endif)
+  */
+  bool getParsePackageMath(ExtendedMathType_t package) const;
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -960,17 +1000,11 @@ private:
    * 'name' is recognized by a package as being a particular function.  We
    * already know that it is not used in the Model as a FunctionDefinition.
    * Should do caseless string comparison.  Return the type of the function,
-   * or @sbmlconstant{AST_UNKNOWN, ASTNodeType_t} if nothing found.
+   * or AST_UNKNOWN if nothing found.
    */
-  int getPackageFunctionFor(const std::string& name) const;
+  ASTNodeType_t getPackageFunctionFor(const std::string& name) const;
 
 
-  /**
-   * Delete the plugin objects.
-   */
-  void deletePlugins();
-
-  /** @endcond */
 };
 
 
@@ -987,11 +1021,9 @@ BEGIN_C_DECLS
 /**
  * Creates a new L3ParserSettings_t structure and returns a pointer to it
  *
- * @note This functions sets the Model * to NULL, and other settings to 
- * @sbmlconstant{L3P_PARSE_LOG_AS_LOG10,ParseLogType_t}, 
- * @sbmlconstant{L3P_EXPAND_UNARY_MINUS,}, 
- * @sbmlconstant{L3P_PARSE_UNITS,}, and 
- * @sbmlconstant{L3P_AVOGADRO_IS_CSYMBOL,}.
+ * @note This functions sets the Model* to NULL, and other settings to 
+ * L3P_PARSE_LOG_AS_LOG10, L3P_EXPAND_UNARY_MINUS, L3P_PARSE_UNITS, 
+ * and L3P_AVOGADRO_IS_CSYMBOL.
  *
  * @return a pointer to the newly created L3ParserSettings_t structure.
  *
@@ -1062,9 +1094,9 @@ L3ParserSettings_unsetModel (L3ParserSettings_t * settings);
  *
  * This option allows the user to specify how the infix expression 'log(x)'
  * is parsed in a MathML ASTNode. The options are:
- * @li @sbmlconstant{L3P_PARSE_LOG_AS_LOG10,ParseLogType_t} (0)
- * @li @sbmlconstant{L3P_PARSE_LOG_AS_LN,ParseLogType_t} (1)
- * @li @sbmlconstant{L3P_PARSE_LOG_AS_ERROR,ParseLogType_t} (2)
+ * @li L3P_PARSE_LOG_AS_LOG10 (0)
+ * @li L3P_PARSE_LOG_AS_LN (1)
+ * @li L3P_PARSE_LOG_AS_ERROR (2)
  *
  * @param settings the L3ParserSettings_t structure on which to set the option.
  * @param type ParseLogType_t log parsing option to associate with this 
@@ -1082,15 +1114,15 @@ L3ParserSettings_setParseLog (L3ParserSettings_t * settings, ParseLogType_t type
  *
  * This option allows the user to specify how the infix expression 'log(x)'
  * is parsed in a MathML ASTNode. The options are:
- * @li @sbmlconstant{L3P_PARSE_LOG_AS_LOG10,ParseLogType_t} (0)
- * @li @sbmlconstant{L3P_PARSE_LOG_AS_LN,ParseLogType_t} (1)
- * @li @sbmlconstant{L3P_PARSE_LOG_AS_ERROR,ParseLogType_t} (2)
+ * @li L3P_PARSE_LOG_AS_LOG10 (0)
+ * @li L3P_PARSE_LOG_AS_LN (1)
+ * @li L3P_PARSE_LOG_AS_ERROR (2)
  *
  * @param settings the L3ParserSettings_t structure on which to set the Model_t.
  *
  * @return ParseLogType_t log parsing option to associate with this 
- * L3ParserSettings_t structure.  Returns  @sbmlconstant{L3P_PARSE_LOG_AS_LOG10,ParseLogType_t} (0) if @p settings
- * is @c NULL.
+ * L3ParserSettings_t structure.  Returns L3P_PARSE_LOG_AS_LOG10 (0) if @param settings
+ * is NULL.
  *
  * @memberof L3ParserSettings_t
  */
@@ -1102,13 +1134,12 @@ L3ParserSettings_getParseLog (const L3ParserSettings_t * settings);
 /**
  * Sets the collapse minus option associated with this L3ParserSettings_t structure.  
  *
- * This option allows the user to specify how infix expressions like '- -4'
- * are parsed in a MathML ASTNode. 
+ * This option allows the user to specify how the infix expression '-4'
+ * is parsed in a MathML ASTNode. 
  * 
  * @param settings the L3ParserSettings_t structure on which to set the option.
  * @param flag an integer indicating whether unary minus should be collapsed 
- * (@c 1 ; true) or not (@c 0 ; false).  Returns
- * @c 0 (false) if @p settings is @c NULL.
+ * (non-zero) or not (zero).
  *
  * @memberof L3ParserSettings_t
  */
@@ -1120,14 +1151,14 @@ L3ParserSettings_setParseCollapseMinus (L3ParserSettings_t * settings, int flag)
 /**
  * Retrieves the collapse minus option associated with this L3ParserSettings_t structure.  
  *
- * This option allows the user to specify how infix expressions like '- -4'
- * are parsed in a MathML ASTNode. 
+ * This option allows the user to specify how the infix expression '-4'
+ * is parsed in a MathML ASTNode. 
  * 
  * @param settings the L3ParserSettings_t structure from which to get the option.
  *
  * @return an integer indicating whether unary minus should be collapsed 
- * (@c 1 ; true) or not (@c 0 ; false).  Returns
- * @c 0 (false) if @p settings is @c NULL.
+ * (non-zero) or not (zero).  Returns zero (0) if @param settings
+ * is NULL.
  *
  * @memberof L3ParserSettings_t
  */
@@ -1141,8 +1172,7 @@ L3ParserSettings_getParseCollapseMinus (const L3ParserSettings_t * settings);
  *
  * @param settings the L3ParserSettings_t structure on which to set the option.
  * @param flag an integer indicating whether numbers should be considered as 
- * a having units  (@c 1 ; true) or not (@c 0 ; false).  Returns
- * @c 0 (false) if @p settings is @c NULL.
+ * a having units (non-zero) or not (zero).
  *
  * @memberof L3ParserSettings_t
  */
@@ -1157,8 +1187,8 @@ L3ParserSettings_setParseUnits (L3ParserSettings_t * settings, int flag);
  * @param settings the L3ParserSettings_t structure from which to get the option.
  *
  * @return an integer indicating whether numbers should be considered as 
- * a having units  (@c 1 ; true) or not (@c 0 ; false).  Returns 
- * @c 0 (false) if @p settings is @c NULL.
+ * a having units (non-zero) or not (zero).  Returns zero (0) if @param settings
+ * is NULL.
  *
  * @memberof L3ParserSettings_t
  */
@@ -1172,8 +1202,7 @@ L3ParserSettings_getParseUnits (const L3ParserSettings_t * settings);
  *
  * @param settings the L3ParserSettings_t structure on which to set the option.
  * @param flag an integer indicating whether avogadro should be considered as 
- * a csymbol (@c 1 ; true) or not (@c 0 ; false).  Returns @c 0 (false) if @p settings
- * is @c NULL.
+ * a csymbol (non-zero) or not (zero).
  *
  * @memberof L3ParserSettings_t
  */
@@ -1188,8 +1217,8 @@ L3ParserSettings_setParseAvogadroCsymbol (L3ParserSettings_t * settings, int fla
  * @param settings the L3ParserSettings_t structure from which to get the option.
  *
  * @return an integer indicating whether avogadro should be considered as 
- * a csymbol (@c 1 ; true) or not (@c 0 ; false).  Returns @c 0 (false) if 
- * @p settings is @c NULL.
+ * a csymbol (non-zero) or not (zero).  Returns zero (0) if @param settings
+ * is NULL.
  *
  * @memberof L3ParserSettings_t
  */
@@ -1199,7 +1228,7 @@ L3ParserSettings_getParseAvogadroCsymbol (const L3ParserSettings_t * settings);
 
 
 /**
-* Sets the behavior for handling the @% symbol in mathematical
+* Sets the behavior for handling the '%' sumbol in mathematical
 * formulas.
 *
 * @copydetails doc_modulo_l3v2_settings
@@ -1210,13 +1239,12 @@ L3ParserSettings_getParseAvogadroCsymbol (const L3ParserSettings_t * settings);
 *
 * @copydetails doc_modulo_l3v2_values
 *
-* @param settings the L3ParserSettings_t structure to modify.
 * @param modulol3v2 a boolean value (one of the constants
 * @sbmlconstant{L3P_MODULO_IS_PIECEWISE,} or
 * @sbmlconstant{L3P_MODULO_IS_REM,})
-* indicating how the @% symbol in the input should be handled.
+* indicating how the '%' symbol in the input should be handled.
 *
-* @see L3ParserSettings_getParseModuloL3v2()
+* @see getParseModuloL3v2()
 *
 * @memberof L3ParserSettings_t
 */
@@ -1226,16 +1254,16 @@ L3ParserSettings_setParseModuloL3v2(const L3ParserSettings_t * settings, int mod
 
 
 /**
-* Indicates the current behavior set for handling the @% symbol in
+* Indicates the current behavior set for handling the '%' sumbol in
 * mathematical formulas.
 *
 * @copydetails doc_modulo_l3v2_settings
 *
-* @return a boolean indicating the behavior currently set.  The possible
+* @return A boolean indicating the behavior currently set.  The possible
 * values are as follows:
-* @copydetails doc_modulo_l3v2_values
+* @copydetails doc_unary_minus_values
 *
-* @see L3ParserSettings_setParseModuloL3v2(@if java boolean@endif)
+* @see setParseModuloL3v2(@if java boolean@endif)
 *
 * @memberof L3ParserSettings_t
 */
