@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -43,11 +43,6 @@
 #include <sbml/packages/arrays/extension/ArraysSBasePlugin.h>
 #include <sbml/packages/arrays/extension/ArraysASTPlugin.h>
 
-#if (0)
-#include <sbml/packages/arrays/math/ASTArraysMatrixFunctionNode.h>
-#endif
-#include <sbml/packages/arrays/math/ASTArraysVectorFunctionNode.h>
-
 #include <sbml/packages/arrays/sbml/Index.h>
 #include <sbml/packages/arrays/sbml/Dimension.h>
 #include <sbml/packages/arrays/sbml/ListOfDimensions.h>
