@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -345,25 +345,6 @@ ArraysSBMLDocumentPlugin::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this
- * ArraysSBMLDocumentPlugin.
- */
-int
-ArraysSBMLDocumentPlugin::getAttribute(const std::string& attributeName,
-                                       const char* value) const
-{
-  int return_value = SBMLDocumentPlugin::getAttribute(attributeName, value);
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -478,25 +459,6 @@ ArraysSBMLDocumentPlugin::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this
- * ArraysSBMLDocumentPlugin.
- */
-int
-ArraysSBMLDocumentPlugin::setAttribute(const std::string& attributeName,
-                                       const char* value)
-{
-  int return_value = SBMLDocumentPlugin::setAttribute(attributeName, value);
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
