@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -102,9 +102,30 @@ typedef CLASS_OR_STRUCT Submodel                     Submodel_t;
  * @copydoc SBMLDocumentPlugin
  */
 typedef CLASS_OR_STRUCT CompSBMLDocumentPlugin       CompSBMLDocumentPlugin_t;
+
+
+/**
+ * @var typedef class ListOfExternalModelDefinitions ListOfExternalModelDefinitions_t
+ * @copydoc ListOfExternalModelDefinitions
+ */
+typedef CLASS_OR_STRUCT ListOfExternalModelDefinitions       ListOfExternalModelDefinitions_t;
+
+
+/**
+ * @var typedef class ListOfModelDefinitions ListOfModelDefinitions_t
+ * @copydoc ListOfModelDefinitions
+ */
+typedef CLASS_OR_STRUCT ListOfModelDefinitions       ListOfModelDefinitions_t;
 /** @endcond */
 
 
+/**
+ * @var typedef class CompSBasePlugin CompSBasePlugin_t
+ * @copydoc CompSBasePlugin
+ */
+typedef CLASS_OR_STRUCT CompSBasePlugin               CompSBasePlugin_t;
+
+
 /** @cond doxygenLibsbmlInternal */
 /**
  * @var typedef class ModelPlugin ModelPlugin_t
