@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -211,34 +211,7 @@ Deletion::readAttributes (const XMLAttributes& attributes,
       } 
     }
   }
-  SBaseRef::readAttributes(attributes,expectedAttributes);
-
-  //const unsigned int sbmlLevel   = getLevel  ();
-  //const unsigned int sbmlVersion = getVersion();
-
-  XMLTriple tripleId("id", mURI, getPrefix());
-  if (attributes.readInto(tripleId, mId, getErrorLog(), 
-                          false, getLine(), getColumn()))
-  {
-    if (mId.size() == 0)
-    {
-      logEmptyString("id", "<Deletion>");
-    }
-    else 
-    {
-      if (!SyntaxChecker::isValidSBMLSId(mId)) 
-      {
-        logInvalidId("comp:id", mId);
-      }
-    }
-  }
-
-  XMLTriple tripleName("name", mURI, getPrefix());
-  if (attributes.readInto(tripleName, mName, getErrorLog(), false, getLine(), getColumn())) {
-    if (mName.empty()) {
-      logInvalidId("comp:name", mName);
-    }
-  }
+  SBaseRef::readAttributes(attributes,expectedAttributes, true, false, CompDeletionAllowedAttributes);
 }
 /** @endcond */
 
@@ -443,26 +416,6 @@ Deletion_hasRequiredAttributes(Deletion_t * d)
 }
 
 
-LIBSBML_EXTERN
-Deletion_t *
-ListOfDeletions_getById(ListOf_t * lo, const char * sid)
-{
-  if (lo == NULL)
-    return NULL;
-
-  return (sid != NULL) ? static_cast <ListOfDeletions *>(lo)->get(sid) : NULL;
-}
-
-
-LIBSBML_EXTERN
-Deletion_t *
-ListOfDeletions_removeById(ListOf_t * lo, const char * sid)
-{
-  if (lo == NULL)
-    return NULL;
-
-  return (sid != NULL) ? static_cast <ListOfDeletions *>(lo)->remove(sid) : NULL;
-}
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
