@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -237,7 +237,7 @@ ExternalModelDefinition::getModelRef () const
 
 
 /*
- * @return true if the modelRef of this SBML object has been set, false
+ * @return @c true if the modelRef of this SBML object has been set, false
  * otherwise.
  */
 bool
@@ -289,7 +289,7 @@ ExternalModelDefinition::getMd5 () const
 
 
 /*
- * @return true if the md5 of this SBML object has been set, false
+ * @return @c true if the md5 of this SBML object has been set, false
  * otherwise.
  */
 bool
@@ -339,7 +339,7 @@ ExternalModelDefinition::getSource () const
 
 
 /*
- * @return true if the source of this SBML object has been set, false
+ * @return @c true if the source of this SBML object has been set, false
  * otherwise.
  */
 bool
@@ -433,7 +433,7 @@ ExternalModelDefinition::readAttributes (const XMLAttributes& attributes,
   }
 
 
-  CompBase::readAttributes(attributes,expectedAttributes);
+  CompBase::readAttributes(attributes,expectedAttributes, true, true, CompExtModDefAllowedAttributes);
 
   // look to see whether an unknown attribute error was logged
   if (getErrorLog() != NULL)
@@ -463,40 +463,8 @@ ExternalModelDefinition::readAttributes (const XMLAttributes& attributes,
 
   if ( sbmlLevel > 2 )
   {
-    XMLTriple tripleId("id", mURI, getPrefix());
-    bool assigned = false;
-    assigned = attributes.readInto(tripleId, mId, getErrorLog(), 
-      false, getLine(), getColumn()); 
-    
-    if (assigned == false)
-    {
-      logMissingAttribute("id", "<ExternalModelDefinition>");
-    }
-    else if (assigned == true && mId.size() == 0)
-    {
-      logEmptyString("id", "<ExternalModelDefinition>");
-    }
-    else 
-    {
-      if (!SyntaxChecker::isValidSBMLSId(mId)) {
-        logInvalidId("comp:id", mId);
-      }
-    }
-
- 
-    XMLTriple tripleName("name", mURI, getPrefix());
-    assigned = attributes.readInto(tripleName, mName);
-    
-    if (assigned == true)
-    {
-      if (mName.empty()) 
-      {
-        logEmptyString("comp:name", mName);
-      }
-    }
-
     XMLTriple tripleSource("source", mURI, getPrefix());
-    assigned = attributes.readInto(tripleSource, mSource);
+    bool assigned = attributes.readInto(tripleSource, mSource);
 
     if (assigned == false)
     {
@@ -639,13 +607,35 @@ ExternalModelDefinition::getReferencedModel(SBMLDocument* errordoc, set<pair<str
     return NULL;
   }
 
-  if (!(doc->getLevel() == 3  && doc->getVersion() == 1))
+  // We want an L3V2 document to allow L3V2 external models
+  // but L3V1 to only allow L3V1 external models
+  bool matchDocs = true;
+  if (doc->getLevel() != 3)
+  {
+    matchDocs = false;
+  }
+  else if (errordoc->getLevel() != 3)
+  {
+    matchDocs = false;
+  }
+  else if (doc->getVersion() != errordoc->getVersion())
+  {
+    matchDocs = false;
+  }
+
+  if (!matchDocs)
   {
     // comp v1 ONLY allows L3v1 models. All other levels and versions are not supported. 
     // 
     if (errordoc) {
-      string error = "In ExternalModelDefinition::getReferencedModel, unable to resolve the external model definition '" + getId() + "': the SBML document found at source '" + getSource() + "' was not SBML Level 3 Version 1.";
-      errordoc->getErrorLog()->logPackageError("comp", CompReferenceMustBeL3, getPackageVersion(), getLevel(), getVersion(), error, getLine(), getColumn());
+      stringstream errout;
+
+      errout << "In ExternalModelDefinition::getReferencedModel, "
+        "unable to resolve the external model definition '" << getId()
+        << "': the SBML document found at source '" << getSource() 
+        << "' was not SBML Level 3 Version " << doc->getVersion() << ".";
+      errordoc->getErrorLog()->logPackageError("comp", CompReferenceMustBeL3, 
+        getPackageVersion(), getLevel(), getVersion(), errout.str(), getLine(), getColumn());
     }
     return NULL;
   }
@@ -923,28 +913,6 @@ ExternalModelDefinition_hasRequiredAttributes(ExternalModelDefinition_t * emd)
 {
   return (emd != NULL) ? static_cast<int>(emd->hasRequiredAttributes()) : 0;
 }
-
-
-LIBSBML_EXTERN
-ExternalModelDefinition_t *
-ListOfExternalModelDefinitions_getById(ListOf_t * lo, const char * sid)
-{
-  if (lo == NULL)
-    return NULL;
-
-  return (sid != NULL) ? static_cast <ListOfExternalModelDefinitions *>(lo)->get(sid) : NULL;
-}
-
-
-LIBSBML_EXTERN
-ExternalModelDefinition_t *
-ListOfExternalModelDefinitions_removeById(ListOf_t * lo, const char * sid)
-{
-  if (lo == NULL)
-    return NULL;
-
-  return (sid != NULL) ? static_cast <ListOfExternalModelDefinitions *>(lo)->remove(sid) : NULL;
-}
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
