@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -105,6 +105,7 @@ public:
    * @param n the index number of the ReplacedElement to get.
    * 
    * @return the nth ReplacedElement in this ListOfReplacedElements.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
@@ -117,6 +118,7 @@ public:
    * @param n the index number of the ReplacedElement to get.
    * 
    * @return the nth ReplacedElement in this ListOfReplacedElements.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
@@ -186,9 +188,46 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
-//
-// C API will be added here.
-//
+
+/**
+ * Get a ReplacedElement_t from the ListOf_t.
+ *
+ * @param lo the ListOf_t structure to search.
+ *
+ * @param n an unsigned int representing the index of the ReplacedElement_t to
+ * retrieve.
+ *
+ * @return the nth ReplacedElement_t in this ListOf_t.
+ * If the index @p n is invalid, @c NULL is returned.
+ *
+ * @copydetails doc_returned_unowned_pointer
+ *
+ * @memberof ListOfReplacedElements_t
+ */
+LIBSBML_EXTERN
+ReplacedElement_t*
+ListOfReplacedElements_getReplacedElement(ListOf_t* lo, unsigned int n);
+
+
+/**
+ * Removes the nth ReplacedElement_t from this ListOf_t and returns a pointer
+ * to it.
+ *
+ * @param lo the ListOf_t structure to search.
+ *
+ * @param n an unsigned int representing the index of the ReplacedElement_t to
+ * remove.
+ *
+ * @return a pointer to the nth ReplacedElement_t in this ListOf_t.
+ *
+ * @copydetails doc_warning_returns_owned_pointer
+ *
+ * @memberof ListOfReplacedElements_t
+ */
+LIBSBML_EXTERN
+ReplacedElement_t*
+ListOfReplacedElements_remove(ListOf_t* lo, unsigned int n);
+
 
 END_C_DECLS
 LIBSBML_CPP_NAMESPACE_END
