@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -103,6 +103,7 @@ public:
    * @param n the index number of the Submodel to get.
    * 
    * @return the nth Submodel in this ListOfSubmodels.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
@@ -115,6 +116,7 @@ public:
    * @param n the index number of the Submodel to get.
    * 
    * @return the nth Submodel in this ListOfSubmodels.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
@@ -231,9 +233,84 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
-//
-// C API will be added here.
-//
+
+/**
+ * Get a Submodel_t from the ListOf_t.
+ *
+ * @param lo the ListOf_t structure to search.
+ *
+ * @param n an unsigned int representing the index of the Submodel_t to
+ * retrieve.
+ *
+ * @return the nth Submodel_t in this ListOf_t.
+ * If the index @p n is invalid, @c NULL is returned.
+ *
+ * @copydetails doc_returned_unowned_pointer
+ *
+ * @memberof ListOfSubmodels_t
+ */
+LIBSBML_EXTERN
+Submodel_t*
+ListOfSubmodels_getSubmodel(ListOf_t* lo, unsigned int n);
+
+
+/**
+ * Get a Submodel_t from the ListOf_t based on its identifier.
+ *
+ * @param lo the ListOf_t structure to search.
+ *
+ * @param sid a string representing the identifier of the Submodel_t to
+ * retrieve.
+ *
+ * @return the Submodel_t in this ListOf_t with the given @p sid or @c NULL if
+ * no such Submodel_t exists.
+ *
+ * @copydetails doc_returned_unowned_pointer
+ *
+ * @memberof ListOfSubmodels_t
+ */
+LIBSBML_EXTERN
+Submodel_t*
+ListOfSubmodels_getById(ListOf_t* lo, const char *sid);
+
+
+/**
+ * Removes the nth Submodel_t from this ListOf_t and returns a pointer to it.
+ *
+ * @param lo the ListOf_t structure to search.
+ *
+ * @param n an unsigned int representing the index of the Submodel_t to remove.
+ *
+ * @return a pointer to the nth Submodel_t in this ListOf_t.
+ *
+ * @copydetails doc_warning_returns_owned_pointer
+ *
+ * @memberof ListOfSubmodels_t
+ */
+LIBSBML_EXTERN
+Submodel_t*
+ListOfSubmodels_remove(ListOf_t* lo, unsigned int n);
+
+
+/**
+ * Removes the Submodel_t from this ListOf_t based on its identifier and
+ * returns a pointer to it.
+ *
+ * @param lo the ListOf_t structure to search.
+ *
+ * @param sid a string representing the identifier of the Submodel_t to remove.
+ *
+ * @return the Submodel_t in this ListOf_t based on the identifier or NULL if
+ * no such Submodel_t exists.
+ *
+ * @copydetails doc_warning_returns_owned_pointer
+ *
+ * @memberof ListOfSubmodels_t
+ */
+LIBSBML_EXTERN
+Submodel_t*
+ListOfSubmodels_removeById(ListOf_t* lo, const char* sid);
+
 
 END_C_DECLS
 LIBSBML_CPP_NAMESPACE_END
