@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -730,40 +730,6 @@ FbcReactionPlugin::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this FbcReactionPlugin.
- */
-int
-FbcReactionPlugin::getAttribute(const std::string& attributeName,
-                                const char* value) const
-{
-  int return_value = SBasePlugin::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "lowerFluxBound")
-  {
-    value = getLowerFluxBound().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "upperFluxBound")
-  {
-    value = getUpperFluxBound().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -888,33 +854,6 @@ FbcReactionPlugin::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this FbcReactionPlugin.
- */
-int
-FbcReactionPlugin::setAttribute(const std::string& attributeName,
-                                const char* value)
-{
-  int return_value = SBasePlugin::setAttribute(attributeName, value);
-
-  if (attributeName == "lowerFluxBound")
-  {
-    return_value = setLowerFluxBound(value);
-  }
-  else if (attributeName == "upperFluxBound")
-  {
-    return_value = setUpperFluxBound(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
