@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -150,17 +150,17 @@ public:
 
 
    /**
-   * Returns the  "ListOfFbcAssociations" in this FbcAnd object.
+   * Returns the ListOfFbcAssociations in this FbcAnd object.
    *
-   * @return the "ListOfFbcAssociations" attribute of this FbcAnd.
+   * @return the ListOfFbcAssociations child of this FbcAnd.
    */
   const ListOfFbcAssociations* getListOfAssociations() const;
 
 
   /**
-   * Returns the  "ListOfFbcAssociations" in this FbcAnd object.
+   * Returns the ListOfFbcAssociations in this FbcAnd object.
    *
-   * @return the "ListOfFbcAssociations" attribute of this FbcAnd.
+   * @return the ListOfFbcAssociations child of this FbcAnd.
    */
   ListOfFbcAssociations* getListOfAssociations();
 
@@ -172,6 +172,7 @@ public:
    *
    * @return the nth FbcAssociation in the ListOfFbcAssociations within this
    * FbcAnd.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see getNumAssociations()
    */
@@ -185,6 +186,7 @@ public:
    *
    * @return the nth FbcAssociation in the ListOfFbcAssociations within this
    * FbcAnd.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see getNumAssociations()
    */
@@ -199,7 +201,7 @@ public:
    * of the FbcAssociation to get.
    *
    * @return the FbcAssociation in the ListOfFbcAssociations
-   * with the given id or NULL if no such
+   * with the given id or @c NULL if no such
    * FbcAssociation exists.
    *
    * @see getAssociation(unsigned int n)
@@ -217,7 +219,7 @@ public:
    * of the FbcAssociation to get.
    *
    * @return the FbcAssociation in the ListOfFbcAssociations
-   * with the given id or NULL if no such
+   * with the given id or @c NULL if no such
    * FbcAssociation exists.
    *
    * @see getAssociation(unsigned int n)
@@ -543,26 +545,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Gets the value of the "attributeName" attribute of this FbcAnd.
-   *
-   * @param attributeName, the name of the attribute to retrieve.
-   *
-   * @param value, the address of the value to record.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int getAttribute(const std::string& attributeName,
-                           const char* value) const;
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -677,26 +659,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Sets the value of the "attributeName" attribute of this FbcAnd.
-   *
-   * @param attributeName, the name of the attribute to set.
-   *
-   * @param value, the value of the attribute to set.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int setAttribute(const std::string& attributeName, const char*
-    value);
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -751,7 +713,7 @@ public:
    *
    * @param elementName, the name of the element to get number of.
    *
-   * @param index, unsigned int teh index of teh object to retrieve.
+   * @param index, unsigned int the index of the object to retrieve.
    *
    * @return pointer to the object.
    */
@@ -825,20 +787,21 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
+
 /**
- * Creates a new FbcAnd_t structure using the given SBML @p level and
- * @p version values.
+ * Creates a new FbcAnd_t using the given SBML Level, Version and
+ * &ldquo;fbc&rdquo; package version.
  *
- * @param level an unsigned int, the SBML level to assign to this
- * FbcAnd_t structure.
+ * @param level an unsigned int, the SBML Level to assign to this FbcAnd_t.
  *
- * @param version an unsigned int, the SBML version to assign to this
- * FbcAnd_t structure.
+ * @param version an unsigned int, the SBML Version to assign to this FbcAnd_t.
  *
- * @returns the newly-created FbcAnd_t structure, or a null pointer if
- * an error occurred during construction.
+ * @param pkgVersion an unsigned int, the SBML Fbc Version to assign to this
+ * FbcAnd_t.
  *
- * @copydetails doc_note_setting_lv
+ * @copydetails doc_note_setting_lv_pkg
+ *
+ * @copydetails doc_warning_returns_owned_pointer
  *
  * @memberof FbcAnd_t
  */
@@ -849,92 +812,232 @@ FbcAnd_create(unsigned int level, unsigned int version,
 
 
 /**
- * Frees the given FbcAnd_t structure.
- * 
- * @param fa the FbcAnd_t structure to be freed.
+ * Frees this FbcAnd_t object.
+ *
+ * @param fa the FbcAnd_t structure.
  *
  * @memberof FbcAnd_t
  */
 LIBSBML_EXTERN
 void
-FbcAnd_free(FbcAnd_t * fa);
+FbcAnd_free(FbcAnd_t* fa);
 
 
 /**
- * Creates a deep copy of the given FbcAnd_t structure.
- * 
- * @param fa the FbcAnd_t structure to be copied.
+ * Creates and returns a deep copy of this FbcAnd_t object.
  *
- * @returns a (deep) copy of the given FbcAnd_t structure, or a null
+ * @param fa the FbcAnd_t structure.
+ *
+ * @return a (deep) copy of this FbcAnd_t object.
  * pointer if a failure occurred.
  *
  * @memberof FbcAnd_t
  */
 LIBSBML_EXTERN
-FbcAnd_t *
-FbcAnd_clone(FbcAnd_t * fa);
+FbcAnd_t*
+FbcAnd_clone(const FbcAnd_t* fa);
 
 
+/**
+ * Adds a copy of the given FbcAssociation_t to this FbcAnd_t.
+ *
+ * @param fa the FbcAnd_t structure to which the FbcAssociation_t should be added.
+ *
+ * @param a the FbcAssociation_t object to add.
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_LEVEL_MISMATCH, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_VERSION_MISMATCH, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_PKG_VERSION_MISMATCH, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_DUPLICATE_OBJECT_ID, OperationReturnValues_t}
+ *
+ * @memberof FbcAnd_t
+ */
 LIBSBML_EXTERN
 int
-FbcAnd_addAssociation(FbcAnd_t * fa, FbcAssociation_t * association);
+FbcAnd_addAssociation(FbcAnd_t* fa, const FbcAssociation_t* a);
 
 
+/**
+ * Creates a new FbcAnd_t object, adds it to this FbcAnd_t object and returns
+ * the FbcAnd_t object created.
+ *
+ * @param fa the FbcAnd_t structure to which the FbcAnd_t should be added.
+ *
+ * @return a new FbcAnd_t object instance.
+ *
+ * @copydetails doc_returned_unowned_pointer
+ *
+ * @memberof FbcAnd_t
+ */
 LIBSBML_EXTERN
-FbcAnd_t *
-FbcAnd_createAnd(FbcAnd_t * fa);
+FbcAnd_t*
+FbcAnd_createAnd(FbcAnd_t* fa);
 
 
+/**
+ * Creates a new FbcOr_t object, adds it to this FbcAnd_t object and returns
+ * the FbcOr_t object created.
+ *
+ * @param fa the FbcAnd_t structure to which the FbcOr_t should be added.
+ *
+ * @return a new FbcOr_t object instance.
+ *
+ * @copydetails doc_returned_unowned_pointer
+ *
+ * @memberof FbcAnd_t
+ */
 LIBSBML_EXTERN
-FbcOr_t *
-FbcAnd_createOr(FbcAnd_t * fa);
+FbcOr_t*
+FbcAnd_createOr(FbcAnd_t* fa);
 
 
+/**
+ * Creates a new GeneProductRef_t object, adds it to this FbcAnd_t object and
+ * returns the GeneProductRef_t object created.
+ *
+ * @param fa the FbcAnd_t structure to which the GeneProductRef_t should be
+ * added.
+ *
+ * @return a new GeneProductRef_t object instance.
+ *
+ * @copydetails doc_returned_unowned_pointer
+ *
+ * @memberof FbcAnd_t
+ */
 LIBSBML_EXTERN
-GeneProductRef_t *
-FbcAnd_createGeneProductRef(FbcAnd_t * fa);
+GeneProductRef_t*
+FbcAnd_createGeneProductRef(FbcAnd_t* fa);
 
 
+/**
+ * Returns a ListOf_t * containing FbcAssociation_t objects from this FbcAnd_t.
+ *
+ * @param fa the FbcAnd_t structure whose ListOfAssociations is sought.
+ *
+ * @return the ListOfAssociations from this FbcAnd_t as a ListOf_t *.
+ *
+ * @copydetails doc_returned_unowned_pointer
+ *
+ * @see FbcAnd_addAssociation()
+ * @see FbcAnd_getAssociationById()
+ * @see FbcAnd_getAssociation()
+ * @see FbcAnd_getNumAssociations()
+ * @see FbcAnd_removeAssociationById()
+ * @see FbcAnd_removeAssociation()
+ *
+ * @memberof FbcAnd_t
+ */
 LIBSBML_EXTERN
-ListOf_t *
-FbcAnd_getListOfFbcAssociations(FbcAnd_t * fa) ;
+ListOf_t*
+FbcAnd_getListOfFbcAssociations(FbcAnd_t* fa);
 
 
+/**
+ * Get an FbcAssociation_t from the FbcAnd_t.
+ *
+ * @param fa the FbcAnd_t structure to search.
+ *
+ * @param n an unsigned int representing the index of the FbcAssociation_t to
+ * retrieve.
+ *
+ * @return the nth FbcAssociation_t in the ListOfAssociations within this FbcAnd.
+ * If the index @p n is invalid, @c NULL is returned.
+ *
+ * @copydetails doc_returned_unowned_pointer
+ *
+ * @memberof FbcAnd_t
+ */
 LIBSBML_EXTERN
-FbcAssociation_t *
-FbcAnd_getAssociation(FbcAnd_t * fa, unsigned int n);
+FbcAssociation_t*
+FbcAnd_getAssociation(FbcAnd_t* fa, unsigned int n);
 
 
+/**
+ * Get an FbcAssociation_t from the FbcAnd_t.
+ *
+ * @param fa the FbcAnd_t structure to search.
+ *
+ * @param sid the identifier of the FbcAssociation_t to
+ * retrieve.
+ *
+ * @return the FbcAssociation_t with the given @p sid in the ListOfAssociations within this FbcAnd.
+ *
+ * @copydetails doc_returned_unowned_pointer
+ *
+ * @memberof FbcAnd_t
+ */
 LIBSBML_EXTERN
 FbcAssociation_t *
 FbcAnd_getAssociationById(FbcAnd_t * fa, const char * sid);
 
 
+/**
+ * Get the number of FbcAssociation_t objects in this FbcAnd_t.
+ *
+ * @param fa the FbcAnd_t structure to query.
+ *
+ * @return the number of FbcAssociation_t objects in this FbcAnd_t.
+ *
+ * @memberof FbcAnd_t
+ */
 LIBSBML_EXTERN
 unsigned int
-FbcAnd_getNumAssociations(FbcAnd_t * fa);
+FbcAnd_getNumAssociations(FbcAnd_t* fa);
 
 
+/**
+ * Removes the nth FbcAssociation_t from this FbcAnd_t and returns a pointer to
+ * it.
+ *
+ * @param fa the FbcAnd_t structure to search.
+ *
+ * @param n an unsigned int representing the index of the FbcAssociation_t to
+ * remove.
+ *
+ * @return a pointer to the nth FbcAssociation_t in this FbcAnd_t.
+ *
+ * @copydetails doc_warning_returns_owned_pointer
+ *
+ * @memberof FbcAnd_t
+ */
 LIBSBML_EXTERN
-FbcAssociation_t *
-FbcAnd_removeAssociation(FbcAnd_t * fa, unsigned int n);
+FbcAssociation_t*
+FbcAnd_removeAssociation(FbcAnd_t* fa, unsigned int n);
 
 
+/**
+ * Removes the FbcAssociation_t with the given identifier from this FbcAnd_t and returns a pointer to
+ * it.
+ *
+ * @param fa the FbcAnd_t structure to search.
+ *
+ * @param sid the identifier of the FbcAssociation_t to
+ * remove.
+ *
+ * @return a pointer to the nth FbcAssociation_t in this FbcAnd_t.
+ *
+ * @copydetails doc_warning_returns_owned_pointer
+ *
+ */
 LIBSBML_EXTERN
 FbcAssociation_t *
 FbcAnd_removeAssociationById(FbcAnd_t * fa, const char * sid);
 
 
 /**
- * Predicate returning @c 1 or *c 0 depending on whether all the required
- * attributes of the given FbcAnd_t structure have been set.
+ * Predicate returning @c 1 (true) if all the required attributes for this
+ * FbcAnd_t object have been set.
  *
- * @param fa the FbcAnd_t structure to check.
+ * @param fa the FbcAnd_t structure.
  *
- * @return @c 1 if all the required attributes for this
- * structure have been defined, @c 0 otherwise.
+ * @return @c 1 (true) to indicate that all the required attributes of this
+ * FbcAnd_t have been set, otherwise @c 0 (false) is returned.
  *
- * @member of FbcAnd_t
+ * @memberof FbcAnd_t
  */
 LIBSBML_EXTERN
 int
@@ -942,15 +1045,18 @@ FbcAnd_hasRequiredAttributes(const FbcAnd_t * fa);
 
 
 /**
- * Predicate returning @c 1 or *c 0 depending on whether all the required
- * sub-elements of the given FbcAnd_t structure have been set.
+ * Predicate returning @c 1 (true) if all the required elements for this
+ * FbcAnd_t object have been set.
  *
- * @param fa the FbcAnd_t structure to check.
+ * @param fa the FbcAnd_t structure.
  *
- * @return @c 1 if all the required sub-elements for this
- * structure have been defined, @c 0 otherwise.
+ * @return @c 1 (true) to indicate that all the required elements of this
+ * FbcAnd_t have been set, otherwise @c 0 (false) is returned.
  *
- * @member of FbcAnd_t
+ *
+ * @note The required elements for the FbcAnd_t object are:
+ *
+ * @memberof FbcAnd_t
  */
 LIBSBML_EXTERN
 int
