@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  * 
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -260,7 +260,7 @@ FluxBound::getReaction () const
 
 
 /*
- * @return true if the reaction of this SBML object has been set, false
+ * @return @c true if the reaction of this SBML object has been set, false
  * otherwise.
  */
 bool
@@ -348,7 +348,7 @@ FluxBound::getFluxBoundOperation () const
 
 
 /*
- * @return true if the operation of this SBML object has been set, false
+ * @return @c true if the operation of this SBML object has been set, false
  * otherwise.
  */
 bool
@@ -391,7 +391,7 @@ FluxBound::getValue () const
 
 
 /*
- * @return true if the value of this SBML object has been set, false
+ * @return @c true if the value of this SBML object has been set, false
  * otherwise.
  */
 bool
@@ -570,50 +570,6 @@ FluxBound::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this FluxBound.
- */
-int
-FluxBound::getAttribute(const std::string& attributeName,
-                        const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "id")
-  {
-    value = getId().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "name")
-  {
-    value = getName().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "reaction")
-  {
-    value = getReaction().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "operation")
-  {
-    value = const_cast<FluxBound*>(this)->getOperation().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -761,40 +717,6 @@ FluxBound::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this FluxBound.
- */
-int
-FluxBound::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "id")
-  {
-    return_value = setId(value);
-  }
-  else if (attributeName == "name")
-  {
-    return_value = setName(value);
-  }
-  else if (attributeName == "reaction")
-  {
-    return_value = setReaction(value);
-  }
-  else if (attributeName == "operation")
-  {
-    return_value = setOperation(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
