@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -47,9 +47,10 @@
  * must be the identifier of a Reaction object defined within the enclosing
  * model.
  *
- * The "operation" attribute takes a value from an enumeration
- * (#FluxBoundOperation_t) of Boolean operations that represent mathemetical
- * inequalities.  Possible values for "operation" include
+ * The "operation" attribute takes a value from
+ * @if clike the enumeration #FluxBoundOperation_t @else a set of constants
+ * whose names begin with <code>FLUXBOUND_</code>@endif@~ representing
+ * different mathematical inequalities. Possible values for "operation" include
  * <code>"greaterEqual"</code>, <code>"equal"</code>, and others.
  *
  * The "value" attribute takes a numerical value of type <code>double</code>,
@@ -591,26 +592,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Gets the value of the "attributeName" attribute of this FluxBound.
-   *
-   * @param attributeName, the name of the attribute to retrieve.
-   *
-   * @param value, the address of the value to record.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int getAttribute(const std::string& attributeName,
-                           const char* value) const;
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -725,26 +706,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Sets the value of the "attributeName" attribute of this FluxBound.
-   *
-   * @param attributeName, the name of the attribute to set.
-   *
-   * @param value, the value of the attribute to set.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int setAttribute(const std::string& attributeName, const char*
-    value);
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -879,6 +840,7 @@ public:
    * @param n the index number of the FluxBound to get.
    *
    * @return the nth FluxBound in this ListOfFluxBounds.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
@@ -891,6 +853,7 @@ public:
    * @param n the index number of the FluxBound to get.
    *
    * @return the nth FluxBound in this ListOfFluxBounds.
+   * If the index @p n is invalid, @c NULL is returned.
    *
    * @see size()
    */
