@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -567,50 +567,6 @@ GeneProduct::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this GeneProduct.
- */
-int
-GeneProduct::getAttribute(const std::string& attributeName,
-                          const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "id")
-  {
-    value = getId().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "name")
-  {
-    value = getName().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "label")
-  {
-    value = getLabel().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "associatedSpecies")
-  {
-    value = getAssociatedSpecies().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -750,40 +706,6 @@ GeneProduct::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this GeneProduct.
- */
-int
-GeneProduct::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "id")
-  {
-    return_value = setId(value);
-  }
-  else if (attributeName == "name")
-  {
-    return_value = setName(value);
-  }
-  else if (attributeName == "label")
-  {
-    return_value = setLabel(value);
-  }
-  else if (attributeName == "associatedSpecies")
-  {
-    return_value = setAssociatedSpecies(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1061,7 +983,7 @@ ListOfGeneProducts::clone () const
 
 /*
  * Get a GeneProduct from the ListOfGeneProducts by index.
-*/
+ */
 GeneProduct*
 ListOfGeneProducts::get(unsigned int n)
 {
@@ -1085,7 +1007,7 @@ ListOfGeneProducts::get(unsigned int n) const
 GeneProduct*
 ListOfGeneProducts::get(const std::string& sid)
 {
-	return const_cast<GeneProduct*>(
+  return const_cast<GeneProduct*>(
     static_cast<const ListOfGeneProducts&>(*this).get(sid));
 }
 
@@ -1137,7 +1059,7 @@ ListOfGeneProducts::addGeneProduct(const GeneProduct* gp)
   }
   else
   {
-	return append(gp);
+  return append(gp);
   }
 }
 
@@ -1150,7 +1072,7 @@ ListOfGeneProducts::addGeneProduct(const GeneProduct* gp)
 unsigned int 
 ListOfGeneProducts::getNumGeneProducts() const
 {
-	return size();
+  return size();
 }
 
 
@@ -1217,7 +1139,7 @@ ListOfGeneProducts::remove(const std::string& sid)
     mItems.erase(result);
   }
 
-	return static_cast <GeneProduct*> (item);
+  return static_cast <GeneProduct*> (item);
 }
 
 
@@ -1343,7 +1265,7 @@ LIBSBML_EXTERN
 const char *
 GeneProduct_getId(const GeneProduct_t * gp)
 {
-	return (gp != NULL && gp->isSetId()) ? gp->getId().c_str() : NULL;
+  return (gp != NULL && gp->isSetId()) ? gp->getId().c_str() : NULL;
 }
 
 
@@ -1351,7 +1273,7 @@ LIBSBML_EXTERN
 const char *
 GeneProduct_getName(const GeneProduct_t * gp)
 {
-	return (gp != NULL && gp->isSetName()) ? gp->getName().c_str() : NULL;
+  return (gp != NULL && gp->isSetName()) ? gp->getName().c_str() : NULL;
 }
 
 
@@ -1359,7 +1281,7 @@ LIBSBML_EXTERN
 const char *
 GeneProduct_getLabel(const GeneProduct_t * gp)
 {
-	return (gp != NULL && gp->isSetLabel()) ? gp->getLabel().c_str() : NULL;
+  return (gp != NULL && gp->isSetLabel()) ? gp->getLabel().c_str() : NULL;
 }
 
 
@@ -1367,7 +1289,7 @@ LIBSBML_EXTERN
 const char *
 GeneProduct_getAssociatedSpecies(const GeneProduct_t * gp)
 {
-	return (gp != NULL && gp->isSetAssociatedSpecies()) ? gp->getAssociatedSpecies().c_str() : NULL;
+  return (gp != NULL && gp->isSetAssociatedSpecies()) ? gp->getAssociatedSpecies().c_str() : NULL;
 }
 
 
@@ -1487,9 +1409,6 @@ GeneProduct_hasRequiredAttributes(const GeneProduct_t * gp)
 }
 
 
-/*
- *
- */
 LIBSBML_EXTERN
 GeneProduct_t *
 ListOfGeneProducts_getById(ListOf_t * lo, const char * sid)
@@ -1501,9 +1420,6 @@ ListOfGeneProducts_getById(ListOf_t * lo, const char * sid)
 }
 
 
-/*
- *
- */
 LIBSBML_EXTERN
 GeneProduct_t *
 ListOfGeneProducts_removeById(ListOf_t * lo, const char * sid)
