@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -56,8 +56,6 @@ Group::Group(unsigned int level,
              unsigned int version,
              unsigned int pkgVersion)
   : SBase(level, version)
-//  , mId ("")
-//  , mName ("")
   , mKind (GROUP_KIND_UNKNOWN)
   , mMembers (level, version, pkgVersion)
 {
@@ -71,8 +69,6 @@ Group::Group(unsigned int level,
  */
 Group::Group(GroupsPkgNamespaces *groupsns)
   : SBase(groupsns)
-//  , mId ("")
-//  , mName ("")
   , mKind (GROUP_KIND_UNKNOWN)
   , mMembers (groupsns)
 {
@@ -87,8 +83,6 @@ Group::Group(GroupsPkgNamespaces *groupsns)
  */
 Group::Group(const Group& orig)
   : SBase( orig )
-  //, mId ( orig.mId )
-  //, mName ( orig.mName )
   , mKind ( orig.mKind )
   , mMembers ( orig.mMembers )
 {
@@ -105,8 +99,6 @@ Group::operator=(const Group& rhs)
   if (&rhs != this)
   {
     SBase::operator=(rhs);
-    mId = rhs.mId;
-    mName = rhs.mName;
     mKind = rhs.mKind;
     mMembers = rhs.mMembers;
     connectToChild();
@@ -167,14 +159,21 @@ Group::getKind() const
 /*
  * Returns the value of the "kind" attribute of this Group.
  */
-const std::string&
+
+//const std::string&
+//Group::getKindAsString() const
+//{
+//  static const std::string code_str = GroupKind_toString(mKind);
+//  return code_str;
+//}
+//bgoli22
+std::string
 Group::getKindAsString() const
 {
-  static const std::string code_str = GroupKind_toString(mKind);
+  std::string code_str = GroupKind_toString(mKind);
   return code_str;
 }
 
-
 /*
  * Predicate returning @c true if this Group's "id" attribute is set.
  */
@@ -251,16 +250,23 @@ Group::setKind(const GroupKind_t kind)
 int
 Group::setKind(const std::string& kind)
 {
-  if (GroupKind_isValidString(kind.c_str()) == 0)
+  //if (GroupKind_isValidString(kind.c_str()) == 0)
+  //{
+  //  mKind = GROUP_KIND_UNKNOWN;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mKind = GroupKind_fromString(kind.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mKind = GroupKind_fromString(kind.c_str());
+  if (mKind == GROUP_KIND_UNKNOWN)
   {
-    mKind = GROUP_KIND_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mKind = GroupKind_fromString(kind.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -374,7 +380,7 @@ Group::getMember(const std::string& sid) const
 
 
 /*
- * Get a Member from the Group based on the IdRef to which it refers.
+ * Get a Member from the Group based on the element to which it refers.
  */
 const Member*
 Group::getMemberByIdRef(const std::string& sid) const
@@ -384,7 +390,7 @@ Group::getMemberByIdRef(const std::string& sid) const
 
 
 /*
- * Get a Member from the Group based on the IdRef to which it refers.
+ * Get a Member from the Group based on the element to which it refers.
  */
 Member*
 Group::getMemberByIdRef(const std::string& sid)
@@ -529,6 +535,7 @@ Group::hasRequiredAttributes() const
 }
 
 
+
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -623,6 +630,382 @@ Group::enablePackageInternal(const std::string& pkgURI,
 /** @endcond */
 
 
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::getAttribute(const std::string& attributeName, bool& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::getAttribute(const std::string& attributeName, int& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::getAttribute(const std::string& attributeName, double& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::getAttribute(const std::string& attributeName,
+                    unsigned int& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::getAttribute(const std::string& attributeName,
+                    std::string& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  if (return_value == LIBSBML_OPERATION_SUCCESS)
+  {
+    return return_value;
+  }
+
+  if (attributeName == "id")
+  {
+    value = getId();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  else if (attributeName == "name")
+  {
+    value = getName();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  else if (attributeName == "kind")
+  {
+    value = getKindAsString();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Predicate returning @c true if this Group's attribute "attributeName" is
+ * set.
+ */
+bool
+Group::isSetAttribute(const std::string& attributeName) const
+{
+  bool value = SBase::isSetAttribute(attributeName);
+
+  if (attributeName == "id")
+  {
+    value = isSetId();
+  }
+  else if (attributeName == "name")
+  {
+    value = isSetName();
+  }
+  else if (attributeName == "kind")
+  {
+    value = isSetKind();
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::setAttribute(const std::string& attributeName, bool value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::setAttribute(const std::string& attributeName, int value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::setAttribute(const std::string& attributeName, double value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::setAttribute(const std::string& attributeName, unsigned int value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::setAttribute(const std::string& attributeName,
+                    const std::string& value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  if (attributeName == "id")
+  {
+    return_value = setId(value);
+  }
+  else if (attributeName == "name")
+  {
+    return_value = setName(value);
+  }
+  else if (attributeName == "kind")
+  {
+    return_value = setKind(value);
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Unsets the value of the "attributeName" attribute of this Group.
+ */
+int
+Group::unsetAttribute(const std::string& attributeName)
+{
+  int value = SBase::unsetAttribute(attributeName);
+
+  if (attributeName == "id")
+  {
+    value = unsetId();
+  }
+  else if (attributeName == "name")
+  {
+    value = unsetName();
+  }
+  else if (attributeName == "kind")
+  {
+    value = unsetKind();
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Creates and returns an new "elementName" object in this Group.
+ */
+SBase*
+Group::createChildObject(const std::string& elementName)
+{
+  SBase* obj = NULL;
+
+  if (elementName == "member")
+  {
+    return createMember();
+  }
+
+  return obj;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Adds a new "elementName" object to this Group.
+ */
+int
+Group::addChildObject(const std::string& elementName, const SBase* element)
+{
+  if (elementName == "member" && element->getTypeCode() == SBML_GROUPS_MEMBER)
+  {
+    return addMember((const Member*)(element));
+  }
+
+  return LIBSBML_OPERATION_FAILED;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Removes and returns the new "elementName" object with the given id in this
+ * Group.
+ */
+SBase*
+Group::removeChildObject(const std::string& elementName,
+                         const std::string& id)
+{
+  if (elementName == "member")
+  {
+    return removeMember(id);
+  }
+
+  return NULL;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Returns the number of "elementName" in this Group.
+ */
+unsigned int
+Group::getNumObjects(const std::string& elementName)
+{
+  unsigned int n = 0;
+
+  if (elementName == "member")
+  {
+    return getNumMembers();
+  }
+
+  return n;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Returns the nth object of "objectName" in this Group.
+ */
+SBase*
+Group::getObject(const std::string& elementName, unsigned int index)
+{
+  SBase* obj = NULL;
+
+  if (elementName == "member")
+  {
+    return getMember(index);
+  }
+
+  return obj;
+}
+
+/** @endcond */
+
+
 /*
  * Returns the first child element that has the given @p id in the model-wide
  * SId namespace, or @c NULL if no such object is found.
@@ -830,10 +1213,9 @@ Group::readAttributes(const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mId) == false)
     {
-      log->logPackageError("groups", GroupsIdSyntaxRule,
-        pkgVersion, level, version, "The id on the <" 
-        + getElementName() + "> is '" + mId + "', which does not conform to the syntax.", 
-        getLine(), getColumn());
+      log->logPackageError("groups", GroupsIdSyntaxRule, pkgVersion, level,
+        version, "The id on the <" + getElementName() + "> is '" + mId + "', which "
+          "does not conform to the syntax.", getLine(), getColumn());
     }
   }
 
@@ -982,7 +1364,7 @@ Group_free(Group_t* g)
  * Returns the value of the "id" attribute of this Group_t.
  */
 LIBSBML_EXTERN
-const char *
+char *
 Group_getId(const Group_t * g)
 {
   if (g == NULL)
@@ -998,7 +1380,7 @@ Group_getId(const Group_t * g)
  * Returns the value of the "name" attribute of this Group_t.
  */
 LIBSBML_EXTERN
-const char *
+char *
 Group_getName(const Group_t * g)
 {
   if (g == NULL)
@@ -1038,7 +1420,7 @@ Group_getKindAsString(const Group_t * g)
 
 
 /*
- * Predicate returning @c 1 if this Group_t's "id" attribute is set.
+ * Predicate returning @c 1 (true) if this Group_t's "id" attribute is set.
  */
 LIBSBML_EXTERN
 int
@@ -1049,7 +1431,7 @@ Group_isSetId(const Group_t * g)
 
 
 /*
- * Predicate returning @c 1 if this Group_t's "name" attribute is set.
+ * Predicate returning @c 1 (true) if this Group_t's "name" attribute is set.
  */
 LIBSBML_EXTERN
 int
@@ -1060,7 +1442,7 @@ Group_isSetName(const Group_t * g)
 
 
 /*
- * Predicate returning @c 1 if this Group_t's "kind" attribute is set.
+ * Predicate returning @c 1 (true) if this Group_t's "kind" attribute is set.
  */
 LIBSBML_EXTERN
 int
@@ -1148,7 +1530,7 @@ Group_unsetKind(Group_t * g)
 
 
 /*
- * Returns a ListOf_t* containing Member_t objects from this Group_t.
+ * Returns a ListOf_t * containing Member_t objects from this Group_t.
  */
 LIBSBML_EXTERN
 ListOf_t*
@@ -1162,7 +1544,7 @@ Group_getListOfMembers(Group_t* g)
  * Get a Member_t from the Group_t.
  */
 LIBSBML_EXTERN
-const Member_t*
+Member_t*
 Group_getMember(Group_t* g, unsigned int n)
 {
   return (g != NULL) ? g->getMember(n) : NULL;
@@ -1173,7 +1555,7 @@ Group_getMember(Group_t* g, unsigned int n)
  * Get a Member_t from the Group_t based on its identifier.
  */
 LIBSBML_EXTERN
-const Member_t*
+Member_t*
 Group_getMemberById(Group_t* g, const char *sid)
 {
   return (g != NULL && sid != NULL) ? g->getMember(sid) : NULL;
@@ -1181,10 +1563,10 @@ Group_getMemberById(Group_t* g, const char *sid)
 
 
 /*
- * Get a Member_t from the Group_t based on the IdRef to which it refers.
+ * Get a Member_t from the Group_t based on the element to which it refers.
  */
 LIBSBML_EXTERN
-const Member_t*
+Member_t*
 Group_getMemberByIdRef(Group_t* g, const char *sid)
 {
   return (g != NULL && sid != NULL) ? g->getMemberByIdRef(sid) : NULL;
@@ -1249,8 +1631,8 @@ Group_removeMemberById(Group_t* g, const char* sid)
 
 
 /*
- * Predicate returning @c 1 if all the required attributes for this Group_t
- * object have been set.
+ * Predicate returning @c 1 (true) if all the required attributes for this
+ * Group_t object have been set.
  */
 LIBSBML_EXTERN
 int
@@ -1260,18 +1642,6 @@ Group_hasRequiredAttributes(const Group_t * g)
 }
 
 
-/*
- * Predicate returning @c 1 if all the required elements for this Group_t
- * object have been set.
- */
-LIBSBML_EXTERN
-int
-Group_hasRequiredElements(const Group_t * g)
-{
-  return (g != NULL) ? static_cast<int>(g->hasRequiredElements()) : 0;
-}
-
-
 
 
 LIBSBML_CPP_NAMESPACE_END
