@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -31,7 +31,22 @@
  * ------------------------------------------------------------------------ -->
  *
  * @class Member
- * @sbmlbrief{groups} TODO:Definition of the Member class.
+ * @sbmlbrief{groups} The Member class defines what objects are parts of
+ * a Group.
+ *
+ * The Member class has four optional attributes: id and name, which identify 
+ * the element, and idRef and metaIdRef which reference the identifiers of 
+ * other elements. There must be exactly one (and only one) method used to 
+ * reference another element: either idRef or metaIdRef may be defined, but 
+ * not both. (Multiple attributes are needed to account for the different types 
+ * of identifiers that a given object may have.) The referenced object 
+ * (including, potentially, another Group object) is thus made a member of the 
+ * group in which the Member object is contained.
+ * 
+ * Since Member is derived from SBase and, as mentioned above, SBase provides 
+ * both the ability to attach SBO terms as well as MIRIAM annotations, the 
+ * semantics of a given member in a model can be made more precise by reference 
+ * to external controlled vocabularies and ontologies.
  */
 
 
@@ -489,26 +504,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Gets the value of the "attributeName" attribute of this Member.
-   *
-   * @param attributeName, the name of the attribute to retrieve.
-   *
-   * @param value, the address of the value to record.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int getAttribute(const std::string& attributeName,
-                           const char* value) const;
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -623,26 +618,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Sets the value of the "attributeName" attribute of this Member.
-   *
-   * @param attributeName, the name of the attribute to set.
-   *
-   * @param value, the value of the attribute to set.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int setAttribute(const std::string& attributeName, const char*
-    value);
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -750,7 +725,7 @@ BEGIN_C_DECLS
  *
  * @copydetails doc_note_setting_lv_pkg
  *
- * @copydetails doc_returned_owned_pointer
+ * @copydetails doc_warning_returns_owned_pointer
  *
  * @memberof Member_t
  */
@@ -768,7 +743,7 @@ Member_create(unsigned int level,
  *
  * @return a (deep) copy of this Member_t object.
  *
- * @copydetails doc_returned_owned_pointer
+ * @copydetails doc_warning_returns_owned_pointer
  *
  * @memberof Member_t
  */
@@ -797,7 +772,7 @@ Member_free(Member_t* m);
  * @return the value of the "id" attribute of this Member_t as a pointer to a
  * string.
  *
- * @copydetails doc_returned_owned_char
+ * @copydetails doc_warning_returns_owned_char
  *
  * @memberof Member_t
  */
@@ -814,7 +789,7 @@ Member_getId(const Member_t * m);
  * @return the value of the "name" attribute of this Member_t as a pointer to a
  * string.
  *
- * @copydetails doc_returned_owned_char
+ * @copydetails doc_warning_returns_owned_char
  *
  * @memberof Member_t
  */
@@ -831,7 +806,7 @@ Member_getName(const Member_t * m);
  * @return the value of the "idRef" attribute of this Member_t as a pointer to
  * a string.
  *
- * @copydetails doc_returned_owned_char
+ * @copydetails doc_warning_returns_owned_char
  *
  * @memberof Member_t
  */
@@ -848,7 +823,7 @@ Member_getIdRef(const Member_t * m);
  * @return the value of the "metaIdRef" attribute of this Member_t as a pointer
  * to a string.
  *
- * @copydetails doc_returned_owned_char
+ * @copydetails doc_warning_returns_owned_char
  *
  * @memberof Member_t
  */
