@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -236,7 +236,7 @@ static const packageErrorTableEntry groupsErrorTable[] =
 
   // 4020305
   { GroupsGroupKindMustBeGroupKindEnum,
-    "The 'kind' attribute must be GroupKindEnum.",
+    "The 'kind' attribute must be GroupKind.",
     LIBSBML_CAT_GENERAL_CONSISTENCY,
     LIBSBML_SEV_ERROR,
     "The value of the attribute 'groups:kind' of a <group> object must conform "
