@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -305,24 +305,6 @@ QualModelPlugin::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this QualModelPlugin.
- */
-int
-QualModelPlugin::getAttribute(const std::string& attributeName,
-                              const char* value) const
-{
-  int return_value = SBasePlugin::getAttribute(attributeName, value);
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -428,24 +410,6 @@ QualModelPlugin::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this QualModelPlugin.
- */
-int
-QualModelPlugin::setAttribute(const std::string& attributeName,
-                              const char* value)
-{
-  int return_value = SBasePlugin::setAttribute(attributeName, value);
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
