@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -133,7 +133,7 @@ public:
   virtual void writeElements (XMLOutputStream& stream) const;
 
 
-  /** ------------------------------------------------------------------
+  /* ------------------------------------------------------------------
    *
    *  Additional public functions
    *
@@ -179,6 +179,7 @@ public:
    * @param n the index number of the QualitativeSpecies to get.
    *
    * @return the nth QualitativeSpecies in the ListOfQualitativeSpecies.
+   * If the index @p n is invalid, @c NULL is returned.
    */
   const QualitativeSpecies* getQualitativeSpecies (unsigned int n) const;
 
@@ -190,6 +191,7 @@ public:
    * @param n the index number of the QualitativeSpecies to get.
    *
    * @return the nth QualitativeSpecies in the ListOfQualitativeSpecies.
+   * If the index @p n is invalid, @c NULL is returned.
    */
   QualitativeSpecies* getQualitativeSpecies (unsigned int n);
 
@@ -229,7 +231,7 @@ public:
    *
    * @param qualitativeSpecies the QualitativeSpecies object to be added to the list of qual.
    *
-   * @copydetails doc_returns_success_code
+   * @copydetails doc_returns_one_success_code
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    */
   int addQualitativeSpecies (const QualitativeSpecies* qualitativeSpecies);
@@ -306,6 +308,7 @@ public:
    * @param n the index number of the Transition to get.
    *
    * @return the nth Transition in the ListOfTransitions.
+   * If the index @p n is invalid, @c NULL is returned.
    */
   const Transition* getTransition (unsigned int n) const;
 
@@ -317,6 +320,7 @@ public:
    * @param n the index number of the Transition to get.
    *
    * @return the nth Transition in the ListOfTransitions.
+   * If the index @p n is invalid, @c NULL is returned.
    */
   Transition* getTransition (unsigned int n);
 
@@ -356,7 +360,7 @@ public:
    *
    * @param transition the Transition object to be added to the list of qual.
    *
-   * @copydetails doc_returns_success_code
+   * @copydetails doc_returns_one_success_code
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    */
   int addTransition (const Transition* transition);
@@ -594,26 +598,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Gets the value of the "attributeName" attribute of this QualModelPlugin.
-   *
-   * @param attributeName, the name of the attribute to retrieve.
-   *
-   * @param value, the address of the value to record.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int getAttribute(const std::string& attributeName,
-                           const char* value) const;
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -728,26 +712,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Sets the value of the "attributeName" attribute of this QualModelPlugin.
-   *
-   * @param attributeName, the name of the attribute to set.
-   *
-   * @param value, the value of the attribute to set.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int setAttribute(const std::string& attributeName, const char*
-    value);
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -936,6 +900,7 @@ QualModelPlugin_getListOfQualitativeSpecies(QualModelPlugin_t* qmp);
  *
  * @return the nth QualitativeSpecies_t in the ListOfQualitativeSpecies within
  * this QualModelPlugin.
+ * If the index @p n is invalid, @c NULL is returned.
  *
  * @memberof QualModelPlugin_t
  */
@@ -1102,6 +1067,7 @@ QualModelPlugin_getListOfTransitions(QualModelPlugin_t* qmp);
  *
  * @return the nth Transition_t in the ListOfTransitions within this
  * QualModelPlugin.
+ * If the index @p n is invalid, @c NULL is returned.
  *
  * @memberof QualModelPlugin_t
  */
