@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -171,6 +171,8 @@ void
 }
 /** @endcond */
 
+/** @cond doxygenLibsbmlInternal */
+
 /* 
  * Parse L2 annotation if supported
  *
@@ -181,6 +183,8 @@ RenderLayoutPlugin::parseAnnotation(SBase *parentObject, XMLNode *annotation)
   mLocalRenderInformation.setSBMLDocument(mSBML);  
   parseLocalRenderAnnotation(annotation,(Layout*)parentObject);
 }
+/** @endcond */
+
 
 /** @cond doxygenLibsbmlInternal */
 /*
@@ -234,7 +238,7 @@ RenderLayoutPlugin::syncAnnotation (SBase *parentObject, XMLNode *pAnnotation)
  * Subclasses should override this method to read (and store) XHTML,
  * MathML, etc. directly from the XMLInputStream.
  *
- * @return true if the subclass read from the stream, false otherwise.
+ * @return @c true if the subclass read from the stream, false otherwise.
  */
 bool
 RenderLayoutPlugin::readOtherXML (SBase* parentObject, XMLInputStream& stream)
@@ -245,6 +249,8 @@ RenderLayoutPlugin::readOtherXML (SBase* parentObject, XMLInputStream& stream)
 }
 /** @endcond */
 
+
+/** @cond doxygenLibsbmlInternal */
 /* default for components that have no required elements */
 bool
   RenderLayoutPlugin::hasRequiredElements() const
@@ -253,6 +259,7 @@ bool
 
   return allPresent;
 }
+/** @endcond */
 
 
 
@@ -264,7 +271,7 @@ bool
 
 
 
-
+/** @cond doxygenLibsbmlInternal */
 /*
 * Sets the parent SBMLDocument of this SBML object.
 *
@@ -275,9 +282,15 @@ void
 {
   SBasePlugin::setSBMLDocument(d);
   mLocalRenderInformation.setSBMLDocument(d);
+  if (mLocalRenderInformation.isSetDefaultValues())
+  {
+    mLocalRenderInformation.getDefaultValues()->setSBMLDocument(d);
+  }
 }
+/** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
 /*
 * Sets the parent SBML object of this plugin object to
 * this object and child elements (if any).
@@ -289,8 +302,10 @@ void
   SBasePlugin::connectToParent(sbase);
   mLocalRenderInformation.connectToParent(sbase);
 }
+/** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
 /*
 * Enables/Disables the given package with child elements in this plugin
 * object (if any).
@@ -301,6 +316,7 @@ void
 {
   mLocalRenderInformation.enablePackageInternal(pkgURI, pkgPrefix, flag);
 }
+/** @endcond */
 
 
 /*
@@ -495,7 +511,7 @@ RenderLayoutPlugin::accept (SBMLVisitor& v) const
  * Subclasses should override this method to read (and store) XHTML,
  * MathML, etc. directly from the XMLInputStream.
  *
- * @return true if the subclass read from the stream, false otherwise.
+ * @return @c true if the subclass read from the stream, false otherwise.
  */
 bool
 RenderLayoutPlugin::readOtherXML (XMLInputStream& stream)
@@ -512,8 +528,8 @@ RenderLayoutPlugin::readOtherXML (XMLInputStream& stream)
       if (getLevel() < 3) 
       {
         logError(NotSchemaConformant, getLevel(), getVersion(),
-	        "Only one <annotation> element is permitted inside a "
-	        "particular containing element.");
+          "Only one <annotation> element is permitted inside a "
+          "particular containing element.");
       }
       else
       {
@@ -530,7 +546,7 @@ RenderLayoutPlugin::readOtherXML (XMLInputStream& stream)
       mLocalRenderInformation.setSBMLDocument(mSBML);  
       parseLocalRenderAnnotation(mAnnotation,this);
     }
-	
+  
     read = true;
   }
 
