@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -23,6 +23,13 @@
  * in the file named "LICENSE.txt" included with this software distribution
  * and also available online as http://sbml.org/software/libsbml/license.html
  *------------------------------------------------------------------------- -->
+ *
+ * @class RenderLayoutPlugin
+ * @sbmlbrief{render} LibSBML implementation for the extension to the
+ * Layout class by the Render extension.
+ *
+ * The Render package extends the Layout object from the Layout package 
+ * with the addition of an optional ListOfLocalRenderInformation object.
  */
 
 #ifndef RenderLayoutPlugin_h
@@ -42,6 +49,7 @@
 #include <sbml/extension/SBasePlugin.h>
 
 #include <sbml/packages/render/extension/RenderExtension.h>
+#include <sbml/packages/render/sbml/ListOfLocalRenderInformation.h>
 #include <sbml/packages/render/sbml/LocalRenderInformation.h>
 
 LIBSBML_CPP_NAMESPACE_BEGIN
@@ -169,7 +177,7 @@ public:
    * Returns a List of all child SBase objects, including those nested to an
    * arbitrary depth
    *
-   * @return a List* of pointers to all children objects.
+   * @return a List of pointers to all children objects.
    */
   virtual List* getAllElements(ElementFilter* filter=NULL);
 
@@ -283,14 +291,14 @@ public:
    * Subclasses should override this function if they have their specific
    * elements.
    *
-   * @return true if this pugin object has all the required elements,
-   * otherwise false will be returned.
+   * @return @c true if this pugin object has all the required elements,
+   * otherwise @c false will be returned.
    */
   virtual bool hasRequiredElements() const ;
   /** @endcond */
 
 
-  /** ------------------------------------------------------------------
+  /* ------------------------------------------------------------------
    *
    *  Additional public functions
    *
@@ -409,7 +417,7 @@ protected:
    * Subclasses should override this method to read (and store) XHTML,
    * MathML, etc. directly from the XMLInputStream.
    *
-   * @return true if the subclass read from the stream, false otherwise.
+   * @return @c true if the subclass read from the stream, @c false otherwise.
    */
   virtual bool readOtherXML (SBase* parentObject, XMLInputStream& stream);
 
