@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -30,6 +30,7 @@
 #include <sbml/packages/layout/common/LayoutExtensionTypes.h>
 #include <sbml/packages/render/util/RenderUtilities.h>
 #include <sbml/packages/render/sbml/GlobalRenderInformation.h>
+#include <sbml/packages/render/sbml/ListOfGlobalRenderInformation.h>
 #include <sbml/util/ElementFilter.h>
 
 
@@ -215,6 +216,7 @@ RenderListOfLayoutsPlugin::writeAttributes (XMLOutputStream& stream) const
 /** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
 /* default for components that have no required elements */
 bool
   RenderListOfLayoutsPlugin::hasRequiredElements() const
@@ -223,6 +225,7 @@ bool
 
   return allPresent;
 }
+/** @endcond */
 
 
 
@@ -235,6 +238,7 @@ bool
 
 
 
+/** @cond doxygenLibsbmlInternal */
 /*
 * Sets the parent SBMLDocument of this SBML object.
 *
@@ -245,10 +249,16 @@ void
 {
   SBasePlugin::setSBMLDocument(d);
   mGlobalRenderInformation.setSBMLDocument(d);  
+  if (mGlobalRenderInformation.isSetDefaultValues())
+  {
+    mGlobalRenderInformation.getDefaultValues()->setSBMLDocument(d);
+  }
 
 }
+/** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
 /*
 * Sets the parent SBML object of this plugin object to
 * this object and child elements (if any).
@@ -260,8 +270,10 @@ void
   SBasePlugin::connectToParent(sbase);
   mGlobalRenderInformation.connectToParent(sbase);
 }
+/** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
 /*
 * Enables/Disables the given package with child elements in this plugin
 * object (if any).
@@ -272,6 +284,7 @@ void
 {
   mGlobalRenderInformation.enablePackageInternal(pkgURI, pkgPrefix, flag);
 }
+/** @endcond */
 
 
 /** @cond doxygenLibsbmlInternal */
@@ -279,7 +292,7 @@ void
  * Subclasses should override this method to read (and store) XHTML,
  * MathML, etc. directly from the XMLInputStream.
  *
- * @return true if the subclass read from the stream, false otherwise.
+ * @return @c true if the subclass read from the stream, false otherwise.
  */
 bool
 RenderListOfLayoutsPlugin::readOtherXML (SBase* parentObject, XMLInputStream& stream)
@@ -290,13 +303,18 @@ RenderListOfLayoutsPlugin::readOtherXML (SBase* parentObject, XMLInputStream& st
 }
 /** @endcond */
 
+
+/** @cond doxygenLibsbmlInternal */
 void RenderListOfLayoutsPlugin::parseAnnotation()
 {
   ListOfLayouts* lol = (ListOfLayouts*)getParentSBMLObject();
 
   parseGlobalRenderAnnotation(lol->getAnnotation(), lol);
 }
+/** @endcond */
 
+
+/** @cond doxygenLibsbmlInternal */
 /* 
  * Parse L2 annotation if supported
  *
@@ -307,6 +325,8 @@ RenderListOfLayoutsPlugin::parseAnnotation(SBase *parentObject, XMLNode *annotat
   mGlobalRenderInformation.setSBMLDocument(mSBML);  
   parseGlobalRenderAnnotation(annotation,(ListOfLayouts*)parentObject);  
 }
+/** @endcond */
+
 
 /** @cond doxygenLibsbmlInternal */
 /*
