@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -55,7 +55,7 @@ AdvectionCoefficient::AdvectionCoefficient(unsigned int level,
                                            unsigned int pkgVersion)
   : SBase(level, version)
   , mVariable ("")
-  , mCoordinate (COORDINATEKIND_UNKNOWN)
+  , mCoordinate (SPATIAL_COORDINATEKIND_INVALID)
 {
   setSBMLNamespacesAndOwn(new SpatialPkgNamespaces(level, version,
     pkgVersion));
@@ -69,7 +69,7 @@ AdvectionCoefficient::AdvectionCoefficient(unsigned int level,
 AdvectionCoefficient::AdvectionCoefficient(SpatialPkgNamespaces *spatialns)
   : SBase(spatialns)
   , mVariable ("")
-  , mCoordinate (COORDINATEKIND_UNKNOWN)
+  , mCoordinate (SPATIAL_COORDINATEKIND_INVALID)
 {
   setElementNamespace(spatialns->getURI());
   loadPlugins(spatialns);
@@ -173,7 +173,7 @@ AdvectionCoefficient::isSetVariable() const
 bool
 AdvectionCoefficient::isSetCoordinate() const
 {
-  return (mCoordinate != COORDINATEKIND_UNKNOWN);
+  return (mCoordinate != SPATIAL_COORDINATEKIND_INVALID);
 }
 
 
@@ -203,7 +203,7 @@ AdvectionCoefficient::setCoordinate(const CoordinateKind_t coordinate)
 {
   if (CoordinateKind_isValid(coordinate) == 0)
   {
-    mCoordinate = COORDINATEKIND_UNKNOWN;
+    mCoordinate = SPATIAL_COORDINATEKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -222,7 +222,7 @@ AdvectionCoefficient::setCoordinate(const std::string& coordinate)
 {
   if (CoordinateKind_isValidString(coordinate.c_str()) == 0)
   {
-    mCoordinate = COORDINATEKIND_UNKNOWN;
+    mCoordinate = SPATIAL_COORDINATEKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -258,7 +258,7 @@ AdvectionCoefficient::unsetVariable()
 int
 AdvectionCoefficient::unsetCoordinate()
 {
-  mCoordinate = COORDINATEKIND_UNKNOWN;
+  mCoordinate = SPATIAL_COORDINATEKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -497,41 +497,6 @@ AdvectionCoefficient::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this
- * AdvectionCoefficient.
- */
-int
-AdvectionCoefficient::getAttribute(const std::string& attributeName,
-                                   const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "variable")
-  {
-    value = getVariable().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "coordinate")
-  {
-    value = getCoordinateAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -663,34 +628,6 @@ AdvectionCoefficient::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this
- * AdvectionCoefficient.
- */
-int
-AdvectionCoefficient::setAttribute(const std::string& attributeName,
-                                   const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "variable")
-  {
-    return_value = setVariable(value);
-  }
-  else if (attributeName == "coordinate")
-  {
-    return_value = setCoordinate(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -958,7 +895,7 @@ AdvectionCoefficient_getCoordinate(const AdvectionCoefficient_t * ac)
 {
   if (ac == NULL)
   {
-    return COORDINATEKIND_UNKNOWN;
+    return SPATIAL_COORDINATEKIND_INVALID;
   }
 
   return ac->getCoordinate();
