@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -57,7 +57,7 @@ AnalyticVolume::AnalyticVolume(unsigned int level,
                                unsigned int pkgVersion)
   : SBase(level, version)
   , mId ("")
-  , mFunctionType (FUNCTIONKIND_UNKNOWN)
+  , mFunctionType (SPATIAL_FUNCTIONKIND_INVALID)
   , mOrdinal (SBML_INT_MAX)
   , mIsSetOrdinal (false)
   , mDomainType ("")
@@ -75,7 +75,7 @@ AnalyticVolume::AnalyticVolume(unsigned int level,
 AnalyticVolume::AnalyticVolume(SpatialPkgNamespaces *spatialns)
   : SBase(spatialns)
   , mId ("")
-  , mFunctionType (FUNCTIONKIND_UNKNOWN)
+  , mFunctionType (SPATIAL_FUNCTIONKIND_INVALID)
   , mOrdinal (SBML_INT_MAX)
   , mIsSetOrdinal (false)
   , mDomainType ("")
@@ -227,7 +227,7 @@ AnalyticVolume::isSetId() const
 bool
 AnalyticVolume::isSetFunctionType() const
 {
-  return (mFunctionType != FUNCTIONKIND_UNKNOWN);
+  return (mFunctionType != SPATIAL_FUNCTIONKIND_INVALID);
 }
 
 
@@ -271,7 +271,7 @@ AnalyticVolume::setFunctionType(const FunctionKind_t functionType)
 {
   if (FunctionKind_isValid(functionType) == 0)
   {
-    mFunctionType = FUNCTIONKIND_UNKNOWN;
+    mFunctionType = SPATIAL_FUNCTIONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -290,7 +290,7 @@ AnalyticVolume::setFunctionType(const std::string& functionType)
 {
   if (FunctionKind_isValidString(functionType.c_str()) == 0)
   {
-    mFunctionType = FUNCTIONKIND_UNKNOWN;
+    mFunctionType = SPATIAL_FUNCTIONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -356,7 +356,7 @@ AnalyticVolume::unsetId()
 int
 AnalyticVolume::unsetFunctionType()
 {
-  mFunctionType = FUNCTIONKIND_UNKNOWN;
+  mFunctionType = SPATIAL_FUNCTIONKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -764,45 +764,6 @@ AnalyticVolume::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this AnalyticVolume.
- */
-int
-AnalyticVolume::getAttribute(const std::string& attributeName,
-                             const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "id")
-  {
-    value = getId().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "functionType")
-  {
-    value = getFunctionTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "domainType")
-  {
-    value = getDomainType().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -943,37 +904,6 @@ AnalyticVolume::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this AnalyticVolume.
- */
-int
-AnalyticVolume::setAttribute(const std::string& attributeName,
-                             const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "id")
-  {
-    return_value = setId(value);
-  }
-  else if (attributeName == "functionType")
-  {
-    return_value = setFunctionType(value);
-  }
-  else if (attributeName == "domainType")
-  {
-    return_value = setDomainType(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1362,7 +1292,7 @@ AnalyticVolume_getFunctionType(const AnalyticVolume_t * av)
 {
   if (av == NULL)
   {
-    return FUNCTIONKIND_UNKNOWN;
+    return SPATIAL_FUNCTIONKIND_INVALID;
   }
 
   return av->getFunctionType();
