@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -54,7 +54,7 @@ CSGPrimitive::CSGPrimitive(unsigned int level,
                            unsigned int version,
                            unsigned int pkgVersion)
   : CSGNode(level, version)
-  , mPrimitiveType (PRIMITIVEKIND_UNKNOWN)
+  , mPrimitiveType (SPATIAL_PRIMITIVEKIND_INVALID)
 {
   setSBMLNamespacesAndOwn(new SpatialPkgNamespaces(level, version,
     pkgVersion));
@@ -66,7 +66,7 @@ CSGPrimitive::CSGPrimitive(unsigned int level,
  */
 CSGPrimitive::CSGPrimitive(SpatialPkgNamespaces *spatialns)
   : CSGNode(spatialns)
-  , mPrimitiveType (PRIMITIVEKIND_UNKNOWN)
+  , mPrimitiveType (SPATIAL_PRIMITIVEKIND_INVALID)
 {
   setElementNamespace(spatialns->getURI());
   loadPlugins(spatialns);
@@ -145,7 +145,7 @@ CSGPrimitive::getPrimitiveTypeAsString() const
 bool
 CSGPrimitive::isSetPrimitiveType() const
 {
-  return (mPrimitiveType != PRIMITIVEKIND_UNKNOWN);
+  return (mPrimitiveType != SPATIAL_PRIMITIVEKIND_INVALID);
 }
 
 
@@ -157,7 +157,7 @@ CSGPrimitive::setPrimitiveType(const PrimitiveKind_t primitiveType)
 {
   if (PrimitiveKind_isValid(primitiveType) == 0)
   {
-    mPrimitiveType = PRIMITIVEKIND_UNKNOWN;
+    mPrimitiveType = SPATIAL_PRIMITIVEKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -176,7 +176,7 @@ CSGPrimitive::setPrimitiveType(const std::string& primitiveType)
 {
   if (PrimitiveKind_isValidString(primitiveType.c_str()) == 0)
   {
-    mPrimitiveType = PRIMITIVEKIND_UNKNOWN;
+    mPrimitiveType = SPATIAL_PRIMITIVEKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -193,7 +193,7 @@ CSGPrimitive::setPrimitiveType(const std::string& primitiveType)
 int
 CSGPrimitive::unsetPrimitiveType()
 {
-  mPrimitiveType = PRIMITIVEKIND_UNKNOWN;
+  mPrimitiveType = SPATIAL_PRIMITIVEKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -402,35 +402,6 @@ CSGPrimitive::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this CSGPrimitive.
- */
-int
-CSGPrimitive::getAttribute(const std::string& attributeName,
-                           const char* value) const
-{
-  int return_value = CSGNode::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "primitiveType")
-  {
-    value = getPrimitiveTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -546,29 +517,6 @@ CSGPrimitive::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this CSGPrimitive.
- */
-int
-CSGPrimitive::setAttribute(const std::string& attributeName,
-                           const char* value)
-{
-  int return_value = CSGNode::setAttribute(attributeName, value);
-
-  if (attributeName == "primitiveType")
-  {
-    return_value = setPrimitiveType(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -792,7 +740,7 @@ CSGPrimitive_getPrimitiveType(const CSGPrimitive_t * csgp)
 {
   if (csgp == NULL)
   {
-    return PRIMITIVEKIND_UNKNOWN;
+    return SPATIAL_PRIMITIVEKIND_INVALID;
   }
 
   return csgp->getPrimitiveType();
