@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -62,7 +62,7 @@ CSGSetOperator::CSGSetOperator(unsigned int level,
                                unsigned int version,
                                unsigned int pkgVersion)
   : CSGNode(level, version)
-  , mOperationType (SETOPERATION_UNKNOWN)
+  , mOperationType (SPATIAL_SETOPERATION_INVALID)
   , mComplementA ("")
   , mComplementB ("")
   , mCSGNodes (level, version, pkgVersion)
@@ -78,7 +78,7 @@ CSGSetOperator::CSGSetOperator(unsigned int level,
  */
 CSGSetOperator::CSGSetOperator(SpatialPkgNamespaces *spatialns)
   : CSGNode(spatialns)
-  , mOperationType (SETOPERATION_UNKNOWN)
+  , mOperationType (SPATIAL_SETOPERATION_INVALID)
   , mComplementA ("")
   , mComplementB ("")
   , mCSGNodes (spatialns)
@@ -154,10 +154,17 @@ CSGSetOperator::getOperationType() const
 /*
  * Returns the value of the "operationType" attribute of this CSGSetOperator.
  */
-const std::string&
+//const std::string&
+//CSGSetOperator::getOperationTypeAsString() const
+//{
+//  static const std::string code_str = SetOperation_toString(mOperationType);
+//  return code_str;
+//}
+//bgoli22
+std::string
 CSGSetOperator::getOperationTypeAsString() const
 {
-  static const std::string code_str = SetOperation_toString(mOperationType);
+  std::string code_str = SetOperation_toString(mOperationType);
   return code_str;
 }
 
@@ -189,7 +196,7 @@ CSGSetOperator::getComplementB() const
 bool
 CSGSetOperator::isSetOperationType() const
 {
-  return (mOperationType != SETOPERATION_UNKNOWN);
+  return (mOperationType != SPATIAL_SETOPERATION_INVALID);
 }
 
 
@@ -223,7 +230,7 @@ CSGSetOperator::setOperationType(const SetOperation_t operationType)
 {
   if (SetOperation_isValid(operationType) == 0)
   {
-    mOperationType = SETOPERATION_UNKNOWN;
+    mOperationType = SPATIAL_SETOPERATION_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -240,16 +247,23 @@ CSGSetOperator::setOperationType(const SetOperation_t operationType)
 int
 CSGSetOperator::setOperationType(const std::string& operationType)
 {
-  if (SetOperation_isValidString(operationType.c_str()) == 0)
+  //if (SetOperation_isValidString(operationType.c_str()) == 0)
+  //{
+  //  mOperationType = SPATIAL_SETOPERATION_INVALID;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mOperationType = SetOperation_fromString(operationType.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mOperationType = SetOperation_fromString(operationType.c_str());
+  if (mOperationType == SPATIAL_SETOPERATION_INVALID)
   {
-    mOperationType = SETOPERATION_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mOperationType = SetOperation_fromString(operationType.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -295,7 +309,7 @@ CSGSetOperator::setComplementB(const std::string& complementB)
 int
 CSGSetOperator::unsetOperationType()
 {
-  mOperationType = SETOPERATION_UNKNOWN;
+  mOperationType = SPATIAL_SETOPERATION_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -915,45 +929,6 @@ CSGSetOperator::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this CSGSetOperator.
- */
-int
-CSGSetOperator::getAttribute(const std::string& attributeName,
-                             const char* value) const
-{
-  int return_value = CSGNode::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "operationType")
-  {
-    value = getOperationTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "complementA")
-  {
-    value = getComplementA().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "complementB")
-  {
-    value = getComplementB().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1085,37 +1060,6 @@ CSGSetOperator::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this CSGSetOperator.
- */
-int
-CSGSetOperator::setAttribute(const std::string& attributeName,
-                             const char* value)
-{
-  int return_value = CSGNode::setAttribute(attributeName, value);
-
-  if (attributeName == "operationType")
-  {
-    return_value = setOperationType(value);
-  }
-  else if (attributeName == "complementA")
-  {
-    return_value = setComplementA(value);
-  }
-  else if (attributeName == "complementB")
-  {
-    return_value = setComplementB(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1556,7 +1500,7 @@ CSGSetOperator_getOperationType(const CSGSetOperator_t * csgso)
 {
   if (csgso == NULL)
   {
-    return SETOPERATION_UNKNOWN;
+    return SPATIAL_SETOPERATION_INVALID;
   }
 
   return csgso->getOperationType();
