@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -58,7 +58,7 @@ CoordinateComponent::CoordinateComponent(unsigned int level,
                                          unsigned int pkgVersion)
   : SBase(level, version)
   , mId ("")
-  , mType (COORDINATEKIND_UNKNOWN)
+  , mType (SPATIAL_COORDINATEKIND_INVALID)
   , mUnit ("")
   , mBoundaryMin (NULL)
   , mBoundaryMax (NULL)
@@ -76,7 +76,7 @@ CoordinateComponent::CoordinateComponent(unsigned int level,
 CoordinateComponent::CoordinateComponent(SpatialPkgNamespaces *spatialns)
   : SBase(spatialns)
   , mId ("")
-  , mType (COORDINATEKIND_UNKNOWN)
+  , mType (SPATIAL_COORDINATEKIND_INVALID)
   , mUnit ("")
   , mBoundaryMin (NULL)
   , mBoundaryMax (NULL)
@@ -202,6 +202,7 @@ CoordinateComponent::getTypeAsString() const
   static const std::string code_str = CoordinateKind_toString(mType);
   return code_str;
 }
+//bgoli22
 
 
 /*
@@ -232,7 +233,7 @@ CoordinateComponent::isSetId() const
 bool
 CoordinateComponent::isSetType() const
 {
-  return (mType != COORDINATEKIND_UNKNOWN);
+  return (mType != SPATIAL_COORDINATEKIND_INVALID);
 }
 
 
@@ -265,7 +266,7 @@ CoordinateComponent::setType(const CoordinateKind_t type)
 {
   if (CoordinateKind_isValid(type) == 0)
   {
-    mType = COORDINATEKIND_UNKNOWN;
+    mType = SPATIAL_COORDINATEKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -284,7 +285,7 @@ CoordinateComponent::setType(const std::string& type)
 {
   if (CoordinateKind_isValidString(type.c_str()) == 0)
   {
-    mType = COORDINATEKIND_UNKNOWN;
+    mType = SPATIAL_COORDINATEKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -292,6 +293,7 @@ CoordinateComponent::setType(const std::string& type)
     mType = CoordinateKind_fromString(type.c_str());
     return LIBSBML_OPERATION_SUCCESS;
   }
+  //bgoli22
 }
 
 
@@ -338,7 +340,7 @@ CoordinateComponent::unsetId()
 int
 CoordinateComponent::unsetType()
 {
-  mType = COORDINATEKIND_UNKNOWN;
+  mType = SPATIAL_COORDINATEKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -885,45 +887,6 @@ CoordinateComponent::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this CoordinateComponent.
- */
-int
-CoordinateComponent::getAttribute(const std::string& attributeName,
-                                  const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "id")
-  {
-    value = getId().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "type")
-  {
-    value = getTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "unit")
-  {
-    value = getUnit().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1057,37 +1020,6 @@ CoordinateComponent::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this CoordinateComponent.
- */
-int
-CoordinateComponent::setAttribute(const std::string& attributeName,
-                                  const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "id")
-  {
-    return_value = setId(value);
-  }
-  else if (attributeName == "type")
-  {
-    return_value = setType(value);
-  }
-  else if (attributeName == "unit")
-  {
-    return_value = setUnit(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1661,7 +1593,7 @@ CoordinateComponent_getType(const CoordinateComponent_t * cc)
 {
   if (cc == NULL)
   {
-    return COORDINATEKIND_UNKNOWN;
+    return SPATIAL_COORDINATEKIND_INVALID;
   }
 
   return cc->getType();
