@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -55,9 +55,9 @@ DiffusionCoefficient::DiffusionCoefficient(unsigned int level,
                                            unsigned int pkgVersion)
   : SBase(level, version)
   , mVariable ("")
-  , mType (DIFFUSIONKIND_UNKNOWN)
-  , mCoordinateReference1 (COORDINATEKIND_UNKNOWN)
-  , mCoordinateReference2 (COORDINATEKIND_UNKNOWN)
+  , mType (SPATIAL_DIFFUSIONKIND_INVALID)
+  , mCoordinateReference1 (SPATIAL_COORDINATEKIND_INVALID)
+  , mCoordinateReference2 (SPATIAL_COORDINATEKIND_INVALID)
 {
   setSBMLNamespacesAndOwn(new SpatialPkgNamespaces(level, version,
     pkgVersion));
@@ -71,9 +71,9 @@ DiffusionCoefficient::DiffusionCoefficient(unsigned int level,
 DiffusionCoefficient::DiffusionCoefficient(SpatialPkgNamespaces *spatialns)
   : SBase(spatialns)
   , mVariable ("")
-  , mType (DIFFUSIONKIND_UNKNOWN)
-  , mCoordinateReference1 (COORDINATEKIND_UNKNOWN)
-  , mCoordinateReference2 (COORDINATEKIND_UNKNOWN)
+  , mType (SPATIAL_DIFFUSIONKIND_INVALID)
+  , mCoordinateReference1 (SPATIAL_COORDINATEKIND_INVALID)
+  , mCoordinateReference2 (SPATIAL_COORDINATEKIND_INVALID)
 {
   setElementNamespace(spatialns->getURI());
   loadPlugins(spatialns);
@@ -153,10 +153,17 @@ DiffusionCoefficient::getType() const
 /*
  * Returns the value of the "type" attribute of this DiffusionCoefficient.
  */
-const std::string&
+//const std::string&
+//DiffusionCoefficient::getTypeAsString() const
+//{
+//  static const std::string code_str = DiffusionKind_toString(mType);
+//  return code_str;
+//}
+//bgoli22
+std::string
 DiffusionCoefficient::getTypeAsString() const
 {
-  static const std::string code_str = DiffusionKind_toString(mType);
+  std::string code_str = DiffusionKind_toString(mType);
   return code_str;
 }
 
@@ -200,15 +207,21 @@ DiffusionCoefficient::getCoordinateReference2() const
  * Returns the value of the "coordinateReference2" attribute of this
  * DiffusionCoefficient.
  */
-const std::string&
+//const std::string&
+//DiffusionCoefficient::getCoordinateReference2AsString() const
+//{
+//  static const std::string code_str =
+//    CoordinateKind_toString(mCoordinateReference2);
+//  return code_str;
+//}
+//bgoli22
+std::string
 DiffusionCoefficient::getCoordinateReference2AsString() const
 {
-  static const std::string code_str =
-    CoordinateKind_toString(mCoordinateReference2);
+  std::string code_str = CoordinateKind_toString(mCoordinateReference2);
   return code_str;
 }
 
-
 /*
  * Predicate returning @c true if this DiffusionCoefficient's "variable"
  * attribute is set.
@@ -227,7 +240,7 @@ DiffusionCoefficient::isSetVariable() const
 bool
 DiffusionCoefficient::isSetType() const
 {
-  return (mType != DIFFUSIONKIND_UNKNOWN);
+  return (mType != SPATIAL_DIFFUSIONKIND_INVALID);
 }
 
 
@@ -238,7 +251,7 @@ DiffusionCoefficient::isSetType() const
 bool
 DiffusionCoefficient::isSetCoordinateReference1() const
 {
-  return (mCoordinateReference1 != COORDINATEKIND_UNKNOWN);
+  return (mCoordinateReference1 != SPATIAL_COORDINATEKIND_INVALID);
 }
 
 
@@ -249,7 +262,7 @@ DiffusionCoefficient::isSetCoordinateReference1() const
 bool
 DiffusionCoefficient::isSetCoordinateReference2() const
 {
-  return (mCoordinateReference2 != COORDINATEKIND_UNKNOWN);
+  return (mCoordinateReference2 != SPATIAL_COORDINATEKIND_INVALID);
 }
 
 
@@ -279,7 +292,7 @@ DiffusionCoefficient::setType(const DiffusionKind_t type)
 {
   if (DiffusionKind_isValid(type) == 0)
   {
-    mType = DIFFUSIONKIND_UNKNOWN;
+    mType = SPATIAL_DIFFUSIONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -296,16 +309,23 @@ DiffusionCoefficient::setType(const DiffusionKind_t type)
 int
 DiffusionCoefficient::setType(const std::string& type)
 {
-  if (DiffusionKind_isValidString(type.c_str()) == 0)
+  //if (DiffusionKind_isValidString(type.c_str()) == 0)
+  //{
+  //  mType = SPATIAL_DIFFUSIONKIND_INVALID;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mType = DiffusionKind_fromString(type.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mType = DiffusionKind_fromString(type.c_str());
+  if (mType == SPATIAL_DIFFUSIONKIND_INVALID)
   {
-    mType = DIFFUSIONKIND_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mType = DiffusionKind_fromString(type.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -319,7 +339,7 @@ DiffusionCoefficient::setCoordinateReference1(const CoordinateKind_t
 {
   if (CoordinateKind_isValid(coordinateReference1) == 0)
   {
-    mCoordinateReference1 = COORDINATEKIND_UNKNOWN;
+    mCoordinateReference1 = SPATIAL_COORDINATEKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -340,7 +360,7 @@ DiffusionCoefficient::setCoordinateReference1(const std::string&
 {
   if (CoordinateKind_isValidString(coordinateReference1.c_str()) == 0)
   {
-    mCoordinateReference1 = COORDINATEKIND_UNKNOWN;
+    mCoordinateReference1 = SPATIAL_COORDINATEKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -362,7 +382,7 @@ DiffusionCoefficient::setCoordinateReference2(const CoordinateKind_t
 {
   if (CoordinateKind_isValid(coordinateReference2) == 0)
   {
-    mCoordinateReference2 = COORDINATEKIND_UNKNOWN;
+    mCoordinateReference2 = SPATIAL_COORDINATEKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -381,17 +401,25 @@ int
 DiffusionCoefficient::setCoordinateReference2(const std::string&
   coordinateReference2)
 {
-  if (CoordinateKind_isValidString(coordinateReference2.c_str()) == 0)
+  //if (CoordinateKind_isValidString(coordinateReference2.c_str()) == 0)
+  //{
+  //  mCoordinateReference2 = SPATIAL_COORDINATEKIND_INVALID;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mCoordinateReference2 =
+  //    CoordinateKind_fromString(coordinateReference2.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mCoordinateReference2 = 
+    CoordinateKind_fromString(coordinateReference2.c_str());
+  if (mCoordinateReference2 == SPATIAL_COORDINATEKIND_INVALID)
   {
-    mCoordinateReference2 = COORDINATEKIND_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mCoordinateReference2 =
-      CoordinateKind_fromString(coordinateReference2.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -420,7 +448,7 @@ DiffusionCoefficient::unsetVariable()
 int
 DiffusionCoefficient::unsetType()
 {
-  mType = DIFFUSIONKIND_UNKNOWN;
+  mType = SPATIAL_DIFFUSIONKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -432,7 +460,7 @@ DiffusionCoefficient::unsetType()
 int
 DiffusionCoefficient::unsetCoordinateReference1()
 {
-  mCoordinateReference1 = COORDINATEKIND_UNKNOWN;
+  mCoordinateReference1 = SPATIAL_COORDINATEKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -444,7 +472,7 @@ DiffusionCoefficient::unsetCoordinateReference1()
 int
 DiffusionCoefficient::unsetCoordinateReference2()
 {
-  mCoordinateReference2 = COORDINATEKIND_UNKNOWN;
+  mCoordinateReference2 = SPATIAL_COORDINATEKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -693,51 +721,6 @@ DiffusionCoefficient::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this
- * DiffusionCoefficient.
- */
-int
-DiffusionCoefficient::getAttribute(const std::string& attributeName,
-                                   const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "variable")
-  {
-    value = getVariable().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "type")
-  {
-    value = getTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "coordinateReference1")
-  {
-    value = getCoordinateReference1AsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "coordinateReference2")
-  {
-    value = getCoordinateReference2AsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -885,42 +868,6 @@ DiffusionCoefficient::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this
- * DiffusionCoefficient.
- */
-int
-DiffusionCoefficient::setAttribute(const std::string& attributeName,
-                                   const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "variable")
-  {
-    return_value = setVariable(value);
-  }
-  else if (attributeName == "type")
-  {
-    return_value = setType(value);
-  }
-  else if (attributeName == "coordinateReference1")
-  {
-    return_value = setCoordinateReference1(value);
-  }
-  else if (attributeName == "coordinateReference2")
-  {
-    return_value = setCoordinateReference2(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1288,7 +1235,7 @@ DiffusionCoefficient_getType(const DiffusionCoefficient_t * dc)
 {
   if (dc == NULL)
   {
-    return DIFFUSIONKIND_UNKNOWN;
+    return SPATIAL_DIFFUSIONKIND_INVALID;
   }
 
   return dc->getType();
@@ -1316,7 +1263,7 @@ DiffusionCoefficient_getCoordinateReference1(const DiffusionCoefficient_t * dc)
 {
   if (dc == NULL)
   {
-    return COORDINATEKIND_UNKNOWN;
+    return SPATIAL_COORDINATEKIND_INVALID;
   }
 
   return dc->getCoordinateReference1();
@@ -1346,7 +1293,7 @@ DiffusionCoefficient_getCoordinateReference2(const DiffusionCoefficient_t * dc)
 {
   if (dc == NULL)
   {
-    return COORDINATEKIND_UNKNOWN;
+    return SPATIAL_COORDINATEKIND_INVALID;
   }
 
   return dc->getCoordinateReference2();
