@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -170,7 +170,9 @@ public:
    * @return the value of the "type" attribute of this DiffusionCoefficient as
    * a string.
    */
-  const std::string& getTypeAsString() const;
+  std::string getTypeAsString() const;
+  //bgoli22
+
 
 
   /**
@@ -210,7 +212,9 @@ public:
    * @return the value of the "coordinateReference2" attribute of this
    * DiffusionCoefficient as a string.
    */
-  const std::string& getCoordinateReference2AsString() const;
+  std::string getCoordinateReference2AsString() const;
+  //bgoli22
+
 
 
   /**
@@ -600,27 +604,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Gets the value of the "attributeName" attribute of this
-   * DiffusionCoefficient.
-   *
-   * @param attributeName, the name of the attribute to retrieve.
-   *
-   * @param value, the address of the value to record.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int getAttribute(const std::string& attributeName,
-                           const char* value) const;
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -740,27 +723,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Sets the value of the "attributeName" attribute of this
-   * DiffusionCoefficient.
-   *
-   * @param attributeName, the name of the attribute to set.
-   *
-   * @param value, the value of the attribute to set.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int setAttribute(const std::string& attributeName, const char*
-    value);
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
