@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -62,7 +62,7 @@ Geometry::Geometry(unsigned int level,
                    unsigned int pkgVersion)
   : SBase(level, version)
   , mId ("")
-  , mCoordinateSystem (GEOMETRYKIND_UNKNOWN)
+  , mCoordinateSystem (SPATIAL_GEOMETRYKIND_INVALID)
   , mCoordinateComponents (level, version, pkgVersion)
   , mDomainTypes (level, version, pkgVersion)
   , mDomains (level, version, pkgVersion)
@@ -82,7 +82,7 @@ Geometry::Geometry(unsigned int level,
 Geometry::Geometry(SpatialPkgNamespaces *spatialns)
   : SBase(spatialns)
   , mId ("")
-  , mCoordinateSystem (GEOMETRYKIND_UNKNOWN)
+  , mCoordinateSystem (SPATIAL_GEOMETRYKIND_INVALID)
   , mCoordinateComponents (spatialns)
   , mDomainTypes (spatialns)
   , mDomains (spatialns)
@@ -179,10 +179,17 @@ Geometry::getCoordinateSystem() const
 /*
  * Returns the value of the "coordinateSystem" attribute of this Geometry.
  */
-const std::string&
+//const std::string&
+//Geometry::getCoordinateSystemAsString() const
+//{
+//  static const std::string code_str = GeometryKind_toString(mCoordinateSystem);
+//  return code_str;
+//}
+//bgoli22
+std::string
 Geometry::getCoordinateSystemAsString() const
 {
-  static const std::string code_str = GeometryKind_toString(mCoordinateSystem);
+  std::string code_str = GeometryKind_toString(mCoordinateSystem);
   return code_str;
 }
 
@@ -204,7 +211,7 @@ Geometry::isSetId() const
 bool
 Geometry::isSetCoordinateSystem() const
 {
-  return (mCoordinateSystem != GEOMETRYKIND_UNKNOWN);
+  return (mCoordinateSystem != SPATIAL_GEOMETRYKIND_INVALID);
 }
 
 
@@ -226,7 +233,7 @@ Geometry::setCoordinateSystem(const GeometryKind_t coordinateSystem)
 {
   if (GeometryKind_isValid(coordinateSystem) == 0)
   {
-    mCoordinateSystem = GEOMETRYKIND_UNKNOWN;
+    mCoordinateSystem = SPATIAL_GEOMETRYKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -243,16 +250,23 @@ Geometry::setCoordinateSystem(const GeometryKind_t coordinateSystem)
 int
 Geometry::setCoordinateSystem(const std::string& coordinateSystem)
 {
-  if (GeometryKind_isValidString(coordinateSystem.c_str()) == 0)
+  //if (GeometryKind_isValidString(coordinateSystem.c_str()) == 0)
+  //{
+  //  mCoordinateSystem = SPATIAL_GEOMETRYKIND_INVALID;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mCoordinateSystem = GeometryKind_fromString(coordinateSystem.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mCoordinateSystem = GeometryKind_fromString(coordinateSystem.c_str());
+  if (mCoordinateSystem == SPATIAL_GEOMETRYKIND_INVALID)
   {
-    mCoordinateSystem = GEOMETRYKIND_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mCoordinateSystem = GeometryKind_fromString(coordinateSystem.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -281,7 +295,7 @@ Geometry::unsetId()
 int
 Geometry::unsetCoordinateSystem()
 {
-  mCoordinateSystem = GEOMETRYKIND_UNKNOWN;
+  mCoordinateSystem = SPATIAL_GEOMETRYKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -1731,40 +1745,6 @@ Geometry::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this Geometry.
- */
-int
-Geometry::getAttribute(const std::string& attributeName,
-                       const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "id")
-  {
-    value = getId().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "coordinateSystem")
-  {
-    value = getCoordinateSystemAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1887,32 +1867,6 @@ Geometry::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this Geometry.
- */
-int
-Geometry::setAttribute(const std::string& attributeName, const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "id")
-  {
-    return_value = setId(value);
-  }
-  else if (attributeName == "coordinateSystem")
-  {
-    return_value = setCoordinateSystem(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1945,7 +1899,7 @@ Geometry::unsetAttribute(const std::string& attributeName)
  * Creates and returns an new "elementName" object in this Geometry.
  */
 SBase*
-Geometry::createObject(const std::string& elementName)
+Geometry::createChildObject(const std::string& elementName)
 {
   SBase* obj = NULL;
 
@@ -2461,7 +2415,7 @@ Geometry_getCoordinateSystem(const Geometry_t * g)
 {
   if (g == NULL)
   {
-    return GEOMETRYKIND_UNKNOWN;
+    return SPATIAL_GEOMETRYKIND_INVALID;
   }
 
   return g->getCoordinateSystem();
