@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -794,24 +794,6 @@ MixedGeometry::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this MixedGeometry.
- */
-int
-MixedGeometry::getAttribute(const std::string& attributeName,
-                            const char* value) const
-{
-  int return_value = GeometryDefinition::getAttribute(attributeName, value);
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -917,24 +899,6 @@ MixedGeometry::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this MixedGeometry.
- */
-int
-MixedGeometry::setAttribute(const std::string& attributeName,
-                            const char* value)
-{
-  int return_value = GeometryDefinition::setAttribute(attributeName, value);
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -958,7 +922,7 @@ MixedGeometry::unsetAttribute(const std::string& attributeName)
  * Creates and returns an new "elementName" object in this MixedGeometry.
  */
 SBase*
-MixedGeometry::createObject(const std::string& elementName)
+MixedGeometry::createChildObject(const std::string& elementName)
 {
   GeometryDefinition* obj = NULL;
 
