@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -678,24 +678,6 @@ ParametricGeometry::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this ParametricGeometry.
- */
-int
-ParametricGeometry::getAttribute(const std::string& attributeName,
-                                 const char* value) const
-{
-  int return_value = GeometryDefinition::getAttribute(attributeName, value);
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -802,24 +784,6 @@ ParametricGeometry::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this ParametricGeometry.
- */
-int
-ParametricGeometry::setAttribute(const std::string& attributeName,
-                                 const char* value)
-{
-  int return_value = GeometryDefinition::setAttribute(attributeName, value);
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -844,7 +808,7 @@ ParametricGeometry::unsetAttribute(const std::string& attributeName)
  * Creates and returns an new "elementName" object in this ParametricGeometry.
  */
 SBase*
-ParametricGeometry::createObject(const std::string& elementName)
+ParametricGeometry::createChildObject(const std::string& elementName)
 {
   GeometryDefinition* obj = NULL;
 
