@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -56,13 +56,13 @@ ParametricObject::ParametricObject(unsigned int level,
                                    unsigned int pkgVersion)
   : SBase(level, version)
   , mId ("")
-  , mPolygonType (POLYGONKIND_UNKNOWN)
+  , mPolygonType (SPATIAL_POLYGONKIND_INVALID)
   , mDomainType ("")
   , mPointIndex (NULL)
   , mPointIndexLength (SBML_INT_MAX)
   , mIsSetPointIndexLength (false)
-  , mCompression (COMPRESSIONKIND_UNKNOWN)
-  , mDataType (DATAKIND_UNKNOWN)
+  , mCompression (SPATIAL_COMPRESSIONKIND_INVALID)
+  , mDataType (SPATIAL_DATAKIND_INVALID)
 {
   setSBMLNamespacesAndOwn(new SpatialPkgNamespaces(level, version,
     pkgVersion));
@@ -75,13 +75,13 @@ ParametricObject::ParametricObject(unsigned int level,
 ParametricObject::ParametricObject(SpatialPkgNamespaces *spatialns)
   : SBase(spatialns)
   , mId ("")
-  , mPolygonType (POLYGONKIND_UNKNOWN)
+  , mPolygonType (SPATIAL_POLYGONKIND_INVALID)
   , mDomainType ("")
   , mPointIndex (NULL)
   , mPointIndexLength (SBML_INT_MAX)
   , mIsSetPointIndexLength (false)
-  , mCompression (COMPRESSIONKIND_UNKNOWN)
-  , mDataType (DATAKIND_UNKNOWN)
+  , mCompression (SPATIAL_COMPRESSIONKIND_INVALID)
+  , mDataType (SPATIAL_DATAKIND_INVALID)
 {
   setElementNamespace(spatialns->getURI());
   loadPlugins(spatialns);
@@ -178,14 +178,20 @@ ParametricObject::getPolygonType() const
 /*
  * Returns the value of the "polygonType" attribute of this ParametricObject.
  */
-const std::string&
+//const std::string&
+//ParametricObject::getPolygonTypeAsString() const
+//{
+//  static const std::string code_str = PolygonKind_toString(mPolygonType);
+//  return code_str;
+//}
+//bgoli22
+std::string
 ParametricObject::getPolygonTypeAsString() const
 {
-  static const std::string code_str = PolygonKind_toString(mPolygonType);
+  std::string code_str = PolygonKind_toString(mPolygonType);
   return code_str;
 }
 
-
 /*
  * Returns the value of the "domainType" attribute of this ParametricObject.
  */
@@ -256,14 +262,20 @@ ParametricObject::getDataType() const
 /*
  * Returns the value of the "dataType" attribute of this ParametricObject.
  */
-const std::string&
+//const std::string&
+//ParametricObject::getDataTypeAsString() const
+//{
+//  static const std::string code_str = DataKind_toString(mDataType);
+//  return code_str;
+//}
+//bgoli22
+std::string
 ParametricObject::getDataTypeAsString() const
 {
-  static const std::string code_str = DataKind_toString(mDataType);
+  std::string code_str = DataKind_toString(mDataType);
   return code_str;
 }
 
-
 /*
  * Predicate returning @c true if this ParametricObject's "id" attribute is
  * set.
@@ -282,7 +294,7 @@ ParametricObject::isSetId() const
 bool
 ParametricObject::isSetPolygonType() const
 {
-  return (mPolygonType != POLYGONKIND_UNKNOWN);
+  return (mPolygonType != SPATIAL_POLYGONKIND_INVALID);
 }
 
 
@@ -326,7 +338,7 @@ ParametricObject::isSetPointIndexLength() const
 bool
 ParametricObject::isSetCompression() const
 {
-  return (mCompression != COMPRESSIONKIND_UNKNOWN);
+  return (mCompression != SPATIAL_COMPRESSIONKIND_INVALID);
 }
 
 
@@ -337,7 +349,7 @@ ParametricObject::isSetCompression() const
 bool
 ParametricObject::isSetDataType() const
 {
-  return (mDataType != DATAKIND_UNKNOWN);
+  return (mDataType != SPATIAL_DATAKIND_INVALID);
 }
 
 
@@ -359,7 +371,7 @@ ParametricObject::setPolygonType(const PolygonKind_t polygonType)
 {
   if (PolygonKind_isValid(polygonType) == 0)
   {
-    mPolygonType = POLYGONKIND_UNKNOWN;
+    mPolygonType = SPATIAL_POLYGONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -378,7 +390,7 @@ ParametricObject::setPolygonType(const std::string& polygonType)
 {
   if (PolygonKind_isValidString(polygonType.c_str()) == 0)
   {
-    mPolygonType = POLYGONKIND_UNKNOWN;
+    mPolygonType = SPATIAL_POLYGONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -452,7 +464,7 @@ ParametricObject::setCompression(const CompressionKind_t compression)
 {
   if (CompressionKind_isValid(compression) == 0)
   {
-    mCompression = COMPRESSIONKIND_UNKNOWN;
+    mCompression = SPATIAL_COMPRESSIONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -469,16 +481,23 @@ ParametricObject::setCompression(const CompressionKind_t compression)
 int
 ParametricObject::setCompression(const std::string& compression)
 {
-  if (CompressionKind_isValidString(compression.c_str()) == 0)
+  //if (CompressionKind_isValidString(compression.c_str()) == 0)
+  //{
+  //  mCompression = SPATIAL_COMPRESSIONKIND_INVALID;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mCompression = CompressionKind_fromString(compression.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mCompression = CompressionKind_fromString(compression.c_str());
+  if (mCompression == SPATIAL_COMPRESSIONKIND_INVALID)
   {
-    mCompression = COMPRESSIONKIND_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mCompression = CompressionKind_fromString(compression.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -490,7 +509,7 @@ ParametricObject::setDataType(const DataKind_t dataType)
 {
   if (DataKind_isValid(dataType) == 0)
   {
-    mDataType = DATAKIND_UNKNOWN;
+    mDataType = SPATIAL_DATAKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -507,16 +526,23 @@ ParametricObject::setDataType(const DataKind_t dataType)
 int
 ParametricObject::setDataType(const std::string& dataType)
 {
-  if (DataKind_isValidString(dataType.c_str()) == 0)
+  //if (DataKind_isValidString(dataType.c_str()) == 0)
+  //{
+  //  mDataType = SPATIAL_DATAKIND_INVALID;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mDataType = DataKind_fromString(dataType.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mDataType = DataKind_fromString(dataType.c_str());
+  if (mDataType == SPATIAL_DATAKIND_INVALID)
   {
-    mDataType = DATAKIND_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mDataType = DataKind_fromString(dataType.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -545,7 +571,7 @@ ParametricObject::unsetId()
 int
 ParametricObject::unsetPolygonType()
 {
-  mPolygonType = POLYGONKIND_UNKNOWN;
+  mPolygonType = SPATIAL_POLYGONKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -613,7 +639,7 @@ ParametricObject::unsetPointIndexLength()
 int
 ParametricObject::unsetCompression()
 {
-  mCompression = COMPRESSIONKIND_UNKNOWN;
+  mCompression = SPATIAL_COMPRESSIONKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -624,7 +650,7 @@ ParametricObject::unsetCompression()
 int
 ParametricObject::unsetDataType()
 {
-  mDataType = DATAKIND_UNKNOWN;
+  mDataType = SPATIAL_DATAKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -930,55 +956,6 @@ ParametricObject::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this ParametricObject.
- */
-int
-ParametricObject::getAttribute(const std::string& attributeName,
-                               const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "id")
-  {
-    value = getId().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "polygonType")
-  {
-    value = getPolygonTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "domainType")
-  {
-    value = getDomainType().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "compression")
-  {
-    value = getCompressionAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "dataType")
-  {
-    value = getDataTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1139,45 +1116,6 @@ ParametricObject::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this ParametricObject.
- */
-int
-ParametricObject::setAttribute(const std::string& attributeName,
-                               const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "id")
-  {
-    return_value = setId(value);
-  }
-  else if (attributeName == "polygonType")
-  {
-    return_value = setPolygonType(value);
-  }
-  else if (attributeName == "domainType")
-  {
-    return_value = setDomainType(value);
-  }
-  else if (attributeName == "compression")
-  {
-    return_value = setCompression(value);
-  }
-  else if (attributeName == "dataType")
-  {
-    return_value = setDataType(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1678,7 +1616,7 @@ ParametricObject_getPolygonType(const ParametricObject_t * po)
 {
   if (po == NULL)
   {
-    return POLYGONKIND_UNKNOWN;
+    return SPATIAL_POLYGONKIND_INVALID;
   }
 
   return po->getPolygonType();
@@ -1734,7 +1672,7 @@ ParametricObject_getCompression(const ParametricObject_t * po)
 {
   if (po == NULL)
   {
-    return COMPRESSIONKIND_UNKNOWN;
+    return SPATIAL_COMPRESSIONKIND_INVALID;
   }
 
   return po->getCompression();
@@ -1761,7 +1699,7 @@ ParametricObject_getDataType(const ParametricObject_t * po)
 {
   if (po == NULL)
   {
-    return DATAKIND_UNKNOWN;
+    return SPATIAL_DATAKIND_INVALID;
   }
 
   return po->getDataType();
