@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -56,15 +56,15 @@ SampledField::SampledField(unsigned int level,
                            unsigned int pkgVersion)
   : SBase(level, version)
   , mId ("")
-  , mDataType (DATAKIND_UNKNOWN)
+  , mDataType (SPATIAL_DATAKIND_INVALID)
   , mNumSamples1 (SBML_INT_MAX)
   , mIsSetNumSamples1 (false)
   , mNumSamples2 (SBML_INT_MAX)
   , mIsSetNumSamples2 (false)
   , mNumSamples3 (SBML_INT_MAX)
   , mIsSetNumSamples3 (false)
-  , mInterpolationType (INTERPOLATIONKIND_UNKNOWN)
-  , mCompression (COMPRESSIONKIND_UNKNOWN)
+  , mInterpolationType (SPATIAL_INTERPOLATIONKIND_INVALID)
+  , mCompression (SPATIAL_COMPRESSIONKIND_INVALID)
   , mSamples (NULL)
   , mSamplesLength (SBML_INT_MAX)
   , mIsSetSamplesLength (false)
@@ -82,15 +82,15 @@ SampledField::SampledField(unsigned int level,
 SampledField::SampledField(SpatialPkgNamespaces *spatialns)
   : SBase(spatialns)
   , mId ("")
-  , mDataType (DATAKIND_UNKNOWN)
+  , mDataType (SPATIAL_DATAKIND_INVALID)
   , mNumSamples1 (SBML_INT_MAX)
   , mIsSetNumSamples1 (false)
   , mNumSamples2 (SBML_INT_MAX)
   , mIsSetNumSamples2 (false)
   , mNumSamples3 (SBML_INT_MAX)
   , mIsSetNumSamples3 (false)
-  , mInterpolationType (INTERPOLATIONKIND_UNKNOWN)
-  , mCompression (COMPRESSIONKIND_UNKNOWN)
+  , mInterpolationType (SPATIAL_INTERPOLATIONKIND_INVALID)
+  , mCompression (SPATIAL_COMPRESSIONKIND_INVALID)
   , mSamples (NULL)
   , mSamplesLength (SBML_INT_MAX)
   , mIsSetSamplesLength (false)
@@ -217,10 +217,17 @@ SampledField::getDataType() const
 /*
  * Returns the value of the "dataType" attribute of this SampledField.
  */
-const std::string&
+//const std::string&
+//SampledField::getDataTypeAsString() const
+//{
+//  static const std::string code_str = DataKind_toString(mDataType);
+//  return code_str;
+//}
+//bgoli22
+std::string
 SampledField::getDataTypeAsString() const
 {
-  static const std::string code_str = DataKind_toString(mDataType);
+  std::string code_str = DataKind_toString(mDataType);
   return code_str;
 }
 
@@ -268,15 +275,21 @@ SampledField::getInterpolationType() const
 /*
  * Returns the value of the "interpolationType" attribute of this SampledField.
  */
-const std::string&
+//const std::string&
+//SampledField::getInterpolationTypeAsString() const
+//{
+//  static const std::string code_str =
+//    InterpolationKind_toString(mInterpolationType);
+//  return code_str;
+//}
+//bgoli22
+std::string
 SampledField::getInterpolationTypeAsString() const
 {
-  static const std::string code_str =
-    InterpolationKind_toString(mInterpolationType);
+  std::string code_str = InterpolationKind_toString(mInterpolationType);
   return code_str;
 }
 
-
 /*
  * Returns the value of the "compression" attribute of this SampledField.
  */
@@ -290,10 +303,17 @@ SampledField::getCompression() const
 /*
  * Returns the value of the "compression" attribute of this SampledField.
  */
-const std::string&
+//const std::string&
+//SampledField::getCompressionAsString() const
+//{
+//  static const std::string code_str = CompressionKind_toString(mCompression);
+//  return code_str;
+//}
+//bgoli22
+std::string
 SampledField::getCompressionAsString() const
 {
-  static const std::string code_str = CompressionKind_toString(mCompression);
+  std::string code_str = CompressionKind_toString(mCompression);
   return code_str;
 }
 
@@ -340,7 +360,7 @@ SampledField::isSetId() const
 bool
 SampledField::isSetDataType() const
 {
-  return (mDataType != DATAKIND_UNKNOWN);
+  return (mDataType != SPATIAL_DATAKIND_INVALID);
 }
 
 
@@ -384,7 +404,7 @@ SampledField::isSetNumSamples3() const
 bool
 SampledField::isSetInterpolationType() const
 {
-  return (mInterpolationType != INTERPOLATIONKIND_UNKNOWN);
+  return (mInterpolationType != SPATIAL_INTERPOLATIONKIND_INVALID);
 }
 
 
@@ -395,7 +415,7 @@ SampledField::isSetInterpolationType() const
 bool
 SampledField::isSetCompression() const
 {
-  return (mCompression != COMPRESSIONKIND_UNKNOWN);
+  return (mCompression != SPATIAL_COMPRESSIONKIND_INVALID);
 }
 
 
@@ -439,7 +459,7 @@ SampledField::setDataType(const DataKind_t dataType)
 {
   if (DataKind_isValid(dataType) == 0)
   {
-    mDataType = DATAKIND_UNKNOWN;
+    mDataType = SPATIAL_DATAKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -456,16 +476,23 @@ SampledField::setDataType(const DataKind_t dataType)
 int
 SampledField::setDataType(const std::string& dataType)
 {
-  if (DataKind_isValidString(dataType.c_str()) == 0)
+  //if (DataKind_isValidString(dataType.c_str()) == 0)
+  //{
+  //  mDataType = SPATIAL_DATAKIND_INVALID;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mDataType = DataKind_fromString(dataType.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mDataType = DataKind_fromString(dataType.c_str());
+  if (mDataType == SPATIAL_DATAKIND_INVALID)
   {
-    mDataType = DATAKIND_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mDataType = DataKind_fromString(dataType.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -513,7 +540,7 @@ SampledField::setInterpolationType(const InterpolationKind_t interpolationType)
 {
   if (InterpolationKind_isValid(interpolationType) == 0)
   {
-    mInterpolationType = INTERPOLATIONKIND_UNKNOWN;
+    mInterpolationType = SPATIAL_INTERPOLATIONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -530,17 +557,24 @@ SampledField::setInterpolationType(const InterpolationKind_t interpolationType)
 int
 SampledField::setInterpolationType(const std::string& interpolationType)
 {
-  if (InterpolationKind_isValidString(interpolationType.c_str()) == 0)
+  //if (InterpolationKind_isValidString(interpolationType.c_str()) == 0)
+  //{
+  //  mInterpolationType = SPATIAL_INTERPOLATIONKIND_INVALID;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mInterpolationType =
+  //    InterpolationKind_fromString(interpolationType.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mInterpolationType = InterpolationKind_fromString(interpolationType.c_str());
+  if (mInterpolationType == SPATIAL_INTERPOLATIONKIND_INVALID)
   {
-    mInterpolationType = INTERPOLATIONKIND_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mInterpolationType =
-      InterpolationKind_fromString(interpolationType.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -552,7 +586,7 @@ SampledField::setCompression(const CompressionKind_t compression)
 {
   if (CompressionKind_isValid(compression) == 0)
   {
-    mCompression = COMPRESSIONKIND_UNKNOWN;
+    mCompression = SPATIAL_COMPRESSIONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -571,7 +605,7 @@ SampledField::setCompression(const std::string& compression)
 {
   if (CompressionKind_isValidString(compression.c_str()) == 0)
   {
-    mCompression = COMPRESSIONKIND_UNKNOWN;
+    mCompression = SPATIAL_COMPRESSIONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -579,6 +613,13 @@ SampledField::setCompression(const std::string& compression)
     mCompression = CompressionKind_fromString(compression.c_str());
     return LIBSBML_OPERATION_SUCCESS;
   }
+  //bgoli22
+  mCompression = CompressionKind_fromString(compression.c_str());
+  if (mCompression == SPATIAL_COMPRESSIONKIND_INVALID)
+  {
+    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -644,7 +685,7 @@ SampledField::unsetId()
 int
 SampledField::unsetDataType()
 {
-  mDataType = DATAKIND_UNKNOWN;
+  mDataType = SPATIAL_DATAKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -715,7 +756,7 @@ SampledField::unsetNumSamples3()
 int
 SampledField::unsetInterpolationType()
 {
-  mInterpolationType = INTERPOLATIONKIND_UNKNOWN;
+  mInterpolationType = SPATIAL_INTERPOLATIONKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -726,7 +767,7 @@ SampledField::unsetInterpolationType()
 int
 SampledField::unsetCompression()
 {
-  mCompression = COMPRESSIONKIND_UNKNOWN;
+  mCompression = SPATIAL_COMPRESSIONKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -1069,50 +1110,6 @@ SampledField::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this SampledField.
- */
-int
-SampledField::getAttribute(const std::string& attributeName,
-                           const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "id")
-  {
-    value = getId().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "dataType")
-  {
-    value = getDataTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "interpolationType")
-  {
-    value = getInterpolationTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "compression")
-  {
-    value = getCompressionAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1289,41 +1286,6 @@ SampledField::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this SampledField.
- */
-int
-SampledField::setAttribute(const std::string& attributeName,
-                           const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "id")
-  {
-    return_value = setId(value);
-  }
-  else if (attributeName == "dataType")
-  {
-    return_value = setDataType(value);
-  }
-  else if (attributeName == "interpolationType")
-  {
-    return_value = setInterpolationType(value);
-  }
-  else if (attributeName == "compression")
-  {
-    return_value = setCompression(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -2045,7 +2007,7 @@ SampledField_getDataType(const SampledField_t * sf)
 {
   if (sf == NULL)
   {
-    return DATAKIND_UNKNOWN;
+    return SPATIAL_DATAKIND_INVALID;
   }
 
   return sf->getDataType();
@@ -2106,7 +2068,7 @@ SampledField_getInterpolationType(const SampledField_t * sf)
 {
   if (sf == NULL)
   {
-    return INTERPOLATIONKIND_UNKNOWN;
+    return SPATIAL_INTERPOLATIONKIND_INVALID;
   }
 
   return sf->getInterpolationType();
@@ -2134,7 +2096,7 @@ SampledField_getCompression(const SampledField_t * sf)
 {
   if (sf == NULL)
   {
-    return COMPRESSIONKIND_UNKNOWN;
+    return SPATIAL_COMPRESSIONKIND_INVALID;
   }
 
   return sf->getCompression();
