@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -174,7 +174,8 @@ public:
    * @return the value of the "dataType" attribute of this SampledField as a
    * string.
    */
-  const std::string& getDataTypeAsString() const;
+  std::string getDataTypeAsString() const;
+  //bgoli22
 
 
   /**
@@ -221,7 +222,8 @@ public:
    * @return the value of the "interpolationType" attribute of this
    * SampledField as a string.
    */
-  const std::string& getInterpolationTypeAsString() const;
+  std::string getInterpolationTypeAsString() const;
+  //bgoli22
 
 
   /**
@@ -239,8 +241,9 @@ public:
    * @return the value of the "compression" attribute of this SampledField as a
    * string.
    */
-  const std::string& getCompressionAsString() const;
-
+  std::string getCompressionAsString() const;
+  //bgoli22
+  
 
   /**
    * Returns the value of the "samples" attribute of this SampledField.
@@ -814,26 +817,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Gets the value of the "attributeName" attribute of this SampledField.
-   *
-   * @param attributeName, the name of the attribute to retrieve.
-   *
-   * @param value, the address of the value to record.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int getAttribute(const std::string& attributeName,
-                           const char* value) const;
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
@@ -948,26 +931,6 @@ public:
 
 
 
-  /** @cond doxygenLibsbmlInternal */
-
-  /**
-   * Sets the value of the "attributeName" attribute of this SampledField.
-   *
-   * @param attributeName, the name of the attribute to set.
-   *
-   * @param value, the value of the attribute to set.
-   *
-   * @copydetails doc_returns_success_code
-   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   */
-  virtual int setAttribute(const std::string& attributeName, const char*
-    value);
-
-  /** @endcond */
-
-
-
   /** @cond doxygenLibsbmlInternal */
 
   /**
