@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -636,36 +636,6 @@ SampledFieldGeometry::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this
- * SampledFieldGeometry.
- */
-int
-SampledFieldGeometry::getAttribute(const std::string& attributeName,
-                                   const char* value) const
-{
-  int return_value = GeometryDefinition::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "sampledField")
-  {
-    value = getSampledField().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -789,30 +759,6 @@ SampledFieldGeometry::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this
- * SampledFieldGeometry.
- */
-int
-SampledFieldGeometry::setAttribute(const std::string& attributeName,
-                                   const char* value)
-{
-  int return_value = GeometryDefinition::setAttribute(attributeName, value);
-
-  if (attributeName == "sampledField")
-  {
-    return_value = setSampledField(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -843,7 +789,7 @@ SampledFieldGeometry::unsetAttribute(const std::string& attributeName)
  * SampledFieldGeometry.
  */
 SBase*
-SampledFieldGeometry::createObject(const std::string& elementName)
+SampledFieldGeometry::createChildObject(const std::string& elementName)
 {
   GeometryDefinition* obj = NULL;
 
