@@ -7,7 +7,7 @@
  * This file is part of libSBML. Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  * 1. California Institute of Technology, Pasadena, CA, USA
  * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  * 3. University of Heidelberg, Heidelberg, Germany
@@ -55,11 +55,11 @@ SpatialPoints::SpatialPoints(unsigned int level,
                              unsigned int pkgVersion)
   : SBase(level, version)
   , mId ("")
-  , mCompression (COMPRESSIONKIND_UNKNOWN)
+  , mCompression (SPATIAL_COMPRESSIONKIND_INVALID)
   , mArrayData (NULL)
   , mArrayDataLength (SBML_INT_MAX)
   , mIsSetArrayDataLength (false)
-  , mDataType (DATAKIND_UNKNOWN)
+  , mDataType (SPATIAL_DATAKIND_INVALID)
 {
   setSBMLNamespacesAndOwn(new SpatialPkgNamespaces(level, version,
     pkgVersion));
@@ -72,11 +72,11 @@ SpatialPoints::SpatialPoints(unsigned int level,
 SpatialPoints::SpatialPoints(SpatialPkgNamespaces *spatialns)
   : SBase(spatialns)
   , mId ("")
-  , mCompression (COMPRESSIONKIND_UNKNOWN)
+  , mCompression (SPATIAL_COMPRESSIONKIND_INVALID)
   , mArrayData (NULL)
   , mArrayDataLength (SBML_INT_MAX)
   , mIsSetArrayDataLength (false)
-  , mDataType (DATAKIND_UNKNOWN)
+  , mDataType (SPATIAL_DATAKIND_INVALID)
 {
   setElementNamespace(spatialns->getURI());
   loadPlugins(spatialns);
@@ -215,10 +215,17 @@ SpatialPoints::getDataType() const
 /*
  * Returns the value of the "dataType" attribute of this SpatialPoints.
  */
-const std::string&
+//const std::string&
+//SpatialPoints::getDataTypeAsString() const
+//{
+//  static const std::string code_str = DataKind_toString(mDataType);
+//  return code_str;
+//}
+//bgoli22
+std::string
 SpatialPoints::getDataTypeAsString() const
 {
-  static const std::string code_str = DataKind_toString(mDataType);
+  std::string code_str = DataKind_toString(mDataType);
   return code_str;
 }
 
@@ -240,7 +247,7 @@ SpatialPoints::isSetId() const
 bool
 SpatialPoints::isSetCompression() const
 {
-  return (mCompression != COMPRESSIONKIND_UNKNOWN);
+  return (mCompression != SPATIAL_COMPRESSIONKIND_INVALID);
 }
 
 
@@ -273,7 +280,7 @@ SpatialPoints::isSetArrayDataLength() const
 bool
 SpatialPoints::isSetDataType() const
 {
-  return (mDataType != DATAKIND_UNKNOWN);
+  return (mDataType != SPATIAL_DATAKIND_INVALID);
 }
 
 
@@ -295,7 +302,7 @@ SpatialPoints::setCompression(const CompressionKind_t compression)
 {
   if (CompressionKind_isValid(compression) == 0)
   {
-    mCompression = COMPRESSIONKIND_UNKNOWN;
+    mCompression = SPATIAL_COMPRESSIONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -314,7 +321,7 @@ SpatialPoints::setCompression(const std::string& compression)
 {
   if (CompressionKind_isValidString(compression.c_str()) == 0)
   {
-    mCompression = COMPRESSIONKIND_UNKNOWN;
+    mCompression = SPATIAL_COMPRESSIONKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -370,7 +377,7 @@ SpatialPoints::setDataType(const DataKind_t dataType)
 {
   if (DataKind_isValid(dataType) == 0)
   {
-    mDataType = DATAKIND_UNKNOWN;
+    mDataType = SPATIAL_DATAKIND_INVALID;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
   else
@@ -387,16 +394,23 @@ SpatialPoints::setDataType(const DataKind_t dataType)
 int
 SpatialPoints::setDataType(const std::string& dataType)
 {
-  if (DataKind_isValidString(dataType.c_str()) == 0)
+  //if (DataKind_isValidString(dataType.c_str()) == 0)
+  //{
+  //  mDataType = SPATIAL_DATAKIND_INVALID;
+  //  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  //}
+  //else
+  //{
+  //  mDataType = DataKind_fromString(dataType.c_str());
+  //  return LIBSBML_OPERATION_SUCCESS;
+  //}
+  //bgoli22
+  mDataType = DataKind_fromString(dataType.c_str());
+  if (mDataType == SPATIAL_DATAKIND_INVALID)
   {
-    mDataType = DATAKIND_UNKNOWN;
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
-  else
-  {
-    mDataType = DataKind_fromString(dataType.c_str());
-    return LIBSBML_OPERATION_SUCCESS;
-  }
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -425,7 +439,7 @@ SpatialPoints::unsetId()
 int
 SpatialPoints::unsetCompression()
 {
-  mCompression = COMPRESSIONKIND_UNKNOWN;
+  mCompression = SPATIAL_COMPRESSIONKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -473,7 +487,7 @@ SpatialPoints::unsetArrayDataLength()
 int
 SpatialPoints::unsetDataType()
 {
-  mDataType = DATAKIND_UNKNOWN;
+  mDataType = SPATIAL_DATAKIND_INVALID;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -745,45 +759,6 @@ SpatialPoints::getAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Gets the value of the "attributeName" attribute of this SpatialPoints.
- */
-int
-SpatialPoints::getAttribute(const std::string& attributeName,
-                            const char* value) const
-{
-  int return_value = SBase::getAttribute(attributeName, value);
-
-  if (return_value == LIBSBML_OPERATION_SUCCESS)
-  {
-    return return_value;
-  }
-
-  if (attributeName == "id")
-  {
-    value = getId().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "compression")
-  {
-    value = getCompressionAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-  else if (attributeName == "dataType")
-  {
-    value = getDataTypeAsString().c_str();
-    return_value = LIBSBML_OPERATION_SUCCESS;
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -928,37 +903,6 @@ SpatialPoints::setAttribute(const std::string& attributeName,
 
 
 
-/** @cond doxygenLibsbmlInternal */
-
-/*
- * Sets the value of the "attributeName" attribute of this SpatialPoints.
- */
-int
-SpatialPoints::setAttribute(const std::string& attributeName,
-                            const char* value)
-{
-  int return_value = SBase::setAttribute(attributeName, value);
-
-  if (attributeName == "id")
-  {
-    return_value = setId(value);
-  }
-  else if (attributeName == "compression")
-  {
-    return_value = setCompression(value);
-  }
-  else if (attributeName == "dataType")
-  {
-    return_value = setDataType(value);
-  }
-
-  return return_value;
-}
-
-/** @endcond */
-
-
-
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1344,7 +1288,7 @@ SpatialPoints_getCompression(const SpatialPoints_t * sp)
 {
   if (sp == NULL)
   {
-    return COMPRESSIONKIND_UNKNOWN;
+    return SPATIAL_COMPRESSIONKIND_INVALID;
   }
 
   return sp->getCompression();
@@ -1383,7 +1327,7 @@ SpatialPoints_getDataType(const SpatialPoints_t * sp)
 {
   if (sp == NULL)
   {
-    return DATAKIND_UNKNOWN;
+    return SPATIAL_DATAKIND_INVALID;
   }
 
   return sp->getDataType();
