@@ -11,7 +11,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -49,6 +49,7 @@ FormulaUnitsData::FormulaUnitsData()
   mUnitReferenceId = "";
   mContainsUndeclaredUnits = false;
   mCanIgnoreUndeclaredUnits = true;
+  mContainsInconsistency = false;
   mTypeOfElement = SBML_UNKNOWN;
   mUnitDefinition = 
     new UnitDefinition(SBMLDocument::getDefaultLevel(), 
@@ -71,6 +72,7 @@ FormulaUnitsData::FormulaUnitsData(const FormulaUnitsData& orig)
   : mUnitReferenceId ( orig.mUnitReferenceId )
   , mContainsUndeclaredUnits ( orig.mContainsUndeclaredUnits )
   , mCanIgnoreUndeclaredUnits ( orig.mCanIgnoreUndeclaredUnits )
+  , mContainsInconsistency ( orig.mContainsInconsistency)
   , mTypeOfElement ( orig.mTypeOfElement )
   , mUnitDefinition ( NULL )
   , mPerTimeUnitDefinition ( NULL )
@@ -120,6 +122,7 @@ FormulaUnitsData& FormulaUnitsData::operator=(const FormulaUnitsData& rhs)
     mContainsUndeclaredUnits = 
                             rhs.mContainsUndeclaredUnits;
     mCanIgnoreUndeclaredUnits = rhs.mCanIgnoreUndeclaredUnits;
+    mContainsInconsistency = rhs.mContainsInconsistency;
     mTypeOfElement = rhs.mTypeOfElement;
 
     delete mUnitDefinition;
@@ -272,13 +275,29 @@ FormulaUnitsData::getCanIgnoreUndeclaredUnits()
 }
 
 /**
-  * @return @c true if the parameters/numbers 
-  * with undeclared units can be ignored, @c false otherwise.
   */
 bool 
-FormulaUnitsData::getCanIgnoreUndeclaredUnits() const 
+FormulaUnitsData::getContainsInconsistency() const 
 { 
-  return mCanIgnoreUndeclaredUnits; 
+  return mContainsInconsistency; 
+}
+
+/**
+*/
+bool
+FormulaUnitsData::getContainsInconsistency()
+{
+  return mContainsInconsistency;
+}
+
+/**
+* @return @c true if the parameters/numbers
+* with undeclared units can be ignored, @c false otherwise.
+*/
+bool
+FormulaUnitsData::getCanIgnoreUndeclaredUnits() const
+{
+  return mCanIgnoreUndeclaredUnits;
 }
 
 /**
@@ -448,6 +467,13 @@ FormulaUnitsData::setCanIgnoreUndeclaredUnits(bool flag)
   mCanIgnoreUndeclaredUnits = flag; 
 }
 
+
+void
+FormulaUnitsData::setContainsInconsistency(bool flag)
+{
+  mContainsInconsistency = flag;
+}
+
 /**
   * Set the unit definition for this FormulaUnitsData.
   * 
