@@ -11,7 +11,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -227,6 +227,26 @@ public:
   bool getCanIgnoreUndeclaredUnits() const;
 
 
+  /**
+  * Get the value of the "containsInconsistency" flag for this
+  * FormulaUnitsData.
+  *
+  * @return @c true if the FormulaUnitsData includes a math expression
+  * for which units are inconsistent e.g., mole + second, @c false otherwise.
+  */
+  bool getContainsInconsistency();
+
+
+  /**
+  * Get the value of the "containsInconsistency" flag for this
+  * FormulaUnitsData.
+  *
+  * @return @c true if the FormulaUnitsData includes a math expression
+  * for which units are inconsistent e.g., mole + second, @c false otherwise.
+  */
+  bool getContainsInconsistency() const;
+
+
   /**
    * Get the unit definition for this FormulaUnitsData.
    * 
@@ -343,6 +363,17 @@ public:
   void setCanIgnoreUndeclaredUnits(bool flag);
 
 
+  /**
+  * Sets the value of the "containsInconsistency" flag for this
+  * FormulaUnitsData.
+  *
+  * @param flag boolean value indicating whether the FormulaUnitsData
+  * includes includes a math expression
+  * for which units are inconsistent e.g., mole + second.
+  */
+  void setContainsInconsistency(bool flag);
+
+
   /**
    * Set the unit definition for this FormulaUnitsData.
    * 
@@ -381,6 +412,7 @@ protected:
 
     bool mContainsUndeclaredUnits;
     bool mCanIgnoreUndeclaredUnits;
+    bool mContainsInconsistency;
 
     int mTypeOfElement;
 
