@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -49,6 +49,7 @@ UnitFormulaFormatter::UnitFormulaFormatter(const Model *m)
  : model(m)
 {
   mContainsUndeclaredUnits = false;
+  mContainsInconsistentUnits = false;
   mCanIgnoreUndeclaredUnits = 2;
   depthRecursiveCall = 0;
 }
@@ -143,7 +144,6 @@ UnitFormulaFormatter::getUnitDefinition(const ASTNode * node,
     case AST_LOGICAL_XOR:
     case AST_CONSTANT_FALSE:
     case AST_CONSTANT_TRUE:
-    case AST_LOGICAL_IMPLIES:
 
     /* relational */
     case AST_RELATIONAL_EQ:
@@ -163,8 +163,6 @@ UnitFormulaFormatter::getUnitDefinition(const ASTNode * node,
     case AST_FUNCTION_ABS:
     case AST_FUNCTION_CEILING:
     case AST_FUNCTION_FLOOR:
-    case AST_FUNCTION_MIN:
-    case AST_FUNCTION_MAX:
   
       ud = getUnitDefinitionFromArgUnitsReturnFunction(node, inKL, reactNo);
       break;
@@ -184,23 +182,10 @@ UnitFormulaFormatter::getUnitDefinition(const ASTNode * node,
 
   /* divide functions */
     case AST_DIVIDE:
-    case AST_FUNCTION_QUOTIENT:
   
       ud = getUnitDefinitionFromDivide(node, inKL, reactNo);
       break;
 
-  /* rem functions */
-    case AST_FUNCTION_REM:
-  
-      ud = getUnitDefinitionFromRem(node, inKL, reactNo);
-      break;
-
-  /* rateOf function */
-    case AST_FUNCTION_RATE_OF:
-  
-      ud = getUnitDefinitionFromRateOf(node, inKL, reactNo);
-      break;
-
   /* piecewise functions */
     case AST_FUNCTION_PIECEWISE:
   
@@ -256,22 +241,38 @@ UnitFormulaFormatter::getUnitDefinition(const ASTNode * node,
 
     case AST_UNKNOWN:
     default:
-    
-      if (node->isQualifier() == true)
+      bool found = false;
+      if (node->getNumPlugins() == 0)
       {
-        /* code so that old and new ast classes will do the right thing */
-        ud = getUnitDefinition(node->getChild(0), inKL, reactNo);
+        ((ASTNode*)(node))->loadASTPlugins(NULL);
       }
-      else
+      for (unsigned int p = 0; p < node->getNumPlugins(); p++)
       {
-        try
+        const ASTBasePlugin* baseplugin = node->getPlugin(p);
+        if (baseplugin->defines(node->getType()))
         {
-          ud = new UnitDefinition(model->getSBMLNamespaces());
+          found = true;
+          ud = baseplugin->getUnitDefinitionFromPackage(this, node, inKL, reactNo);
         }
-        catch ( ... )
+      }
+      if (!found)
+      {
+        if (node->isQualifier() == true)
         {
-          ud = new UnitDefinition(SBMLDocument::getDefaultLevel(),
-            SBMLDocument::getDefaultVersion());
+          /* code so that old and new ast classes will do the right thing */
+          ud = getUnitDefinition(node->getChild(0), inKL, reactNo);
+        }
+        else
+        {
+          try
+          {
+            ud = new UnitDefinition(model->getSBMLNamespaces());
+          }
+          catch (...)
+          {
+            ud = new UnitDefinition(SBMLDocument::getDefaultLevel(),
+              SBMLDocument::getDefaultVersion());
+          }
         }
       }
       break;
@@ -306,6 +307,8 @@ UnitFormulaFormatter::getUnitDefinition(const ASTNode * node,
         UnitDefinition*>(node,static_cast<UnitDefinition*>(ud->clone())));
       undeclaredUnitsMap.insert(std::pair<const ASTNode*, 
                                     bool>(node,mContainsUndeclaredUnits));
+      inconsistentUnitsMap.insert(std::pair<const ASTNode*, bool>
+        (node, mContainsInconsistentUnits));
       canIgnoreUndeclaredUnitsMap.insert(std::pair<const ASTNode*, 
                            unsigned int>(node,mCanIgnoreUndeclaredUnits));
     }
@@ -324,13 +327,20 @@ UnitFormulaFormatter::getUnitDefinition(const ASTNode * node,
     }
     unitDefinitionMap.clear();
     undeclaredUnitsMap.clear();
+    inconsistentUnitsMap.clear();
     canIgnoreUndeclaredUnitsMap.clear();
   }
 
   /* if something is returned with an empty unitDefinition
    * it means not all units could be determined
+   * 
+   * NO !! it might mean the answer could not be determined
+   * i.e. mole + second does not contain undeclared units
+   * but the answer is indeterminate
+   * 
+   * so only mark as undeclared if we have not marked inconsistency
    */
-  if (ud->getNumUnits() == 0)
+  if (!mContainsInconsistentUnits && ud->getNumUnits() == 0)
   {
     mContainsUndeclaredUnits = true;
     mCanIgnoreUndeclaredUnits = 0;
@@ -521,55 +531,6 @@ UnitFormulaFormatter::getUnitDefinitionFromDivide(const ASTNode * node,
 /* @endcond */
 
 
-/* @cond doxygenLibsbmlInternal */
-/** 
-  * returns the unitDefinition for the ASTNode from a rem function
-  */
-UnitDefinition * 
-UnitFormulaFormatter::getUnitDefinitionFromRem(const ASTNode * node, 
-                                        bool inKL, int reactNo)
-{ 
-  UnitDefinition * ud;
-
-  ud = getUnitDefinition(node->getLeftChild(), inKL, reactNo);
-
-  return ud;
-}
-/* @endcond */
-
-
-/* @cond doxygenLibsbmlInternal */
-/** 
-  * returns the unitDefinition for the ASTNode from a rateOf function
-  */
-UnitDefinition * 
-UnitFormulaFormatter::getUnitDefinitionFromRateOf(const ASTNode * node, 
-                                        bool inKL, int reactNo)
-{ 
-  UnitDefinition * ud;
-  UnitDefinition * tempUD;
-  unsigned int i;
-  Unit * unit;
-
-  ud = getUnitDefinition(node->getLeftChild(), inKL, reactNo);
-
-  tempUD = getTimeUnitDefinition();
-  
-  for (i = 0; i < tempUD->getNumUnits(); i++)
-  {
-    unit = tempUD->getUnit(i)->clone();
-    unit->setExponentUnitChecking(-1 * unit->getExponentUnitChecking());
-    ud->addUnit(unit);
-    delete unit;
-  }
-
-  delete tempUD;
-
-  return ud;
-}
-/* @endcond */
-
-
 /* @cond doxygenLibsbmlInternal */
 /** 
   * returns the unitDefinition for the ASTNode from a power function
@@ -612,6 +573,7 @@ UnitFormulaFormatter::getUnitDefinitionFromPower(const ASTNode * node,
   ASTNode * exponentNode = node->getRightChild();
 
   // is the exponent dimensionless or a number because if not it is a problem
+  bool inconsistent = false;
   UnitDefinition* exponentUD = getUnitDefinition(exponentNode, inKL, reactNo);
   UnitDefinition::simplify(exponentUD);
 
@@ -633,12 +595,24 @@ UnitFormulaFormatter::getUnitDefinitionFromPower(const ASTNode * node,
     mContainsUndeclaredUnits = varHasUndeclared;
     mCanIgnoreUndeclaredUnits = varCanIgnoreUndeclared;
   }
+  else if (exponentUD != NULL && exponentUD->getNumUnits() > 0)
+  {
+    inconsistent = true;
+  }
   else
   {
     mContainsUndeclaredUnits = true;
   }
   
   delete exponentUD;
+  if (inconsistent)
+  {
+    for (unsigned int n = variableUD->getNumUnits(); n > 0; --n)
+    {
+      variableUD->removeUnit(n-1);
+    }
+    mContainsInconsistentUnits = true;
+  }
 
   return variableUD;
 
@@ -728,6 +702,8 @@ UnitFormulaFormatter::getUnitDefinitionFromRoot(const ASTNode * node,
     child = node->getLeftChild();
   }
 
+  bool inconsistent = false;
+
   for (i = 0; i < tempUD->getNumUnits(); i++)
   {
     unit = tempUD->getUnit(i);
@@ -755,37 +731,51 @@ UnitFormulaFormatter::getUnitDefinitionFromRoot(const ASTNode * node,
       {
 
         tempUD2 = getUnitDefinition(child, inKL, reactNo);
-        UnitDefinition::simplify(tempUD2);
-
-        if (tempUD2->isVariantOfDimensionless())
+        if (tempUD2 && tempUD2->getNumUnits() > 0)
         {
-          SBMLTransforms::mapComponentValues(model);
-          double value = SBMLTransforms::evaluateASTNode(child);
-          SBMLTransforms::clearComponentValues();
-          if (!util_isNaN(value))
+          UnitDefinition::simplify(tempUD2);
+
+          if (tempUD2->isVariantOfDimensionless())
           {
-            double doubleExponent = 
-                                double(unit->getExponent())/value;
-            //if (floor(doubleExponent) != doubleExponent)
+            SBMLTransforms::mapComponentValues(model);
+            double value = SBMLTransforms::evaluateASTNode(child);
+            SBMLTransforms::clearComponentValues();
+            if (!util_isNaN(value))
+            {
+              double doubleExponent =
+                double(unit->getExponent()) / value;
+              //if (floor(doubleExponent) != doubleExponent)
               unit->setExponentUnitChecking(doubleExponent);
-//              mContainsUndeclaredUnits = true;
-//            unit->setExponentUnitChecking((int)(unit->getExponent()/value));
+              //              mContainsUndeclaredUnits = true;
+              //            unit->setExponentUnitChecking((int)(unit->getExponent()/value));
+            }
+            else
+            {
+              inconsistent = true;
+            }
           }
           else
           {
-            mContainsUndeclaredUnits = true;
+            /* here the child is an expression with units
+            * flag the expression as not checked
+            */
+            inconsistent = true;
           }
         }
         else
         {
-          /* here the child is an expression with units
-          * flag the expression as not checked
-          */
           mContainsUndeclaredUnits = true;
         }
       }
     }
-    ud->addUnit(unit);
+    if (!inconsistent)
+    {
+      ud->addUnit(unit);
+    }
+    else
+    {
+      mContainsInconsistentUnits = true;
+    }
   }
 
   delete tempUD;
@@ -895,6 +885,7 @@ UnitFormulaFormatter::getUnitDefinitionFromArgUnitsReturnFunction
   UnitDefinition * tempUd;
   unsigned int i = 0;
   unsigned int n = 0;
+  bool conflictingUnits = false;
  
   /* save any existing value of undeclaredUnits/canIgnoreUndeclaredUnits */
   unsigned int originalIgnore = mCanIgnoreUndeclaredUnits;
@@ -933,6 +924,13 @@ UnitFormulaFormatter::getUnitDefinitionFromArgUnitsReturnFunction
     {
       resetFlags();
       tempUd = getUnitDefinition(node->getChild(n), inKL, reactNo);
+      if (tempUd->getNumUnits() > 0)
+      {
+        if (!UnitDefinition::areEquivalent(ud, tempUd))
+        {
+          conflictingUnits = true;
+        }
+      }
       if (getContainsUndeclaredUnits())
       {
         currentUndeclared = true;
@@ -953,6 +951,18 @@ UnitFormulaFormatter::getUnitDefinitionFromArgUnitsReturnFunction
   {
     mCanIgnoreUndeclaredUnits = currentIgnore;
   }
+
+  // we know we have something like mole + second
+  // we dont want to report either mole or second as the 'correct' answer
+  if (conflictingUnits)
+  {
+    mContainsInconsistentUnits = true;
+    for (unsigned int j = ud->getNumUnits(); j > 0; --j)
+    {
+      ud->removeUnit(j - 1);
+    }
+    
+  }
   
 
 
@@ -2123,9 +2133,9 @@ UnitFormulaFormatter::getUnitDefinitionFromEventTime(const Event * event)
 }
 
 /**
-* Returns the unitDefinition constructed
-* from the extent units of this Model.
-*/
+ * Returns the unitDefinition constructed
+ * from the extent units of this Model.
+ */
 UnitDefinition * 
 UnitFormulaFormatter::getExtentUnitDefinition()
 {
@@ -2489,13 +2499,23 @@ UnitFormulaFormatter::getContainsUndeclaredUnits()
   return mContainsUndeclaredUnits;
 }
 
-/** 
+/**
+* returns undeclaredUnits value
+*/
+bool
+UnitFormulaFormatter::getContainsInconsistentUnits()
+{
+  return mContainsInconsistentUnits;
+}
+
+/**
   * resets the undeclaredUnits and canIgnoreUndeclaredUnits flags
   * since these will different for each math formula
   */
 void 
 UnitFormulaFormatter::resetFlags()
 {
+  mContainsInconsistentUnits = false;
   mContainsUndeclaredUnits = false;
   mCanIgnoreUndeclaredUnits = 2;
 }
@@ -2505,6 +2525,7 @@ UnitFormulaFormatter::inferUnitDefinition(UnitDefinition* expectedUD,
     const ASTNode * LHS, std::string id, bool inKL, int reactNo)
 {
   UnitDefinition * resultUD = NULL;
+  if (expectedUD == NULL) return NULL;
 
   ASTNode * math = LHS->deepCopy();
   UnitDefinition * tempUD = expectedUD->clone();
