@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1172,12 +1172,182 @@ START_TEST(test_unitdefinition_divide9)
 END_TEST
 
 
+START_TEST(test_unitdefinition_simplify3)
+{
+  UnitDefinition ud(3, 1);
+  Unit* u = ud.createUnit();
+  u->setKind(UNIT_KIND_LITRE);
+  u->setExponent(1);
+  u->setScale(0);
+  u->setMultiplier(1);
+
+  u = ud.createUnit();
+  u->setKind(UNIT_KIND_LITRE);
+  u->setExponent(1);
+  u->setScale(0);
+  u->setMultiplier(1);
+
+  u = ud.createUnit();
+  u->setKind(UNIT_KIND_LITRE);
+  u->setExponent(-1);
+  u->setScale(-3);
+  u->setMultiplier(1);
+  
+  // (1*l)^1 * (1*l)^1 * (10^-3 * l)^-1 - multiplier and scale are 'inside' exponent
+  //l^1 * l^1 * 10^3 * l^-1
+  // 1000 * l^1
+  ud.simplify(&ud);
+
+
+  fail_unless(ud.getNumUnits() == 1);
+  u = ud.getUnit(0);
+
+  fail_unless(u->getExponent() == 1);
+  //fail_unless(u->getScale() == -3);
+
+  fail_unless(u->getMultiplier() == 1000);
+  fail_unless(u->getScale() == 0);
+  fail_unless(u->getKind() == UNIT_KIND_LITRE);
+
+}
+END_TEST
+
+
+START_TEST(test_unitdefinition_simplify3b)
+{
+  UnitDefinition ud(3, 1);
+  Unit* u = ud.createUnit();
+  u->setKind(UNIT_KIND_LITRE);
+  u->setExponent(1);
+  u->setScale(0);
+  u->setMultiplier(1);
+
+  u = ud.createUnit();
+  u->setKind(UNIT_KIND_LITRE);
+  u->setExponent(-1);
+  u->setScale(-3);
+  u->setMultiplier(1);
+
+  u = ud.createUnit();
+  u->setKind(UNIT_KIND_LITRE);
+  u->setExponent(1);
+  u->setScale(0);
+  u->setMultiplier(1);
+
+  // (1*l)^1 * (1*l)^1 * (10^-3 * l)^-1 - multiplier and scale are 'inside' exponent
+  //l^1 * l^1 * 10^3 * l^-1
+  // 1000 * l^1
+  ud.simplify(&ud);
+
+
+  fail_unless(ud.getNumUnits() == 1);
+  u = ud.getUnit(0);
+
+  fail_unless(u->getExponent() == 1);
+
+  fail_unless(u->getMultiplier() == 1000);
+  fail_unless(u->getScale() == 0);
+  fail_unless(u->getKind() == UNIT_KIND_LITRE);
+
+}
+END_TEST
+
+
+START_TEST(test_unitdefinition_simplify4)
+{
+  UnitDefinition ud(3, 1);
+  Unit* u = ud.createUnit();
+  u->setKind(UNIT_KIND_DIMENSIONLESS);
+  u->setExponent(1);
+  u->setScale(0);
+  u->setMultiplier(1);
+
+  u = ud.createUnit();
+  u->setKind(UNIT_KIND_DIMENSIONLESS);
+  u->setExponent(2);
+  u->setScale(0);
+  u->setMultiplier(1);
+
+  u = ud.createUnit();
+  u->setKind(UNIT_KIND_DIMENSIONLESS);
+  u->setExponent(-2);
+  u->setScale(-3);
+  u->setMultiplier(1);
+
+  ud.simplify(&ud);
+
+
+  // (1 * dim)^1 *  (1 * dim)^2 * (1 * 10^-3 * dim)^-2
+  //dim^1 * dim^2 * 10^6 * dim^-2
+  // 1000000 * dim^1
+  fail_unless(ud.getNumUnits() == 1);
+  u = ud.getUnit(0);
+  fail_unless(u->getKind() == UNIT_KIND_DIMENSIONLESS);
+  fail_unless(u->getExponent() == 1);
+  //fail_unless(u->getScale() == -3);
+  fail_unless(u->getMultiplier() == 1000000);
+  fail_unless(u->getScale() == 0);
+
+}
+END_TEST
+
+
+START_TEST(test_unitdefinition_simplify5)
+{
+  UnitDefinition ud(3, 1);
+  Unit* u = ud.createUnit();
+  u->setKind(UNIT_KIND_DIMENSIONLESS);
+  u->setExponent(1);
+  u->setScale(0);
+  u->setMultiplier(1);
+
+  u = ud.createUnit();
+  u->setKind(UNIT_KIND_DIMENSIONLESS);
+  u->setExponent(2);
+  u->setScale(0);
+  u->setMultiplier(1);
+
+  u = ud.createUnit();
+  u->setKind(UNIT_KIND_LITRE);
+  u->setExponent(1);
+  u->setScale(0);
+  u->setMultiplier(1);
+
+  u = ud.createUnit();
+  u->setKind(UNIT_KIND_DIMENSIONLESS);
+  u->setExponent(-2);
+  u->setScale(-3);
+  u->setMultiplier(1);
+
+  ud.simplify(&ud);
+
+  // (1 * dim)^1 *  (1 * dim)^2 * (1 * l)^1 * (1 * 10^-3 * dim)^-2
+  // dim^1 * dim^2 *  l^1 * 10^6 * dim^-2
+  // 1000000 * l^1
+
+  fail_unless(ud.getNumUnits() == 1);
+  u = ud.getUnit(0);
+  //fail_unless(u->getExponent() == 1);
+  //fail_unless(u->getScale() == -3);
+  fail_unless(u->getKind() == UNIT_KIND_LITRE);
+  fail_unless(u->getExponent() == 1);
+  fail_unless(u->getMultiplier() == 1000000);
+  fail_unless(u->getScale() == 0);
+
+}
+END_TEST
+
+
 Suite *
 create_suite_UtilsUnitDefinition (void) 
 { 
   Suite *suite = suite_create("UtilsUnitDefinition");
   TCase *tcase = tcase_create("UtilsUnitDefinition");
  
+  tcase_add_test( tcase, test_unitdefinition_simplify3     );
+  tcase_add_test( tcase, test_unitdefinition_simplify3b    );
+  tcase_add_test( tcase, test_unitdefinition_simplify4     );
+  tcase_add_test( tcase, test_unitdefinition_simplify5     );
 
   tcase_add_test( tcase, test_unitdefinition_simplify      );
   tcase_add_test( tcase, test_unitdefinition_simplify1     );
