@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -123,8 +123,17 @@ IdList::end () const
   return mIds.end();
 }
 #endif
+
+
+bool
+IdList::empty() const
+{
+  return mIds.empty();
+}
+
+
 /**
- * @return true if id is already in this IdList, false otherwise.
+ * @return @c true if id is already in this IdList, false otherwise.
  */
 bool
 IdList::contains (const std::string& id) const
