@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -72,6 +72,14 @@ public:
    * @return @c true if id is already in this IdList, @c false otherwise.
    */
   bool contains (const std::string& id) const;
+  
+  /**
+   * Returns @c true if this IdList is empty, @c false otherwise.
+   * 
+   * @return @c true if this IdList is empty, @c false otherwise.
+   */
+  bool empty() const;
+  
 
   /**
    * Removes all ids in this IdList before the given @p id.
