@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -112,8 +112,6 @@ ArgumentsUnitsCheck::checkUnits (const Model& m, const ASTNode& node, const SBas
     case AST_RELATIONAL_LEQ:
     case AST_RELATIONAL_LT:
     case AST_RELATIONAL_NEQ:
-    case AST_FUNCTION_MAX:
-    case AST_FUNCTION_MIN:
   
       checkSameUnitsAsArgs(m, node, sb, inKL, reactNo);
       break;
@@ -292,7 +290,7 @@ ArgumentsUnitsCheck::checkSameUnitsAsArgs (const Model& m,
   ud = unitFormat->getUnitDefinition(node.getChild(i), inKL, reactNo);
 
   /* get the first child that is not a parameter with undeclared units */
-  while (unitFormat->getContainsUndeclaredUnits() && 
+  while ((unitFormat->getContainsUndeclaredUnits() || (ud != NULL && ud->getNumUnits() == 0)) && 
     i < node.getNumChildren()-1)
   {
     delete ud; 
@@ -368,9 +366,9 @@ ArgumentsUnitsCheck::getMessage (const ASTNode& node, const SBase& object)
   return oss_msg.str();
 }
 /*
-* Logs a message about a function that should return same units
-* as the arguments
-*/
+ * Logs a message about a function that should return same units
+ * as the arguments
+ */
 void 
 ArgumentsUnitsCheck::logInconsistentSameUnits (const ASTNode & node, 
                                              const SBase & sb)
@@ -403,8 +401,8 @@ ArgumentsUnitsCheck::logInconsistentSameUnits (const ASTNode & node,
 }
 
 /*
-* Logs a message about a delay function that should have time units
-*/
+ * Logs a message about a delay function that should have time units
+ */
 void 
 ArgumentsUnitsCheck::logInconsistentDelay (const ASTNode & node, 
                                           const SBase & sb)
@@ -438,8 +436,8 @@ ArgumentsUnitsCheck::logInconsistentDelay (const ASTNode & node,
 }
 
 /*
-* Logs a message about a piecewise function that should same units
-*/
+ * Logs a message about a piecewise function that should same units
+ */
 void 
 ArgumentsUnitsCheck::logInconsistentPiecewise (const ASTNode & node, 
                                           const SBase & sb)
@@ -473,9 +471,9 @@ ArgumentsUnitsCheck::logInconsistentPiecewise (const ASTNode & node,
 }
 
 /*
-* Logs a message about the conditional part of a piecewise function 
-* that should have dimensionless units
-*/
+ * Logs a message about the conditional part of a piecewise function 
+ * that should have dimensionless units
+ */
 void 
 ArgumentsUnitsCheck::logInconsistentPiecewiseCondition (const ASTNode & node, 
                                           const SBase & sb)
