@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -139,7 +139,7 @@ LocalParameterMathCheck::checkCiElement (const Model& m,
       m.getParameter(name)   == NULL &&
       m.getReaction(name)    == NULL)
   {
-    if (m.getLevel() >= 3)
+    if (m.getLevel() >= 3 || (m.getLevel() == 2 && m.getVersion() == 5))
     {
       for (unsigned int rxn = 0; rxn < m.getNumReactions(); rxn++)
       {
