@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -149,6 +149,12 @@ protected:
    */
   void logMathConflict (const ASTNode& node, const SBase& object);
 
+  /**
+  * Logs a message that the math (and its corresponding object) have
+  * failed to satisfy this constraint.
+  */
+  void logPackageMathConflict (const ASTNode& node, const SBase& object, const std::string& error);
+
   /**
    * Checks that the math will return a numeric result
    * forces recursion thru the AST tree
