@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -142,16 +142,7 @@ PieceBooleanMathCheck::checkPiece (const Model& m, const ASTNode& node,
   unsigned int numChildren = node.getNumChildren();
   unsigned int numPieces = numChildren;
 
-#ifdef LIBSBML_USE_LEGACY_MATH
   if ((numChildren % 2) != 0) numPieces--;
-#else
-  numPieces = 2 * node.getNumPiece();
-  if (numPieces > numChildren)
-  {
-    // the piecewise is not correct
-    return;
-  }
-#endif
 
   for (unsigned int n = 1; n < numPieces; n += 2)
   {
