@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2017 jointly by the following organizations:
+ * Copyright (C) 2013-2018 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -173,11 +173,14 @@ ValidCnUnitsValue::checkValidUnits (const Model& m, const ASTNode& node,
  * in  conflict with an object previously defined.
  */
 const string
-ValidCnUnitsValue::getMessage (const ASTNode& , const SBase& )
+ValidCnUnitsValue::getMessage (const ASTNode& node, const SBase& object)
 {
 
   ostringstream oss_msg;
 
+  oss_msg << "The MathML of the <" << object.getElementName() << "> element "
+    "with id '" << object.getId() << "' contains a <cn> element with an "
+    "unknown unit definition: '" << node.getUnits() << "'.\n";
 
   return oss_msg.str();
 }
